# src.models.py
from typing import List
from pydantic import BaseModel, Field

class Band(BaseModel):
    name: str
    description: str

class Product(BaseModel):
    product_id: str
    description: str
    bands: List[Band]

def get_product_by_id(product_id: str) -> Product:
    for product in PRODUCTS:
        if product.product_id == product_id:
            return product
    raise ValueError("Product not found")

PRODUCTS = [
    Product(
        product_id="GPW_DataQualityInd.411",
        description="Quality of Input Data for Population Count and Density Grids",
        bands=[
            Band(name="data-context", description=""),
            Band(name="mean-admin-area", description=""),
            Band(name="water-mask", description=""),
        ]
    ),
    Product(
        product_id="GPW_UN_Adj_PopCount.411",
        description="UN-adjusted Population Count",
        bands=[
            Band(name="population-count", description=""),
        ]
    ),
    Product(
        product_id="GPW_UN_Adj_PopDensity.411",
        description="UN-adjusted Population Density",
        bands=[
            Band(name="population-density", description=""),
        ]
    ),
    Product(
        product_id="GPW_Basic_Demog_Char.411",
        description="Basic Demographic Characteristics - Population Count (cntm)",
        bands=[
            Band(name="a000_004bt", description="Ages 0 - 4 Both Sexes"),
            Band(name="a000_004ft", description="Ages 0 - 4 Females"),
            Band(name="a000_004mt", description="Ages 0 - 4 Males"),
            Band(name="a000_014bt", description="Ages 0 - 14 Both Sexes"),
            Band(name="a000_014ft", description="Ages 0 - 14 Females"),
            Band(name="a000_014mt", description="Ages 0 - 14 Males"),
            Band(name="a005_009bt", description="Ages 5 - 9 Both Sexes"),
            Band(name="a005_009ft", description="Ages 5 - 9 Females"),
            Band(name="a005_009mt", description="Ages 5 - 9 Males"),
            Band(name="a010_014bt", description="Ages 10 - 14 Both Sexes"),
            Band(name="a010_014ft", description="Ages 10 - 14 Females"),
            Band(name="a010_014mt", description="Ages 10 - 14 Males"),
            Band(name="a015_019bt", description="Ages 15 - 19 Both Sexes"),
            Band(name="a015_019ft", description="Ages 15 - 19 Females"),
            Band(name="a015_019mt", description="Ages 15 - 19 Males"),
            Band(name="a015_049bt", description="Ages 15 - 49 Both Sexes"),
            Band(name="a015_049ft", description="Ages 15 - 49 Females"),
            Band(name="a015_049mt", description="Ages 15 - 49 Males"),
            Band(name="a015_064bt", description="Ages 15 - 64 Both Sexes"),
            Band(name="a015_064ft", description="Ages 15 - 64 Females"),
            Band(name="a015_064mt", description="Ages 15 - 64 Males"),
            Band(name="a020_024bt", description="Ages 20 - 24 Both Sexes"),
            Band(name="a020_024ft", description="Ages 20 - 24 Females"),
            Band(name="a020_024mt", description="Ages 20 - 24 Males"),
            Band(name="a025_029bt", description="Ages 25 - 29 Both Sexes"),
            Band(name="a025_029ft", description="Ages 25 - 29 Females"),
            Band(name="a025_029mt", description="Ages 25 - 29 Males"),
            Band(name="a030_034bt", description="Ages 30 - 34 Both Sexes"),
            Band(name="a030_034ft", description="Ages 30 - 34 Females"),
            Band(name="a030_034mt", description="Ages 30 - 34 Males"),
            Band(name="a035_039bt", description="Ages 35 - 39 Both Sexes"),
            Band(name="a035_039ft", description="Ages 35 - 39 Females"),
            Band(name="a035_039mt", description="Ages 35 - 39 Males"),
            Band(name="a040_044bt", description="Ages 40 - 44 Both Sexes"),
            Band(name="a040_044ft", description="Ages 40 - 44 Females"),
            Band(name="a040_044mt", description="Ages 40 - 44 Males"),
            Band(name="a045_049bt", description="Ages 45 - 49 Both Sexes"),
            Band(name="a045_049ft", description="Ages 45 - 49 Females"),
            Band(name="a045_049mt", description="Ages 45 - 49 Males"),
            Band(name="a050_054bt", description="Ages 50 - 54 Both Sexes"),
            Band(name="a050_054ft", description="Ages 50 - 54 Females"),
            Band(name="a050_054mt", description="Ages 50 - 54 Males"),
            Band(name="a055_059bt", description="Ages 55 - 59 Both Sexes"),
            Band(name="a055_059ft", description="Ages 55 - 59 Females"),
            Band(name="a055_059mt", description="Ages 55 - 59 Males"),
            Band(name="a060_064bt", description="Ages 60 - 64 Both Sexes"),
            Band(name="a060_064ft", description="Ages 60 - 64 Females"),
            Band(name="a060_064mt", description="Ages 60 - 64 Males"),
            Band(name="a065_069bt", description="Ages 65 - 69 Both Sexes"),
            Band(name="a065_069ft", description="Ages 65 - 69 Females"),
            Band(name="a065_069mt", description="Ages 65 - 69 Males"),
            Band(name="a065plusbt", description="Ages 65+ Both Sexes"),
            Band(name="a065plusft", description="Ages 65+ Females"),
            Band(name="a065plusmt", description="Ages 65+ Males"),
            Band(name="a070_074bt", description="Ages 70 - 74 Both Sexes"),
            Band(name="a070_074ft", description="Ages 70 - 74 Females"),
            Band(name="a070_074mt", description="Ages 70 - 74 Males"),
            Band(name="a070plusbt", description="Ages 70+ Both Sexes"),
            Band(name="a070plusft", description="Ages 70+ Females"),
            Band(name="a070plusmt", description="Ages 70+ Males"),
            Band(name="a075_079bt", description="Ages 75 - 79 Both Sexes"),
            Band(name="a075_079ft", description="Ages 75 - 79 Females"),
            Band(name="a075_079mt", description="Ages 75 - 79 Males"),
            Band(name="a075plusbt", description="Ages 75+ Both Sexes"),
            Band(name="a075plusft", description="Ages 75+ Females"),
            Band(name="a075plusmt", description="Ages 75+ Males"),
            Band(name="a080_084bt", description="Ages 80 - 84 Both Sexes"),
            Band(name="a080_084ft", description="Ages 80 - 84 Females"),
            Band(name="a080_084mt", description="Ages 80 - 84 Males"),
            Band(name="a080plusbt", description="Ages 80+ Both Sexes"),
            Band(name="a080plusft", description="Ages 80+ Females"),
            Band(name="a080plusmt", description="Ages 80+ Males"),
            Band(name="a085plusbt", description="Ages 85+ Both Sexes"),
            Band(name="a085plusft", description="Ages 85+ Females"),
            Band(name="a085plusmt", description="Ages 85+ Males"),
            Band(name="atotpopbt", description="Ages Total Population Both Sexes"),
            Band(name="atotpopft", description="Ages Total Population Females"),
            Band(name="atotpopmt", description="Ages Total Population Males"),
        ]
    ),
    Product(
        product_id="MCD12Q1.061",
        description="Land Cover Type",
        bands=[
            Band(name="LC_Prop1", description="FAO-Land Cover Classification System 1 (LCCS1) land cover layer"),
            Band(name="LC_Prop1_Assessment", description="LCCS1 land cover layer confidence"),
            Band(name="LC_Prop2", description="FAO-LCCS2 land use layer"),
            Band(name="LC_Prop2_Assessment", description="LCCS2 land use layer confidence"),
            Band(name="LC_Prop3", description="FAO-LCCS3 surface hydrology layer"),
            Band(name="LC_Prop3_Assessment", description="LCCS3 surface hydrology layer confidence"),
            Band(name="LC_Type1", description="Land Cover Type 1: Annual International Geosphere-Biosphere Programme (IGBP) classification"),
            Band(name="LC_Type2", description="Land Cover Type 2: Annual University of Maryland (UMD) classification"),
            Band(name="LC_Type3", description="Land Cover Type 3: Annual Leaf Area Index (LAI) classification"),
            Band(name="LC_Type4", description="Land Cover Type 4: Annual BIOME-Biogeochemical Cycles (BGC) classification"),
            Band(name="LC_Type5", description="Land Cover Type 5: Annual Plant Functional Types classification"),
            Band(name="LW", description="Binary land (class 2) / water (class 1) mask derived from MOD44W"),
            Band(name="QC", description="Product quality flags"),
        ]
    ),
    Product(
        product_id="MCD12Q2.061",
        description="Land Cover Dynamics",
        bands=[
            Band(name="Dormancy", description="Date when EVI2 last crossed 15% of the segment EVI2 amplitude"),
            Band(name="EVI_Amplitude", description="Segment maximum - minimum EVI2"),
            Band(name="EVI_Area", description="Sum of daily interpolated EVI2 from Greenup to Dormancy"),
            Band(name="EVI_Minimum", description="Segment minimum EVI2 value"),
            Band(name="Greenup", description="Date when EVI2 first crossed 15% of the segment EVI2 amplitude"),
            Band(name="Maturity", description="Date when EVI2 first crossed 90% of the segment EVI2 amplitude"),
            Band(name="MidGreendown", description="Date when EVI2 last crossed 50% of the segment EVI2 amplitude"),
            Band(name="MidGreenup", description="Date when EVI2 first crossed 50% of the segment EVI2 amplitude"),
            Band(name="NumCycles", description="Total number of valid vegetation cycles with peak in product year"),
            Band(name="Peak", description="Date when EVI2 reached the segment maximum"),
            Band(name="QA_Detailed", description="Bit-packed, SDS-specific QA codes"),
            Band(name="QA_Overall", description="QA code for entire segment"),
            Band(name="Senescence", description="Date when EVI2 last crossed 90% of the segment EVI2 amplitude"),
        ]
    ),
    Product(
        product_id="MCD15A2H.061",
        description="Leaf Area Index (LAI) and Fraction of Photosynthetically Active Radiation (FPAR)",
        bands=[
            Band(name="FparExtra_QC", description="Extra detail Quality for Lai and Fpar"),
            Band(name="FparLai_QC", description="Quality for Lai and Fpar"),
            Band(name="FparStdDev_500m", description="Standard deviation of Fpar"),
            Band(name="Fpar_500m", description="Fraction of photosynthetically active radiation"),
            Band(name="LaiStdDev_500m", description="Standard deviation of Lai"),
            Band(name="Lai_500m", description="Leaf area index"),
        ]
    ),
    Product(
        product_id="MCD15A3H.061",
        description="Leaf Area Index (LAI) and Fraction of Photosynthetically Active Radiation (FPAR)",
        bands=[
            Band(name="FparExtra_QC", description="Extra detail Quality for Lai and Fpar"),
            Band(name="FparLai_QC", description="Quality for Lai and Fpar"),
            Band(name="FparStdDev_500m", description="Standard deviation of Fpar"),
            Band(name="Fpar_500m", description="Fraction of photosynthetically active radiation"),
            Band(name="LaiStdDev_500m", description="Standard deviation of Lai"),
            Band(name="Lai_500m", description="Leaf area index"),
        ]
    ),
    Product(
        product_id="MCD43A1.061",
        description="Bidirectional Reflectance Distribution Function (BRDF) and Albedo",
        bands=[
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_Band1", description="BRDF_Albedo_Band_Mandatory_Quality_Band1"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_Band2", description="BRDF_Albedo_Band_Mandatory_Quality_Band2"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_Band3", description="BRDF_Albedo_Band_Mandatory_Quality_Band3"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_Band4", description="BRDF_Albedo_Band_Mandatory_Quality_Band4"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_Band5", description="BRDF_Albedo_Band_Mandatory_Quality_Band5"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_Band6", description="BRDF_Albedo_Band_Mandatory_Quality_Band6"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_Band7", description="BRDF_Albedo_Band_Mandatory_Quality_Band7"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_nir", description="BRDF_Albedo_Band_Mandatory_Quality_nir"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_shortwave", description="BRDF_Albedo_Band_Mandatory_Quality_shortwave"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_vis", description="BRDF_Albedo_Band_Mandatory_Quality_vis"),
            Band(name="BRDF_Albedo_Parameters_Band1", description="3D Parameter (iso, vol, geo)"),
            Band(name="BRDF_Albedo_Parameters_Band2", description="3D Parameter (iso, vol, geo)"),
            Band(name="BRDF_Albedo_Parameters_Band3", description="3D Parameter (iso, vol, geo)"),
            Band(name="BRDF_Albedo_Parameters_Band4", description="3D Parameter (iso, vol, geo)"),
            Band(name="BRDF_Albedo_Parameters_Band5", description="3D Parameter (iso, vol, geo)"),
            Band(name="BRDF_Albedo_Parameters_Band6", description="3D Parameter (iso, vol, geo)"),
            Band(name="BRDF_Albedo_Parameters_Band7", description="3D Parameter (iso, vol, geo)"),
            Band(name="BRDF_Albedo_Parameters_nir", description="3D Parameter (iso, vol, geo)"),
            Band(name="BRDF_Albedo_Parameters_shortwave", description="3D Parameter (iso, vol, geo)"),
            Band(name="BRDF_Albedo_Parameters_vis", description="3D Parameter (iso, vol, geo)"),
        ]
    ),
    Product(
        product_id="MCD43A2.061",
        description="Bidirectional Reflectance Distribution Function (BRDF) and Albedo",
        bands=[
            Band(name="BRDF_Albedo_Band_Quality_Band1", description="BRDF Inversion Information"),
            Band(name="BRDF_Albedo_Band_Quality_Band2", description="BRDF Inversion Information"),
            Band(name="BRDF_Albedo_Band_Quality_Band3", description="BRDF Inversion Information"),
            Band(name="BRDF_Albedo_Band_Quality_Band4", description="BRDF Inversion Information"),
            Band(name="BRDF_Albedo_Band_Quality_Band5", description="BRDF Inversion Information"),
            Band(name="BRDF_Albedo_Band_Quality_Band6", description="BRDF Inversion Information"),
            Band(name="BRDF_Albedo_Band_Quality_Band7", description="BRDF Inversion Information"),
            Band(name="BRDF_Albedo_LandWaterType", description="Land Water Type"),
            Band(name="BRDF_Albedo_LocalSolarNoon", description="Solar Zenith Angle of Local Solar Noon"),
            Band(name="BRDF_Albedo_Platform", description="BRDF Albedo Platform information"),
            Band(name="BRDF_Albedo_Uncertainty", description="BRDF Inversion Information"),
            Band(name="BRDF_Albedo_ValidObs_Band1", description="Valid Observation for Band1"),
            Band(name="BRDF_Albedo_ValidObs_Band2", description="Valid Observation for Band2"),
            Band(name="BRDF_Albedo_ValidObs_Band3", description="Valid Observation for Band3"),
            Band(name="BRDF_Albedo_ValidObs_Band4", description="Valid Observation for Band4"),
            Band(name="BRDF_Albedo_ValidObs_Band5", description="Valid Observation for Band5"),
            Band(name="BRDF_Albedo_ValidObs_Band6", description="Valid Observation for Band6"),
            Band(name="BRDF_Albedo_ValidObs_Band7", description="Valid Observation for Band7"),
            Band(name="Snow_BRDF_Albedo", description="Snow-free BRDF/Albedo retrieved"),
        ]
    ),
    Product(
        product_id="MCD43A3.061",
        description="Bidirectional Reflectance Distribution Function (BRDF) and Albedo",
        bands=[
            Band(name="Albedo_BSA_Band1", description="Black-Sky Albedo for Band 1"),
            Band(name="Albedo_BSA_Band2", description="Black-Sky Albedo for Band 2"),
            Band(name="Albedo_BSA_Band3", description="Black-Sky Albedo for Band 3"),
            Band(name="Albedo_BSA_Band4", description="Black-Sky Albedo for Band 4"),
            Band(name="Albedo_BSA_Band5", description="Black-Sky Albedo for Band 5"),
            Band(name="Albedo_BSA_Band6", description="Black-Sky Albedo for Band 6"),
            Band(name="Albedo_BSA_Band7", description="Black-Sky Albedo for Band 6"),
            Band(name="Albedo_BSA_nir", description="Black-Sky Albedo for NIR broadband"),
            Band(name="Albedo_BSA_shortwave", description="Black-Sky Albedo for shortwave broadband"),
            Band(name="Albedo_BSA_vis", description="Black-Sky Albedo for VIS broadband"),
            Band(name="Albedo_WSA_Band1", description="White-Sky Albedo for Band 1"),
            Band(name="Albedo_WSA_Band2", description="White-Sky Albedo for Band2"),
            Band(name="Albedo_WSA_Band3", description="White-Sky Albedo for Band3"),
            Band(name="Albedo_WSA_Band4", description="White-Sky Albedo for Band4"),
            Band(name="Albedo_WSA_Band5", description="White-Sky Albedo for Band5"),
            Band(name="Albedo_WSA_Band6", description="White-Sky Albedo for Band6"),
            Band(name="Albedo_WSA_Band7", description="White-Sky Albedo for Band7"),
            Band(name="Albedo_WSA_nir", description="White-Sky Albedo for NIR broadband"),
            Band(name="Albedo_WSA_shortwave", description="White-Sky Albedo for shortwave broadband"),
            Band(name="Albedo_WSA_vis", description="White-Sky Albedo for VIS broadband"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_Band1", description="BRDF_Albedo_Band_Mandatory_Quality_Band1"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_Band2", description="BRDF_Albedo_Band_Mandatory_Quality_Band2"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_Band3", description="BRDF_Albedo_Band_Mandatory_Quality_Band3"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_Band4", description="BRDF_Albedo_Band_Mandatory_Quality_Band4"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_Band5", description="BRDF_Albedo_Band_Mandatory_Quality_Band5"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_Band6", description="BRDF_Albedo_Band_Mandatory_Quality_Band6"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_Band7", description="BRDF_Albedo_Band_Mandatory_Quality_Band7"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_nir", description="BRDF_Albedo_Band_Mandatory_Quality_nir"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_shortwave", description="BRDF_Albedo_Band_Mandatory_Quality_shortwave"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_vis", description="BRDF_Albedo_Band_Mandatory_Quality_vis"),
        ]
    ),
    Product(
        product_id="MCD43A4.061",
        description="Bidirectional Reflectance Distribution Function (BRDF) and Albedo",
        bands=[
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_Band1", description="BRDF_Albedo_Band_Mandatory_Quality_Band1"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_Band2", description="BRDF_Albedo_Band_Mandatory_Quality_Band2"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_Band3", description="BRDF_Albedo_Band_Mandatory_Quality_Band3"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_Band4", description="BRDF_Albedo_Band_Mandatory_Quality_Band4"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_Band5", description="BRDF_Albedo_Band_Mandatory_Quality_Band5"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_Band6", description="BRDF_Albedo_Band_Mandatory_Quality_Band6"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_Band7", description="BRDF_Albedo_Band_Mandatory_Quality_Band7"),
            Band(name="Nadir_Reflectance_Band1", description="NBAR at local solar noon for band 1"),
            Band(name="Nadir_Reflectance_Band2", description="NBAR at local solar noon for band 2"),
            Band(name="Nadir_Reflectance_Band3", description="NBAR at local solar noon for band 3"),
            Band(name="Nadir_Reflectance_Band4", description="NBAR at local solar noon for band 4"),
            Band(name="Nadir_Reflectance_Band5", description="NBAR at local solar noon for band 5"),
            Band(name="Nadir_Reflectance_Band6", description="NBAR at local solar noon for band 6"),
            Band(name="Nadir_Reflectance_Band7", description="NBAR at local solar noon for band 7"),
        ]
    ),
    Product(
        product_id="MCD64A1.061",
        description="Burned Area (fire)",
        bands=[
            Band(name="Burn_Date", description="ordinal day of burn"),
            Band(name="Burn_Date_Uncertainty", description="uncertainty in day of burn"),
            Band(name="First_Day", description="first day of reliable change detection"),
            Band(name="Last_Day", description="last day of reliable change detection"),
            Band(name="QA", description="Quality Assurance Indicators"),
        ]
    ),
    Product(
        product_id="MOD09A1.061",
        description="Surface Reflectance Bands 1-7",
        bands=[
            Band(name="sur_refl_b01", description="Surface Reflectance Band 1 (620-670 nm)"),
            Band(name="sur_refl_b02", description="Surface Reflectance Band 2 (841-876 nm)"),
            Band(name="sur_refl_b03", description="Surface Reflectance Band 3 (459-479 nm)"),
            Band(name="sur_refl_b04", description="Surface Reflectance Band 4 (545-565 nm)"),
            Band(name="sur_refl_b05", description="Surface Reflectance Band 5 (1230-1250 nm)"),
            Band(name="sur_refl_b06", description="Surface Reflectance Band 6 (1628-1652 nm)"),
            Band(name="sur_refl_b07", description="Surface Reflectance Band 7 (2105-2155 nm)"),
            Band(name="sur_refl_day_of_year", description="Day of the year for the pixel"),
            Band(name="sur_refl_qc_500m", description="Surface reflectance 500m band quality control flags"),
            Band(name="sur_refl_raz", description="MODIS relative azimuth angle"),
            Band(name="sur_refl_state_500m", description="Surface reflectance 500m state flags"),
            Band(name="sur_refl_szen", description="MODIS solar zenith angle"),
            Band(name="sur_refl_vzen", description="MODIS view zenith angle"),
        ]
    ),
    Product(
        product_id="MOD09GA.061",
        description="Surface Reflectance Bands 1-7",
        bands=[
            Band(name="QC_500m_1", description="Surface Reflectance 500m Quality Assurance"),
            Band(name="Range_1", description="Distance to sensor"),
            Band(name="SensorAzimuth_1", description="Azimuth angle to sensor"),
            Band(name="SensorZenith_1", description="Zenith angle to sensor"),
            Band(name="SolarAzimuth_1", description="Azimuth angle to sun"),
            Band(name="SolarZenith_1", description="Zenith angle to sun"),
            Band(name="gflags_1", description="Geolocation flags"),
            Band(name="granule_pnt_1", description="Granule pointer"),
            Band(name="iobs_res_1", description="Observation number"),
            Band(name="num_observations_1km", description="Number of observations per 1K pixel"),
            Band(name="obscov_500m_1", description="Observation coverage"),
            Band(name="orbit_pnt_1", description="Orbit pointer"),
            Band(name="state_1km_1", description="1km Reflectance Data State QA"),
            Band(name="sur_refl_b01_1", description="Surface Reflectance Band 1"),
            Band(name="sur_refl_b02_1", description="Surface Reflectance Band 2"),
            Band(name="sur_refl_b03_1", description="Surface Reflectance Band 3"),
            Band(name="sur_refl_b04_1", description="Surface Reflectance Band 4"),
            Band(name="sur_refl_b05_1", description="Surface Reflectance Band 5"),
            Band(name="sur_refl_b06_1", description="Surface Reflectance Band 6"),
            Band(name="sur_refl_b07_1", description="Surface Reflectance Band 7"),
        ]
    ),
    Product(
        product_id="MOD09GQ.061",
        description="Surface Reflectance Bands 1-2",
        bands=[
            Band(name="QC_250m_1", description="Surface Reflectance 250m Quality Assurance"),
            Band(name="granule_pnt_1", description="Granule pointer"),
            Band(name="iobs_res_1", description="Observation number"),
            Band(name="num_observations", description="Number of observations per 250m pixel"),
            Band(name="obscov_1", description="Observation coverage"),
            Band(name="orbit_pnt_1", description="Orbit pointer"),
            Band(name="sur_refl_b01_1", description="Surface Reflectance Band 1"),
            Band(name="sur_refl_b02_1", description="Surface Reflectance Band 2"),
        ]
    ),
    Product(
        product_id="MOD09Q1.061",
        description="Surface Reflectance Bands 1-2",
        bands=[
            Band(name="sur_refl_b01", description="Surface Reflectance Band 1"),
            Band(name="sur_refl_b02", description="Surface Reflectance Band 2"),
            Band(name="sur_refl_qc_250m", description="Surface Reflectance 250m Band Quality Control flags"),
            Band(name="sur_refl_state_250m", description="Surface_reflectance_250m_state_flags"),
        ]
    ),
    Product(
        product_id="MOD10A1.061",
        description="Snow Cover (NDSI)",
        bands=[
            Band(name="NDSI_Snow_Cover", description=""),
            Band(name="NDSI_Snow_Cover_Algorithm_Flags_QA", description=""),
            Band(name="NDSI_Snow_Cover_Basic_QA", description=""),
            Band(name="Snow_Albedo_Daily_Tile", description=""),
            Band(name="granule_pnt", description=""),
            Band(name="orbit_pnt", description=""),
        ]
    ),
    Product(
        product_id="MOD10A2.061",
        description="Snow Cover",
        bands=[
            Band(name="Eight_Day_Snow_Cover", description=""),
            Band(name="Maximum_Snow_Extent", description=""),
        ]
    ),
    Product(
        product_id="MOD11A1.061",
        description="Land Surface Temperature & Emissivity (LST&E)",
        bands=[
            Band(name="Clear_day_cov", description="Day clear-sky coverage"),
            Band(name="Clear_night_cov", description="Night clear-sky coverage"),
            Band(name="Day_view_angl", description="View zenith angle of day observation"),
            Band(name="Day_view_time", description="Local time of day observation"),
            Band(name="Emis_31", description="Band 31 emissivity"),
            Band(name="Emis_32", description="Band 32 emissivity"),
            Band(name="LST_Day_1km", description="Day Land Surface Temperature"),
            Band(name="LST_Night_1km", description="Night Land Surface Temperature"),
            Band(name="Night_view_angl", description="View zenith angle of night observation"),
            Band(name="Night_view_time", description="Local time of night observation"),
            Band(name="QC_Day", description="Daytime LST Quality Indicators"),
            Band(name="QC_Night", description="Nighttime LST Quality indicators"),
        ]
    ),
    Product(
        product_id="MOD11A2.061",
        description="Land Surface Temperature & Emissivity (LST&E)",
        bands=[
            Band(name="Clear_sky_days", description="the days in clear-sky conditions and with validate LSTs"),
            Band(name="Clear_sky_nights", description="the nights in clear-sky conditions and with validate LSTs"),
            Band(name="Day_view_angl", description="View zenith angle of day observation"),
            Band(name="Day_view_time", description="Local time of day observation"),
            Band(name="Emis_31", description="Band 31 emissivity"),
            Band(name="Emis_32", description="Band 32 emissivity"),
            Band(name="LST_Day_1km", description="Day Land Surface Temperature"),
            Band(name="LST_Night_1km", description="Night Land Surface Temperature"),
            Band(name="Night_view_angl", description="View zenith angle of night observation"),
            Band(name="Night_view_time", description="Local time of night observation"),
            Band(name="QC_Day", description="Daytime LST Quality Indicators"),
            Band(name="QC_Night", description="Nighttime LST Quality indicators"),
        ]
    ),
    Product(
        product_id="MOD13A1.061",
        description="Vegetation Indices (NDVI & EVI)",
        bands=[
            Band(name="_500m_16_days_EVI", description="500m 16 days EVI"),
            Band(name="_500m_16_days_MIR_reflectance", description="500m 16 days MIR reflectance"),
            Band(name="_500m_16_days_NDVI", description="500m 16 days NDVI"),
            Band(name="_500m_16_days_NIR_reflectance", description="500m 16 days NIR reflectance"),
            Band(name="_500m_16_days_VI_Quality", description="500m 16 days VI Quality"),
            Band(name="_500m_16_days_blue_reflectance", description="500m 16 days blue reflectance"),
            Band(name="_500m_16_days_composite_day_of_the_year", description="500m 16 days composite day of the year"),
            Band(name="_500m_16_days_pixel_reliability", description="500m 16 days pixel reliability"),
            Band(name="_500m_16_days_red_reflectance", description="500m 16 days red reflectance"),
            Band(name="_500m_16_days_relative_azimuth_angle", description="500m 16 days relative azimuth angle"),
            Band(name="_500m_16_days_sun_zenith_angle", description="500m 16 days sun zenith angle"),
            Band(name="_500m_16_days_view_zenith_angle", description="500m 16 days view zenith angle"),
        ]
    ),
    Product(
        product_id="MOD13A2.061",
        description="Vegetation Indices (NDVI & EVI)",
        bands=[
            Band(name="_1_km_16_days_EVI", description="1 km 16 days EVI"),
            Band(name="_1_km_16_days_MIR_reflectance", description="1 km 16 days MIR reflectance"),
            Band(name="_1_km_16_days_NDVI", description="1 km 16 days NDVI"),
            Band(name="_1_km_16_days_NIR_reflectance", description="1 km 16 days NIR reflectance"),
            Band(name="_1_km_16_days_VI_Quality", description="1 km 16 days VI Quality"),
            Band(name="_1_km_16_days_blue_reflectance", description="1 km 16 days blue reflectance"),
            Band(name="_1_km_16_days_composite_day_of_the_year", description="1 km 16 days composite day of the year"),
            Band(name="_1_km_16_days_pixel_reliability", description="1 km 16 days pixel reliability"),
            Band(name="_1_km_16_days_red_reflectance", description="1 km 16 days red reflectance"),
            Band(name="_1_km_16_days_relative_azimuth_angle", description="1 km 16 days relative azimuth angle"),
            Band(name="_1_km_16_days_sun_zenith_angle", description="1 km 16 days sun zenith angle"),
            Band(name="_1_km_16_days_view_zenith_angle", description="1 km 16 days view zenith angle"),
        ]
    ),
    Product(
        product_id="MOD13A3.061",
        description="Vegetation Indices (NDVI & EVI)",
        bands=[
            Band(name="_1_km_monthly_EVI", description="1 km monthly EVI"),
            Band(name="_1_km_monthly_MIR_reflectance", description="1 km monthly MIR reflectance"),
            Band(name="_1_km_monthly_NDVI", description="1 km monthly NDVI"),
            Band(name="_1_km_monthly_NIR_reflectance", description="1 km monthly NIR reflectance"),
            Band(name="_1_km_monthly_VI_Quality", description="1 km monthly VI Quality"),
            Band(name="_1_km_monthly_blue_reflectance", description="1 km monthly blue reflectance"),
            Band(name="_1_km_monthly_pixel_reliability", description="1 km monthly pixel reliability"),
            Band(name="_1_km_monthly_red_reflectance", description="1 km monthly red reflectance"),
            Band(name="_1_km_monthly_relative_azimuth_angle", description="1 km monthly relative azimuth angle"),
            Band(name="_1_km_monthly_sun_zenith_angle", description="1 km monthly sun zenith angle"),
            Band(name="_1_km_monthly_view_zenith_angle", description="1 km monthly view zenith angle"),
        ]
    ),
    Product(
        product_id="MOD13Q1.061",
        description="Vegetation Indices (NDVI & EVI)",
        bands=[
            Band(name="_250m_16_days_EVI", description="16 day EVI average"),
            Band(name="_250m_16_days_MIR_reflectance", description="250m 16 days MIR reflectance"),
            Band(name="_250m_16_days_NDVI", description="16 day NDVI average"),
            Band(name="_250m_16_days_NIR_reflectance", description="250m 16 days NIR reflectance"),
            Band(name="_250m_16_days_VI_Quality", description="250m 16 days VI Quality"),
            Band(name="_250m_16_days_blue_reflectance", description="250m 16 days blue reflectance"),
            Band(name="_250m_16_days_composite_day_of_the_year", description="250m 16 days composite day of the year"),
            Band(name="_250m_16_days_pixel_reliability", description="250m 16 days pixel reliability"),
            Band(name="_250m_16_days_red_reflectance", description="250m 16 days red reflectance"),
            Band(name="_250m_16_days_relative_azimuth_angle", description="250m 16 days relative azimuth angle"),
            Band(name="_250m_16_days_sun_zenith_angle", description="250m 16 days sun zenith angle"),
            Band(name="_250m_16_days_view_zenith_angle", description="250m 16 days view zenith angle"),
        ]
    ),
    Product(
        product_id="MOD14A2.061",
        description="Thermal Anomalies and Fire",
        bands=[
            Band(name="FireMask", description="Confidence of fire"),
            Band(name="QA", description="Pixel Quality Indicators"),
        ]
    ),
    Product(
        product_id="MOD15A2H.061",
        description="Leaf Area Index (LAI) and Fraction of Photosynthetically Active Radiation (FPAR)",
        bands=[
            Band(name="FparExtra_QC", description="Extra detail Quality for Lai and Fpar"),
            Band(name="FparLai_QC", description="Quality for Lai and Fpar"),
            Band(name="FparStdDev_500m", description="Standard deviation of Fpar"),
            Band(name="Fpar_500m", description="Fraction of photosynthetically active radiation"),
            Band(name="LaiStdDev_500m", description="Standard deviation of Lai"),
            Band(name="Lai_500m", description="Leaf area index"),
        ]
    ),
    Product(
        product_id="MOD16A2.061",
        description="Evapotranspiration (ET & LE)",
        bands=[
            Band(name="ET_500m", description="Total Evapotranspiration"),
            Band(name="ET_QC_500m", description="Evapotranspiration Quality Control flags"),
            Band(name="LE_500m", description="Average Latent Heat Flux"),
            Band(name="PET_500m", description="Total Potential Evapotranspiration"),
            Band(name="PLE_500m", description="Average Potential Latent Heat Flux"),
        ]
    ),
    Product(
        product_id="MOD16A2GF.061",
        description="Net Evapotranspiration Gap-Filled (ET & LE)",
        bands=[
            Band(name="ET_500m", description="Total Evapotranspiration"),
            Band(name="ET_QC_500m", description="Evapotranspiration Quality Control flags"),
            Band(name="LE_500m", description="Average Latent Heat Flux"),
            Band(name="PET_500m", description="Total Potential Evapotranspiration"),
            Band(name="PLE_500m", description="Average Potential Latent Heat Flux"),
        ]
    ),
    Product(
        product_id="MOD16A3GF.061",
        description="Net Evapotranspiration Gap-Filled (ET & LE)",
        bands=[
            Band(name="ET_500m", description="Total of Evapotranspiration"),
            Band(name="ET_QC_500m", description="Evapotranspiration Quality Assessment"),
            Band(name="LE_500m", description="Average of Latent Heat Flux"),
            Band(name="PET_500m", description="Total Potential Evapotranspiration"),
            Band(name="PLE_500m", description="Average of Potential Latent Heat Flux"),
        ]
    ),
    Product(
        product_id="MOD17A2H.061",
        description="Gross Primary Productivity (GPP)",
        bands=[
            Band(name="Gpp_500m", description="Gross Primary Production"),
            Band(name="PsnNet_500m", description="Net Photosynthesis"),
            Band(name="Psn_QC_500m", description="Quality control indicators"),
        ]
    ),
    Product(
        product_id="MOD17A2HGF.061",
        description="Gross Primary Productivity (GPP)",
        bands=[
            Band(name="Gpp_500m", description="MODIS/Terra Gross Primary Production (GPP) 8-Day L4 Global 500m SIN Grid"),
            Band(name="PsnNet_500m", description="MODIS/Terra Net Photosynthesis (GPP - maint resp) 8-Day L4 Global 500m SIN Grid"),
            Band(name="Psn_QC_500m", description="Quality control Indicators"),
        ]
    ),
    Product(
        product_id="MOD17A3HGF.061",
        description="Net Primary Production (NPP) Gap-Filled",
        bands=[
            Band(name="Npp_500m", description="Net Primary Productivity"),
            Band(name="Npp_QC_500m", description="Quality Control Bits"),
        ]
    ),
    Product(
        product_id="MOD21A1D.061",
        description="Temperature and Emissivity (LST&E)",
        bands=[
            Band(name="Emis_29", description="Band 29 emissivity"),
            Band(name="Emis_31", description="Band 31 emissivity"),
            Band(name="Emis_32", description="Band 32 emissivity"),
            Band(name="LST_1KM", description="Land surface temperature"),
            Band(name="QC", description="Quality Control (QC)"),
            Band(name="View_Angle", description="MODIS view zenith angle"),
            Band(name="View_Time", description="Time of MODIS observation"),
        ]
    ),
    Product(
        product_id="MOD21A1N.061",
        description="Temperature and Emissivity (LST&E)",
        bands=[
            Band(name="Emis_29", description="Band 29 emissivity"),
            Band(name="Emis_31", description="Band 31 emissivity"),
            Band(name="Emis_32", description="Band 32 emissivity"),
            Band(name="LST_1KM", description="Land surface temperature"),
            Band(name="QC", description="Quality Control (QC)"),
            Band(name="View_Angle", description="MODIS view zenith angle"),
            Band(name="View_Time", description="Time of MODIS observation"),
        ]
    ),
    Product(
        product_id="MOD21A2.061",
        description="Temperature and Emissivity (LST&E)",
        bands=[
            Band(name="Emis_29", description="Band 29 emissivity"),
            Band(name="Emis_31", description="Band 31 emissivity"),
            Band(name="Emis_32", description="Band 32 emissivity"),
            Band(name="LST_Day_1KM", description="Land surface temperature"),
            Band(name="LST_Night_1KM", description="Night Land Surface Temperature"),
            Band(name="QC_Day", description="Quality Control (QC)"),
            Band(name="QC_Night", description="Night Quality Control (QC)"),
            Band(name="View_Angle_Day", description="MODIS view zenith angle"),
            Band(name="View_Angle_Night", description="Night view zenith angle"),
            Band(name="View_Time_Day", description="Time of MODIS observation"),
            Band(name="View_Time_Night", description="Time of Observation for night"),
        ]
    ),
    Product(
        product_id="MOD44B.061",
        description="Vegetation Continuous Fields (VCF)",
        bands=[
            Band(name="Cloud", description="Pixel cloud cover indicators"),
            Band(name="Percent_NonTree_Vegetation", description="Percent of pixel that is nontree vegetation"),
            Band(name="Percent_NonVegetated", description="Percent of pixel non vegetated"),
            Band(name="Percent_NonVegetated_SD", description="Standard deviation of percent not vegetated"),
            Band(name="Percent_Tree_Cover", description="Percent of pixel that is tree covered"),
            Band(name="Percent_Tree_Cover_SD", description="Standard deviation of percent tree covered"),
            Band(name="Quality", description="Quality Control indicators"),
        ]
    ),
    Product(
        product_id="MOD44W.061",
        description="Land/Water Mask",
        bands=[
            Band(name="seven_class", description="Water Body Classification Layer"),
            Band(name="water_mask", description="Land/Water Mask"),
            Band(name="water_mask_QA", description="Quality Assurance (QA)"),
        ]
    ),
    Product(
        product_id="MYD09A1.061",
        description="Surface Reflectance Bands 1-7",
        bands=[
            Band(name="sur_refl_b01", description="Surface Reflectance Band 1"),
            Band(name="sur_refl_b02", description="Surface Reflectance Band 2"),
            Band(name="sur_refl_b03", description="Surface Reflectance Band 3"),
            Band(name="sur_refl_b04", description="Surface Reflectance Band 4"),
            Band(name="sur_refl_b05", description="Surface Reflectance Band 5"),
            Band(name="sur_refl_b06", description="Surface Reflectance Band 6"),
            Band(name="sur_refl_b07", description="Surface Reflectance Band 7"),
            Band(name="sur_refl_day_of_year", description="Day of the year for the pixel"),
            Band(name="sur_refl_qc_500m", description="Surface reflectance 500m band quality control flags"),
            Band(name="sur_refl_raz", description="MODIS relative azimuth angle"),
            Band(name="sur_refl_state_500m", description="Surface eflectance 500m state flags"),
            Band(name="sur_refl_szen", description="MODIS solar zenith angle"),
            Band(name="sur_refl_vzen", description="MODIS view zenith angle"),
        ]
    ),
    Product(
        product_id="MYD09GA.061",
        description="Surface Reflectance Bands 1-7",
        bands=[
            Band(name="QC_500m_1", description="Surface Reflectance 500m Quality Assurance"),
            Band(name="Range_1", description="Distance to sensor"),
            Band(name="SensorAzimuth_1", description="Azimuth angle to sensor"),
            Band(name="SensorZenith_1", description="Zenith angle to sensor"),
            Band(name="SolarAzimuth_1", description="Solar azimuth"),
            Band(name="SolarZenith_1", description="Zenith angle to sun"),
            Band(name="gflags_1", description="Geolocation flags"),
            Band(name="granule_pnt_1", description="Granule Pointer"),
            Band(name="iobs_res_1", description="Observation number"),
            Band(name="num_observations_1km", description="Number of observations per 1K pixel"),
            Band(name="obscov_500m_1", description="Observation coverage"),
            Band(name="orbit_pnt_1", description="Orbit pointer"),
            Band(name="state_1km_1", description="1km Reflectance Data State QA"),
            Band(name="sur_refl_b01_1", description="Surface Reflectance Band 1"),
            Band(name="sur_refl_b02_1", description="Surface Reflectance Band 2"),
            Band(name="sur_refl_b03_1", description="Surface Reflectance Band 3"),
            Band(name="sur_refl_b04_1", description="Surface Reflectance Band 4"),
            Band(name="sur_refl_b05_1", description="Surface Reflectance Band 5"),
            Band(name="sur_refl_b06_1", description="Surface Reflectance Band 6"),
            Band(name="sur_refl_b07_1", description="Surface Reflectance Band 7"),
        ]
    ),
    Product(
        product_id="MYD09GQ.061",
        description="Surface Reflectance Bands 1-2",
        bands=[
            Band(name="QC_250m_1", description="Surface Reflectance 250m Quality Assurance"),
            Band(name="granule_pnt_1", description="Granule Pointer"),
            Band(name="iobs_res_1", description="Observation number"),
            Band(name="num_observations", description="Number of observations per 250m pixel"),
            Band(name="obscov_1", description="Observation coverage"),
            Band(name="orbit_pnt_1", description="Orbit pointer"),
            Band(name="sur_refl_b01_1", description="Surface Reflectance Band 1"),
            Band(name="sur_refl_b02_1", description="Surface Reflectance Band 2"),
        ]
    ),
    Product(
        product_id="MYD09Q1.061",
        description="Surface Reflectance Bands 1-2",
        bands=[
            Band(name="sur_refl_b01", description="Surface Reflectance Band 1"),
            Band(name="sur_refl_b02", description="Surface Reflectance Band 2"),
            Band(name="sur_refl_qc_250m", description="Surface Reflectance 250m Band Quality Control flags"),
            Band(name="sur_refl_state_250m", description="Surface_reflectance_250m_state_flags"),
        ]
    ),
    Product(
        product_id="MYD10A1.061",
        description="Snow Cover (NDSI)",
        bands=[
            Band(name="NDSI_Snow_Cover", description=""),
            Band(name="NDSI_Snow_Cover_Algorithm_Flags_QA", description=""),
            Band(name="NDSI_Snow_Cover_Basic_QA", description=""),
            Band(name="Snow_Albedo_Daily_Tile", description=""),
            Band(name="granule_pnt", description=""),
            Band(name="orbit_pnt", description=""),
        ]
    ),
    Product(
        product_id="MYD10A2.061",
        description="Snow Cover",
        bands=[
            Band(name="Eight_Day_Snow_Cover", description=""),
            Band(name="Maximum_Snow_Extent", description=""),
        ]
    ),
    Product(
        product_id="MYD11A1.061",
        description="Land Surface Temperature & Emissivity (LST&E)",
        bands=[
            Band(name="Clear_day_cov", description="Day clear-sky coverage"),
            Band(name="Clear_night_cov", description="Night clear-sky coverage"),
            Band(name="Day_view_angl", description="View zenith angle of day observation"),
            Band(name="Day_view_time", description="Local time of day observation"),
            Band(name="Emis_31", description="Band 31 emissivity"),
            Band(name="Emis_32", description="Band 32 emissivity"),
            Band(name="LST_Day_1km", description="Day Land Surface Temperature"),
            Band(name="LST_Night_1km", description="Night Land Surface Temperature"),
            Band(name="Night_view_angl", description="View zenith angle of night observation"),
            Band(name="Night_view_time", description="Local time of night observation"),
            Band(name="QC_Day", description="Daytime LST Quality Indicators"),
            Band(name="QC_Night", description="Nighttime LST Quality indicators"),
        ]
    ),
    Product(
        product_id="MYD11A2.061",
        description="Land Surface Temperature & Emissivity (LST&E)",
        bands=[
            Band(name="Clear_sky_days", description="the days in clear-sky conditions and with validate LSTs"),
            Band(name="Clear_sky_nights", description="the nights in clear-sky conditions and with validate LSTs"),
            Band(name="Day_view_angl", description="View zenith angle of day observation"),
            Band(name="Day_view_time", description="Local time of day observation"),
            Band(name="Emis_31", description="Band 31 emissivity"),
            Band(name="Emis_32", description="Band 32 emissivity"),
            Band(name="LST_Day_1km", description="Day Land Surface Temperature"),
            Band(name="LST_Night_1km", description="Night Land Surface Temperature"),
            Band(name="Night_view_angl", description="View zenith angle of night observation"),
            Band(name="Night_view_time", description="Local time of night observation"),
            Band(name="QC_Day", description="Daytime LST Quality Indicators"),
            Band(name="QC_Night", description="Nighttime LST Quality indicators"),
        ]
    ),
    Product(
        product_id="MYD13A1.061",
        description="Vegetation Indices (NDVI & EVI)",
        bands=[
            Band(name="_500m_16_days_EVI", description="500m 16 days EVI"),
            Band(name="_500m_16_days_MIR_reflectance", description="500m 16 days MIR reflectance"),
            Band(name="_500m_16_days_NDVI", description="500m 16 days NDVI"),
            Band(name="_500m_16_days_NIR_reflectance", description="500m 16 days NIR reflectance"),
            Band(name="_500m_16_days_VI_Quality", description="500m 16 days VI Quality"),
            Band(name="_500m_16_days_blue_reflectance", description="500m 16 days blue reflectance"),
            Band(name="_500m_16_days_composite_day_of_the_year", description="500m 16 days composite day of the year"),
            Band(name="_500m_16_days_pixel_reliability", description="500m 16 days pixel reliability"),
            Band(name="_500m_16_days_red_reflectance", description="500m 16 days red reflectance"),
            Band(name="_500m_16_days_relative_azimuth_angle", description="500m 16 days relative azimuth angle"),
            Band(name="_500m_16_days_sun_zenith_angle", description="500m 16 days sun zenith angle"),
            Band(name="_500m_16_days_view_zenith_angle", description="500m 16 days view zenith angle"),
        ]
    ),
    Product(
        product_id="MYD13A2.061",
        description="Vegetation Indices (NDVI & EVI)",
        bands=[
            Band(name="_1_km_16_days_EVI", description="1 km 16 days EVI"),
            Band(name="_1_km_16_days_MIR_reflectance", description="1 km 16 days MIR reflectance"),
            Band(name="_1_km_16_days_NDVI", description="1 km 16 days NDVI"),
            Band(name="_1_km_16_days_NIR_reflectance", description="1 km 16 days NIR reflectance"),
            Band(name="_1_km_16_days_VI_Quality", description="1 km 16 days VI Quality"),
            Band(name="_1_km_16_days_blue_reflectance", description="1 km 16 days blue reflectance"),
            Band(name="_1_km_16_days_composite_day_of_the_year", description="1 km 16 days composite day of the year"),
            Band(name="_1_km_16_days_pixel_reliability", description="1 km 16 days pixel reliability"),
            Band(name="_1_km_16_days_red_reflectance", description="1 km 16 days red reflectance"),
            Band(name="_1_km_16_days_relative_azimuth_angle", description="1 km 16 days relative azimuth angle"),
            Band(name="_1_km_16_days_sun_zenith_angle", description="1 km 16 days sun zenith angle"),
            Band(name="_1_km_16_days_view_zenith_angle", description="1 km 16 days view zenith angle"),
        ]
    ),
    Product(
        product_id="MYD13A3.061",
        description="Vegetation Indices (NDVI & EVI)",
        bands=[
            Band(name="_1_km_monthly_EVI", description="1 km monthly EVI"),
            Band(name="_1_km_monthly_MIR_reflectance", description="1 km monthly MIR reflectance"),
            Band(name="_1_km_monthly_NDVI", description="1 km monthly NDVI"),
            Band(name="_1_km_monthly_NIR_reflectance", description="1 km monthly NIR reflectance"),
            Band(name="_1_km_monthly_VI_Quality", description="1 km monthly VI Quality"),
            Band(name="_1_km_monthly_blue_reflectance", description="1 km monthly blue reflectance"),
            Band(name="_1_km_monthly_pixel_reliability", description="1 km monthly pixel reliability"),
            Band(name="_1_km_monthly_red_reflectance", description="1 km monthly red reflectance"),
            Band(name="_1_km_monthly_relative_azimuth_angle", description="1 km monthly relative azimuth angle"),
            Band(name="_1_km_monthly_sun_zenith_angle", description="1 km monthly sun zenith angle"),
            Band(name="_1_km_monthly_view_zenith_angle", description="1 km monthly view zenith angle"),
        ]
    ),
    Product(
        product_id="MYD13Q1.061",
        description="Vegetation Indices (NDVI & EVI)",
        bands=[
            Band(name="_250m_16_days_EVI", description="250m 16 days EVI"),
            Band(name="_250m_16_days_MIR_reflectance", description="250m 16 days MIR reflectance"),
            Band(name="_250m_16_days_NDVI", description="250m 16 days NDVI"),
            Band(name="_250m_16_days_NIR_reflectance", description="250m 16 days NIR reflectance"),
            Band(name="_250m_16_days_VI_Quality", description="250m 16 days VI Quality"),
            Band(name="_250m_16_days_blue_reflectance", description="250m 16 days blue reflectance"),
            Band(name="_250m_16_days_composite_day_of_the_year", description="250m 16 days composite day of the year"),
            Band(name="_250m_16_days_pixel_reliability", description="250m 16 days pixel reliability"),
            Band(name="_250m_16_days_red_reflectance", description="250m 16 days red reflectance"),
            Band(name="_250m_16_days_relative_azimuth_angle", description="250m 16 days relative azimuth angle"),
            Band(name="_250m_16_days_sun_zenith_angle", description="250m 16 days sun zenith angle"),
            Band(name="_250m_16_days_view_zenith_angle", description="250m 16 days view zenith angle"),
        ]
    ),
    Product(
        product_id="MYD14A2.061",
        description="Thermal Anomalies and Fire",
        bands=[
            Band(name="FireMask", description="Confidence of fire"),
            Band(name="QA", description="Pixel Quality Indicators"),
        ]
    ),
    Product(
        product_id="MYD15A2H.061",
        description="Leaf Area Index (LAI) and Fraction of Photosynthetically Active Radiation (FPAR)",
        bands=[
            Band(name="FparExtra_QC", description="Extra detail Quality for Lai and Fpar"),
            Band(name="FparLai_QC", description="Quality for Lai and Fpar"),
            Band(name="FparStdDev_500m", description="Standard deviation of Fpar"),
            Band(name="Fpar_500m", description="Fraction of photosynthetically active radiation"),
            Band(name="LaiStdDev_500m", description="Standard deviation of Lai"),
            Band(name="Lai_500m", description="Leaf area index"),
        ]
    ),
    Product(
        product_id="MYD16A2.061",
        description="Evapotranspiration (ET & LE)",
        bands=[
            Band(name="ET_500m", description="Total Evapotranspiration"),
            Band(name="ET_QC_500m", description="Evapotranspiration Quality Control flags"),
            Band(name="LE_500m", description="Average Latent Heat Flux"),
            Band(name="PET_500m", description="Total Potential Evapotranspiration"),
            Band(name="PLE_500m", description="Average Potential Latent Heat Flux"),
        ]
    ),
    Product(
        product_id="MYD16A2GF.061",
        description="Net Evapotranspiration Gap-Filled (ET & LE)",
        bands=[
            Band(name="ET_500m", description="Total Evapotranspiration"),
            Band(name="ET_QC_500m", description="Evapotranspiration Quality Control flags"),
            Band(name="LE_500m", description="Average Latent Heat Flux"),
            Band(name="PET_500m", description="Total Potential Evapotranspiration"),
            Band(name="PLE_500m", description="Average Potential Latent Heat Flux"),
        ]
    ),
    Product(
        product_id="MYD16A3GF.061",
        description="Net Evapotranspiration Gap-Filled (ET & LE)",
        bands=[
            Band(name="ET_500m", description="Total Evapotranspiration"),
            Band(name="ET_QC_500m", description="Evapotranspiration Quality Assessment"),
            Band(name="LE_500m", description="Average Latent Heat Flux"),
            Band(name="PET_500m", description="Total Potential Evapotranspiration"),
            Band(name="PLE_500m", description="Average Potential Latent Heat Flux"),
        ]
    ),
    Product(
        product_id="MYD17A2H.061",
        description="Gross Primary Productivity (GPP)",
        bands=[
            Band(name="Gpp_500m", description="Gross Primary Production"),
            Band(name="PsnNet_500m", description="Net Photosynthesis"),
            Band(name="Psn_QC_500m", description="Quality control indicators"),
        ]
    ),
    Product(
        product_id="MYD17A2HGF.061",
        description="Gross Primary Productivity (GPP) Gap-Filled",
        bands=[
            Band(name="Gpp_500m", description="Gross Primary Productivity"),
            Band(name="PsnNet_500m", description="Net Photosynthesis"),
            Band(name="Psn_QC_500m", description="Quality Control Indicators"),
        ]
    ),
    Product(
        product_id="MYD17A3HGF.061",
        description="Net Primary Production (NPP) Gap-Filled",
        bands=[
            Band(name="Npp_500m", description="Net Primary Productivity"),
            Band(name="Npp_QC_500m", description="Quality Control"),
        ]
    ),
    Product(
        product_id="MYD21A1D.061",
        description="Land Surface Temperature & Emissivity (LST&E)",
        bands=[
            Band(name="Emis_29", description="Band 29 emissivity"),
            Band(name="Emis_31", description="Band 31 emissivity"),
            Band(name="Emis_32", description="Band 32 emissivity"),
            Band(name="LST_1KM", description="Land surface temperature"),
            Band(name="QC", description="Quality Control (QC)"),
            Band(name="View_Angle", description="MODIS view zenith angle"),
            Band(name="View_Time", description="Time of MODIS observation"),
        ]
    ),
    Product(
        product_id="MYD21A1N.061",
        description="Land Surface Temperature & Emissivity (LST&E)",
        bands=[
            Band(name="Emis_29", description="Band 29 emissivity"),
            Band(name="Emis_31", description="Band 31 emissivity"),
            Band(name="Emis_32", description="Band 32 emissivity"),
            Band(name="LST_1KM", description="Land surface temperature"),
            Band(name="QC", description="Quality Control (QC)"),
            Band(name="View_Angle", description="MODIS view zenith angle"),
            Band(name="View_Time", description="Time of MODIS observation"),
        ]
    ),
    Product(
        product_id="MYD21A2.061",
        description="Land Surface Temperature & Emissivity (LST&E)",
        bands=[
            Band(name="Emis_29", description="Band 29 emissivity"),
            Band(name="Emis_31", description="Band 31 emissivity"),
            Band(name="Emis_32", description="Band 32 emissivity"),
            Band(name="LST_Day_1KM", description="Land surface temperature"),
            Band(name="LST_Night_1KM", description="Night Land Surface Temperature"),
            Band(name="QC_Day", description="Quality Control (QC)"),
            Band(name="QC_Night", description="Night Quality Control (QC)"),
            Band(name="View_Angle_Day", description="MODIS view zenith angle"),
            Band(name="View_Angle_Night", description="Night view zenith angle"),
            Band(name="View_Time_Day", description="Time of MODIS observation"),
            Band(name="View_Time_Night", description="Time of Observation for night"),
        ]
    ),
    Product(
        product_id="NASADEM_NC.001",
        description="Elevation",
        bands=[
            Band(name="NASADEM_HGT", description="Elevation"),
        ]
    ),
    Product(
        product_id="NASADEM_NUMNC.001",
        description="Source",
        bands=[
            Band(name="NASADEM_NUM", description="Number of Observations"),
        ]
    ),
    Product(
        product_id="SPL3SMP_E.005",
        description="Enhanced L3 Radiometer Soil Moisture",
        bands=[
            Band(name="Soil_Moisture_Retrieval_Data_AM_albedo", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-V within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_albedo_dca", description="Diffuse reflecting power of the Earth&apos;s surface used in DCA within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_albedo_scah", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-H within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_albedo_scav", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-V within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_boresight_incidence", description="Representative angle between the antenna boresight vector and the normal to the Earth&apos;s surface for all footprints within the cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_bulk_density", description="A unitless value that is indicative of aggregated bulk_density within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_clay_fraction", description="A unitless value that is indicative of aggregated clay fraction within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_freeze_thaw_fraction", description="Fraction of the 9 km grid cell that is denoted as frozen.  Based on binary flag that specifies freeze thaw conditions in each of the component 3 km grid cells."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_grid_surface_status", description="Indicates if the grid point lies on land (0) or water (1)."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_radar_water_body_fraction", description="The fraction of the area of the 9 km grid cell that is covered by water based on the radar detection algorithm."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_retrieval_qual_flag", description="Bit flags that record the conditions and the quality of the SCA-V retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_retrieval_qual_flag_dca", description="Bit flags that record the conditions and the quality of the DCA retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_retrieval_qual_flag_scah", description="Bit flags that record the conditions and the quality of the SCA-H retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_retrieval_qual_flag_scav", description="Bit flags that record the conditions and the quality of the SCA-V retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_roughness_coefficient", description="A unitless value that is indicative of bare soil roughness used in SCA-V within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_roughness_coefficient_dca", description="A unitless value that is indicative of bare soil roughness used in DCA within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_roughness_coefficient_scah", description="A unitless value that is indicative of bare soil roughness used in SCA-H within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_roughness_coefficient_scav", description="A unitless value that is indicative of bare soil roughness used in SCA-V within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_soil_moisture", description="Representative SCA-V soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_soil_moisture_dca", description="Representative DCA soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_soil_moisture_error", description="Net uncertainty measure of soil moisture measure for the Earth based grid cell. - Calculation method is TBD."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_soil_moisture_scah", description="Representative SCA-H soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_soil_moisture_scav", description="Representative SCA-V soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_static_water_body_fraction", description="The fraction of the area of the 9 km grid cell that is covered by static water based on a Digital Elevation Map."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_surface_flag", description="Bit flags that record ambient surface conditions for the grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_surface_temperature", description="Temperature at land surface based on GMAO GEOS-5 data."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_surface_water_fraction_mb_h", description="Gain weighted fraction of static water within the radiometer horizontal polarization brightness temperature antenna pattern in 36 km Earth grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_surface_water_fraction_mb_v", description="Gain weighted fraction of static water within the radiometer vertical polarization brightness temperature antenna pattern in 36 km Earth grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_3_corrected", description="Third stokes parameter for each 9 km grid cell calculated with an adjustment for the presence of water bodies"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_4_corrected", description="Fourth stokes parameter for each 9 km grid cell calculated with an adjustment for the presence of water bodies"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_h_corrected", description="Horizontal polarization brightness temperature in 9 km Earth grid cell adjusted for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_h_uncorrected", description="Horizontal polarization brightness temperature in 36 km Earth grid cell before adjustment for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_qual_flag_3", description="Bit flags that represent the quality of the 3rd Stokes brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_qual_flag_4", description="Bit flags that represent the quality of the 4th Stokes brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_qual_flag_h", description="Bit flags that represent the quality of the horizontal polarization brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_qual_flag_v", description="Bit flags that represent the quality of the vertical polarization brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_time_seconds", description="Arithmetic average of the acquisition time of all of the brightness temperature footprints with a center that falls within the EASE grid cell in seconds since noon on January 1, 2000 UTC."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_v_corrected", description="Vertical polarization brightness temperature in 9 km Earth grid cell adjusted for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_vegetation_opacity", description="The measured opacity of the vegetation used in the SCA-V retrieval in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_vegetation_opacity_dca", description="The measured opacity of the vegetation used in the DCA retrieval in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_vegetation_opacity_scah", description="The measured opacity of the vegetation used in the SCA-H retrieval in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_vegetation_opacity_scav", description="The measured opacity of the vegetation used in the SCA-V retrieval in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_vegetation_water_content", description="Representative measure of water in the vegetation within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_albedo_dca_pm", description="Diffuse reflecting power of the Earth&apos;s surface used in DCA retrievals within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_albedo_pm", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-V retrievals within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_albedo_scah_pm", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-H retrievals within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_albedo_scav_pm", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-V retrievals within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_boresight_incidence_pm", description="Representative angle between the antenna boresight vector and the normal to the Earth&apos;s surface for all footprints within the cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_bulk_density_pm", description="A unitless value that is indicative of aggregated bulk density within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_clay_fraction_pm", description="A unitless value that is indicative of aggregated clay fraction within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_freeze_thaw_fraction_pm", description="Fraction of the 9 km grid cell that is denoted as frozen.  Based on binary flag that specifies freeze thaw conditions in each of the component 3 km grid cells."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_grid_surface_status_pm", description="Indicates if the grid point lies on land (0) or water (1)."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_radar_water_body_fraction_pm", description="The fraction of the area of the 9 km grid cell that is covered by water based on the radar detection algorithm."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_retrieval_qual_flag_dca_pm", description="Bit flags that record the conditions and the quality of the DCA retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_retrieval_qual_flag_pm", description="Bit flags that record the conditions and the quality of the SCA-V retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_retrieval_qual_flag_scah_pm", description="Bit flags that record the conditions and the quality of the SCA-H retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_retrieval_qual_flag_scav_pm", description="Bit flags that record the conditions and the quality of the SCA-V retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_roughness_coefficient_dca_pm", description="A unitless value that is indicative of bare soil roughness used in DCA retrievals within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_roughness_coefficient_pm", description="A unitless value that is indicative of bare soil roughness used in SCA-V retrievals within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_roughness_coefficient_scah_pm", description="A unitless value that is indicative of bare soil roughness used in SCA-H retrievals within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_roughness_coefficient_scav_pm", description="A unitless value that is indicative of bare soil roughness used in SCA-V retrievals within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_soil_moisture_dca_pm", description="Representative DCA soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_soil_moisture_error_pm", description="Net uncertainty measure of soil moisture measure for the Earth based grid cell. - Calculation method is TBD."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_soil_moisture_pm", description="Representative SCA-V soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_soil_moisture_scah_pm", description="Representative SCA-H soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_soil_moisture_scav_pm", description="Representative SCA-V soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_static_water_body_fraction_pm", description="The fraction of the area of the 9 km grid cell that is covered by static water based on a Digital Elevation Map."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_surface_flag_pm", description="Bit flags that record ambient surface conditions for the grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_surface_temperature_pm", description="Temperature at land surface based on GMAO GEOS-5 data."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_surface_water_fraction_mb_h_pm", description="Gain weighted fraction of static water within the radiometer horizontal polarization brightness temperature antenna pattern in 36 km Earth grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_surface_water_fraction_mb_v_pm", description="Gain weighted fraction of static water within the radiometer vertical polarization brightness temperature antenna pattern in 36 km Earth grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_3_corrected_pm", description="Third stokes parameter for each 9 km grid cell calculated with an adjustment for the presence of water bodies"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_4_corrected_pm", description="Fourth stokes parameter for each 9 km grid cell calculated with an adjustment for the presence of water bodies"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_h_corrected_pm", description="Horizontal polarization brightness temperature in 9 km Earth grid cell adjusted for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_h_uncorrected_pm", description="Horizontal polarization brightness temperature in 36 km Earth grid cell before adjustment for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_qual_flag_3_pm", description="Bit flags that represent the quality of the 3rd Stokes brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_qual_flag_4_pm", description="Bit flags that represent the quality of the 4th Stokes brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_qual_flag_h_pm", description="Bit flags that represent the quality of the horizontal polarization brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_qual_flag_v_pm", description="Bit flags that represent the quality of the vertical polarization brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_time_seconds_pm", description="Arithmetic average of the acquisition time of all of the brightness temperature footprints with a center that falls within the EASE grid cell in seconds since noon on January 1, 2000 UTC."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_v_corrected_pm", description="Vertical polarization brightness temperature in 9 km Earth grid cell adjusted for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_vegetation_opacity_dca_pm", description="The measured opacity of the vegetation used in DCA retrievals in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_vegetation_opacity_pm", description="The measured opacity of the vegetation used in SCA-V retrievals in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_vegetation_opacity_scah_pm", description="The measured opacity of the vegetation used in SCA-H retrievals in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_vegetation_opacity_scav_pm", description="The measured opacity of the vegetation used in SCA-V retrievals in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_vegetation_water_content_pm", description="Representative measure of water in the vegetation within the 9 km grid cell."),
        ]
    ),
    Product(
        product_id="SPL3SMP_E.006",
        description="Enhanced L3 Radiometer Soil Moisture",
        bands=[
            Band(name="Soil_Moisture_Retrieval_Data_AM_albedo", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-V within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_albedo_dca", description="Diffuse reflecting power of the Earth&apos;s surface used in DCA within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_albedo_scah", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-H within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_albedo_scav", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-V within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_boresight_incidence", description="Representative angle between the antenna boresight vector and the normal to the Earth&apos;s surface for all footprints within the cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_bulk_density", description="A unitless value that is indicative of aggregated bulk_density within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_clay_fraction", description="A unitless value that is indicative of aggregated clay fraction within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_freeze_thaw_fraction", description="Fraction of the 9 km grid cell that is denoted as frozen.  Based on binary flag that specifies freeze thaw conditions in each of the component 3 km grid cells."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_grid_surface_status", description="Indicates if the grid point lies on land (0) or water (1)."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_radar_water_body_fraction", description="The fraction of the area of the 9 km grid cell that is covered by water based on the radar detection algorithm."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_retrieval_qual_flag", description="Bit flags that record the conditions and the quality of the SCA-V retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_retrieval_qual_flag_dca", description="Bit flags that record the conditions and the quality of the DCA retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_retrieval_qual_flag_scah", description="Bit flags that record the conditions and the quality of the SCA-H retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_retrieval_qual_flag_scav", description="Bit flags that record the conditions and the quality of the SCA-V retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_roughness_coefficient", description="A unitless value that is indicative of bare soil roughness used in SCA-V within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_roughness_coefficient_dca", description="A unitless value that is indicative of bare soil roughness used in DCA within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_roughness_coefficient_scah", description="A unitless value that is indicative of bare soil roughness used in SCA-H within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_roughness_coefficient_scav", description="A unitless value that is indicative of bare soil roughness used in SCA-V within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_soil_moisture", description="Representative SCA-V soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_soil_moisture_dca", description="Representative DCA soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_soil_moisture_error", description="Net uncertainty measure of soil moisture measure for the Earth based grid cell. - Calculation method is TBD."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_soil_moisture_scah", description="Representative SCA-H soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_soil_moisture_scav", description="Representative SCA-V soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_static_water_body_fraction", description="The fraction of the area of the 9 km grid cell that is covered by static water based on a Digital Elevation Map."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_surface_flag", description="Bit flags that record ambient surface conditions for the grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_surface_temperature", description="Temperature at land surface based on GMAO GEOS-5 data."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_surface_water_fraction_mb_h", description="Gain weighted fraction of static water within the radiometer horizontal polarization brightness temperature antenna pattern in 36 km Earth grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_surface_water_fraction_mb_v", description="Gain weighted fraction of static water within the radiometer vertical polarization brightness temperature antenna pattern in 36 km Earth grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_3_corrected", description="Third stokes parameter for each 9 km grid cell calculated with an adjustment for the presence of water bodies"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_4_corrected", description="Fourth stokes parameter for each 9 km grid cell calculated with an adjustment for the presence of water bodies"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_h_corrected", description="Horizontal polarization brightness temperature in 9 km Earth grid cell adjusted for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_h_uncorrected", description="Horizontal polarization brightness temperature in 36 km Earth grid cell before adjustment for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_qual_flag_3", description="Bit flags that represent the quality of the 3rd Stokes brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_qual_flag_4", description="Bit flags that represent the quality of the 4th Stokes brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_qual_flag_h", description="Bit flags that represent the quality of the horizontal polarization brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_qual_flag_v", description="Bit flags that represent the quality of the vertical polarization brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_time_seconds", description="Arithmetic average of the acquisition time of all of the brightness temperature footprints with a center that falls within the EASE grid cell in seconds since noon on January 1, 2000 UTC."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_v_corrected", description="Vertical polarization brightness temperature in 9 km Earth grid cell adjusted for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_vegetation_opacity", description="The measured opacity of the vegetation used in the SCA-V retrieval in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_vegetation_opacity_dca", description="The measured opacity of the vegetation used in the DCA retrieval in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_vegetation_opacity_scah", description="The measured opacity of the vegetation used in the SCA-H retrieval in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_vegetation_opacity_scav", description="The measured opacity of the vegetation used in the SCA-V retrieval in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_vegetation_water_content", description="Representative measure of water in the vegetation within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_albedo_dca_pm", description="Diffuse reflecting power of the Earth&apos;s surface used in DCA retrievals within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_albedo_pm", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-V retrievals within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_albedo_scah_pm", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-H retrievals within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_albedo_scav_pm", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-V retrievals within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_boresight_incidence_pm", description="Representative angle between the antenna boresight vector and the normal to the Earth&apos;s surface for all footprints within the cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_bulk_density_pm", description="A unitless value that is indicative of aggregated bulk density within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_clay_fraction_pm", description="A unitless value that is indicative of aggregated clay fraction within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_freeze_thaw_fraction_pm", description="Fraction of the 9 km grid cell that is denoted as frozen.  Based on binary flag that specifies freeze thaw conditions in each of the component 3 km grid cells."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_grid_surface_status_pm", description="Indicates if the grid point lies on land (0) or water (1)."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_radar_water_body_fraction_pm", description="The fraction of the area of the 9 km grid cell that is covered by water based on the radar detection algorithm."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_retrieval_qual_flag_dca_pm", description="Bit flags that record the conditions and the quality of the DCA retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_retrieval_qual_flag_pm", description="Bit flags that record the conditions and the quality of the SCA-V retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_retrieval_qual_flag_scah_pm", description="Bit flags that record the conditions and the quality of the SCA-H retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_retrieval_qual_flag_scav_pm", description="Bit flags that record the conditions and the quality of the SCA-V retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_roughness_coefficient_dca_pm", description="A unitless value that is indicative of bare soil roughness used in DCA retrievals within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_roughness_coefficient_pm", description="A unitless value that is indicative of bare soil roughness used in SCA-V retrievals within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_roughness_coefficient_scah_pm", description="A unitless value that is indicative of bare soil roughness used in SCA-H retrievals within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_roughness_coefficient_scav_pm", description="A unitless value that is indicative of bare soil roughness used in SCA-V retrievals within the 9 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_soil_moisture_dca_pm", description="Representative DCA soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_soil_moisture_error_pm", description="Net uncertainty measure of soil moisture measure for the Earth based grid cell. - Calculation method is TBD."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_soil_moisture_pm", description="Representative SCA-V soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_soil_moisture_scah_pm", description="Representative SCA-H soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_soil_moisture_scav_pm", description="Representative SCA-V soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_static_water_body_fraction_pm", description="The fraction of the area of the 9 km grid cell that is covered by static water based on a Digital Elevation Map."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_surface_flag_pm", description="Bit flags that record ambient surface conditions for the grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_surface_temperature_pm", description="Temperature at land surface based on GMAO GEOS-5 data."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_surface_water_fraction_mb_h_pm", description="Gain weighted fraction of static water within the radiometer horizontal polarization brightness temperature antenna pattern in 36 km Earth grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_surface_water_fraction_mb_v_pm", description="Gain weighted fraction of static water within the radiometer vertical polarization brightness temperature antenna pattern in 36 km Earth grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_3_corrected_pm", description="Third stokes parameter for each 9 km grid cell calculated with an adjustment for the presence of water bodies"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_4_corrected_pm", description="Fourth stokes parameter for each 9 km grid cell calculated with an adjustment for the presence of water bodies"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_h_corrected_pm", description="Horizontal polarization brightness temperature in 9 km Earth grid cell adjusted for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_h_uncorrected_pm", description="Horizontal polarization brightness temperature in 36 km Earth grid cell before adjustment for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_qual_flag_3_pm", description="Bit flags that represent the quality of the 3rd Stokes brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_qual_flag_4_pm", description="Bit flags that represent the quality of the 4th Stokes brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_qual_flag_h_pm", description="Bit flags that represent the quality of the horizontal polarization brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_qual_flag_v_pm", description="Bit flags that represent the quality of the vertical polarization brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_time_seconds_pm", description="Arithmetic average of the acquisition time of all of the brightness temperature footprints with a center that falls within the EASE grid cell in seconds since noon on January 1, 2000 UTC."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_v_corrected_pm", description="Vertical polarization brightness temperature in 9 km Earth grid cell adjusted for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_vegetation_opacity_dca_pm", description="The measured opacity of the vegetation used in DCA retrievals in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_vegetation_opacity_pm", description="The measured opacity of the vegetation used in SCA-V retrievals in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_vegetation_opacity_scah_pm", description="The measured opacity of the vegetation used in SCA-H retrievals in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_vegetation_opacity_scav_pm", description="The measured opacity of the vegetation used in SCA-V retrievals in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_vegetation_water_content_pm", description="Representative measure of water in the vegetation within the 9 km grid cell."),
        ]
    ),
    Product(
        product_id="SPL3SMP.008",
        description="Soil Moisture",
        bands=[
            Band(name="Soil_Moisture_Retrieval_Data_AM_albedo", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-V within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_albedo_dca", description="Diffuse reflecting power of the Earth&apos;s surface used in DCA within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_albedo_scah", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-H within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_albedo_scav", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-V within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_boresight_incidence", description="Representative angle between the antenna boresight vector and the normal to the Earth&apos;s surface for all footprints within the cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_bulk_density", description="A unitless value that is indicative of aggregated bulk_density within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_clay_fraction", description="A unitless value that is indicative of aggregated clay fraction within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_freeze_thaw_fraction", description="Fraction of the 36 km grid cell that is denoted as frozen.  Based on binary flag that specifies freeze thaw conditions in each of the component 3 km grid cells."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_grid_surface_status", description="Indicates if the grid point lies on land (0) or water (1)."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_landcover_class", description="An enumerated type that specifies the most common landcover class in the grid cell based on the IGBP landcover map. The array order is longitude (ascending), followed by latitude (descending), and followed by IGBP land cover type descending dominance (only the first three types are listed)"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_landcover_class_fraction", description="The fraction of the grid cell that contains the most common land cover in that area based on the IGBP landcover map."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_radar_water_body_fraction", description="The fraction of the area of the 36 km grid cell that is covered by water based on the radar detection algorithm."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_retrieval_qual_flag", description="Bit flags that record the conditions and the quality of the SCA-V retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_retrieval_qual_flag_dca", description="Bit flags that record the conditions and the quality of the DCA retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_retrieval_qual_flag_scah", description="Bit flags that record the conditions and the quality of the SCA-H retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_retrieval_qual_flag_scav", description="Bit flags that record the conditions and the quality of the SCA-V retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_roughness_coefficient", description="A unitless value that is indicative of bare soil roughness used in SCA-V within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_roughness_coefficient_dca", description="A unitless value that is indicative of bare soil roughness used in DCA within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_roughness_coefficient_scah", description="A unitless value that is indicative of bare soil roughness used in SCA-H within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_roughness_coefficient_scav", description="A unitless value that is indicative of bare soil roughness used in SCA-V within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_soil_moisture", description="Representative SCA-V soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_soil_moisture_dca", description="Representative DCA soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_soil_moisture_error", description="Net uncertainty measure of soil moisture measure for the Earth based grid cell. - Calculation method is TBD."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_soil_moisture_scah", description="Representative SCA-H soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_soil_moisture_scav", description="Representative SCA-V soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_static_water_body_fraction", description="The fraction of the area of the 36 km grid cell that is covered by static water based on a Digital Elevation Map."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_surface_flag", description="Bit flags that record ambient surface conditions for the grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_surface_temperature", description="Temperature at land surface based on GMAO GEOS-5 data."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_surface_water_fraction_mb_h", description="Gain weighted fraction of static water within the radiometer horizontal polarization brightness temperature antenna pattern in 36 km Earth grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_surface_water_fraction_mb_v", description="Gain weighted fraction of static water within the radiometer vertical polarization brightness temperature antenna pattern in 36 km Earth grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_3_corrected", description="Third stokes parameter for each 36 km grid cell calculated with an adjustment for the presence of water bodies"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_4_corrected", description="Fourth stokes parameter for each 36 km grid cell calculated with an adjustment for the presence of water bodies"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_h_corrected", description="Horizontal polarization brightness temperature in 36 km Earth grid cell adjusted for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_h_uncorrected", description="Horizontal polarization brightness temperature in 36 km Earth grid cell before adjustment for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_qual_flag_3", description="Bit flags that represent the quality of the 3rd Stokes brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_qual_flag_4", description="Bit flags that represent the quality of the 4th Stokes brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_qual_flag_h", description="Bit flags that represent the quality of the horizontal polarization brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_qual_flag_v", description="Bit flags that represent the quality of the vertical polarization brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_time_seconds", description="Arithmetic average of the acquisition time of all of the brightness temperature footprints with a center that falls within the EASE grid cell in seconds since noon on January 1, 2000 UTC."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_v_corrected", description="Vertical polarization brightness temperature in 36 km Earth grid cell adjusted for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_vegetation_opacity", description="The measured opacity of the vegetation used in the SCA-V retrieval in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_vegetation_opacity_dca", description="The measured opacity of the vegetation used in the DCA retrieval in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_vegetation_opacity_scah", description="The measured opacity of the vegetation used in the SCA-H retrieval in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_vegetation_opacity_scav", description="The measured opacity of the vegetation used in the SCA-V retrieval in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_vegetation_water_content", description="Representative measure of water in the vegetation within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_albedo_dca_pm", description="Diffuse reflecting power of the Earth&apos;s surface used in DCA retrievals within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_albedo_pm", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-V retrievals within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_albedo_scah_pm", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-H retrievals within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_albedo_scav_pm", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-V retrievals within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_boresight_incidence_pm", description="Representative angle between the antenna boresight vector and the normal to the Earth&apos;s surface for all footprints within the cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_bulk_density_pm", description="A unitless value that is indicative of aggregated bulk density within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_clay_fraction_pm", description="A unitless value that is indicative of aggregated clay fraction within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_freeze_thaw_fraction_pm", description="Fraction of the 36 km grid cell that is denoted as frozen.  Based on binary flag that specifies freeze thaw conditions in each of the component 3 km grid cells."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_grid_surface_status_pm", description="Indicates if the grid point lies on land (0) or water (1)."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_landcover_class_fraction_pm", description="The fraction of the grid cell that contains the most common land cover in that area based on the IGBP landcover map."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_landcover_class_pm", description="An enumerated type that specifies the most common landcover class in the grid cell based on the IGBP landcover map. The array order is longitude (ascending), followed by latitude (descending), and followed by IGBP land cover type descending dominance (only the first three types are listed)"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_radar_water_body_fraction_pm", description="The fraction of the area of the 36 km grid cell that is covered by water based on the radar detection algorithm."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_retrieval_qual_flag_dca_pm", description="Bit flags that record the conditions and the quality of the DCA retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_retrieval_qual_flag_pm", description="Bit flags that record the conditions and the quality of the SCA-V retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_retrieval_qual_flag_scah_pm", description="Bit flags that record the conditions and the quality of the SCA-H retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_retrieval_qual_flag_scav_pm", description="Bit flags that record the conditions and the quality of the SCA-V retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_roughness_coefficient_dca_pm", description="A unitless value that is indicative of bare soil roughness used in DCA retrievals within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_roughness_coefficient_pm", description="A unitless value that is indicative of bare soil roughness used in SCA-V retrievals within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_roughness_coefficient_scah_pm", description="A unitless value that is indicative of bare soil roughness used in SCA-H retrievals within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_roughness_coefficient_scav_pm", description="A unitless value that is indicative of bare soil roughness used in SCA-V retrievals within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_soil_moisture_dca_pm", description="Representative DCA soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_soil_moisture_error_pm", description="Net uncertainty measure of soil moisture measure for the Earth based grid cell. - Calculation method is TBD."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_soil_moisture_pm", description="Representative SCA-V soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_soil_moisture_scah_pm", description="Representative SCA-H soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_soil_moisture_scav_pm", description="Representative SCA-V soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_static_water_body_fraction_pm", description="The fraction of the area of the 36 km grid cell that is covered by static water based on a Digital Elevation Map."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_surface_flag_pm", description="Bit flags that record ambient surface conditions for the grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_surface_temperature_pm", description="Temperature at land surface based on GMAO GEOS-5 data."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_surface_water_fraction_mb_h_pm", description="Gain weighted fraction of static water within the radiometer horizontal polarization brightness temperature antenna pattern in 36 km Earth grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_surface_water_fraction_mb_v_pm", description="Gain weighted fraction of static water within the radiometer vertical polarization brightness temperature antenna pattern in 36 km Earth grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_3_corrected_pm", description="Third stokes parameter for each 36 km grid cell calculated with an adjustment for the presence of water bodies"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_4_corrected_pm", description="Fourth stokes parameter for each 36 km grid cell calculated with an adjustment for the presence of water bodies"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_h_corrected_pm", description="Horizontal polarization brightness temperature in 36 km Earth grid cell adjusted for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_h_uncorrected_pm", description="Horizontal polarization brightness temperature in 36 km Earth grid cell before adjustment for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_qual_flag_3_pm", description="Bit flags that represent the quality of the 3rd Stokes brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_qual_flag_4_pm", description="Bit flags that represent the quality of the 4th Stokes brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_qual_flag_h_pm", description="Bit flags that represent the quality of the horizontal polarization brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_qual_flag_v_pm", description="Bit flags that represent the quality of the vertical polarization brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_time_seconds_pm", description="Arithmetic average of the acquisition time of all of the brightness temperature footprints with a center that falls within the EASE grid cell in seconds since noon on January 1, 2000 UTC."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_v_corrected_pm", description="Vertical polarization brightness temperature in 36 km Earth grid cell adjusted for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_vegetation_opacity_dca_pm", description="The measured opacity of the vegetation used in DCA retrievals in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_vegetation_opacity_pm", description="The measured opacity of the vegetation used in SCA-V retrievals in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_vegetation_opacity_scah_pm", description="The measured opacity of the vegetation used in SCA-H retrievals in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_vegetation_opacity_scav_pm", description="The measured opacity of the vegetation used in SCA-V retrievals in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_vegetation_water_content_pm", description="Representative measure of water in the vegetation within the 36 km grid cell."),
        ]
    ),
    Product(
        product_id="SPL3SMP.009",
        description="Soil Moisture",
        bands=[
            Band(name="Soil_Moisture_Retrieval_Data_AM_albedo", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-V within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_albedo_dca", description="Diffuse reflecting power of the Earth&apos;s surface used in DCA within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_albedo_scah", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-H within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_albedo_scav", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-V within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_boresight_incidence", description="Representative angle between the antenna boresight vector and the normal to the Earth&apos;s surface for all footprints within the cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_bulk_density", description="A unitless value that is indicative of aggregated bulk_density within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_clay_fraction", description="A unitless value that is indicative of aggregated clay fraction within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_freeze_thaw_fraction", description="Fraction of the 36 km grid cell that is denoted as frozen.  Based on binary flag that specifies freeze thaw conditions in each of the component 3 km grid cells."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_grid_surface_status", description="Indicates if the grid point lies on land (0) or water (1)."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_landcover_class", description="An enumerated type that specifies the most common landcover class in the grid cell based on the IGBP landcover map. The array order is longitude (ascending), followed by latitude (descending), and followed by IGBP land cover type descending dominance (only the first three types are listed)"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_landcover_class_fraction", description="The fraction of the grid cell that contains the most common land cover in that area based on the IGBP landcover map."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_radar_water_body_fraction", description="The fraction of the area of the 36 km grid cell that is covered by water based on the radar detection algorithm."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_retrieval_qual_flag", description="Bit flags that record the conditions and the quality of the SCA-V retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_retrieval_qual_flag_dca", description="Bit flags that record the conditions and the quality of the DCA retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_retrieval_qual_flag_scah", description="Bit flags that record the conditions and the quality of the SCA-H retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_retrieval_qual_flag_scav", description="Bit flags that record the conditions and the quality of the SCA-V retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_roughness_coefficient", description="A unitless value that is indicative of bare soil roughness used in SCA-V within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_roughness_coefficient_dca", description="A unitless value that is indicative of bare soil roughness used in DCA within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_roughness_coefficient_scah", description="A unitless value that is indicative of bare soil roughness used in SCA-H within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_roughness_coefficient_scav", description="A unitless value that is indicative of bare soil roughness used in SCA-V within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_soil_moisture", description="Representative SCA-V soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_soil_moisture_dca", description="Representative DCA soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_soil_moisture_error", description="Net uncertainty measure of soil moisture measure for the Earth based grid cell. - Calculation method is TBD."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_soil_moisture_scah", description="Representative SCA-H soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_soil_moisture_scav", description="Representative SCA-V soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_static_water_body_fraction", description="The fraction of the area of the 36 km grid cell that is covered by static water based on a Digital Elevation Map."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_surface_flag", description="Bit flags that record ambient surface conditions for the grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_surface_temperature", description="Temperature at land surface based on GMAO GEOS-5 data."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_surface_water_fraction_mb_h", description="Gain weighted fraction of static water within the radiometer horizontal polarization brightness temperature antenna pattern in 36 km Earth grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_surface_water_fraction_mb_v", description="Gain weighted fraction of static water within the radiometer vertical polarization brightness temperature antenna pattern in 36 km Earth grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_3_corrected", description="Third stokes parameter for each 36 km grid cell calculated with an adjustment for the presence of water bodies"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_4_corrected", description="Fourth stokes parameter for each 36 km grid cell calculated with an adjustment for the presence of water bodies"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_h_corrected", description="Horizontal polarization brightness temperature in 36 km Earth grid cell adjusted for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_h_uncorrected", description="Horizontal polarization brightness temperature in 36 km Earth grid cell before adjustment for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_qual_flag_3", description="Bit flags that represent the quality of the 3rd Stokes brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_qual_flag_4", description="Bit flags that represent the quality of the 4th Stokes brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_qual_flag_h", description="Bit flags that represent the quality of the horizontal polarization brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_qual_flag_v", description="Bit flags that represent the quality of the vertical polarization brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_time_seconds", description="Arithmetic average of the acquisition time of all of the brightness temperature footprints with a center that falls within the EASE grid cell in seconds since noon on January 1, 2000 UTC."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_tb_v_corrected", description="Vertical polarization brightness temperature in 36 km Earth grid cell adjusted for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_vegetation_opacity", description="The measured opacity of the vegetation used in the SCA-V retrieval in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_vegetation_opacity_dca", description="The measured opacity of the vegetation used in the DCA retrieval in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_vegetation_opacity_scah", description="The measured opacity of the vegetation used in the SCA-H retrieval in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_vegetation_opacity_scav", description="The measured opacity of the vegetation used in the SCA-V retrieval in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_AM_vegetation_water_content", description="Representative measure of water in the vegetation within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_albedo_dca_pm", description="Diffuse reflecting power of the Earth&apos;s surface used in DCA retrievals within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_albedo_pm", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-V retrievals within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_albedo_scah_pm", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-H retrievals within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_albedo_scav_pm", description="Diffuse reflecting power of the Earth&apos;s surface used in SCA-V retrievals within the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_boresight_incidence_pm", description="Representative angle between the antenna boresight vector and the normal to the Earth&apos;s surface for all footprints within the cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_bulk_density_pm", description="A unitless value that is indicative of aggregated bulk density within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_clay_fraction_pm", description="A unitless value that is indicative of aggregated clay fraction within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_freeze_thaw_fraction_pm", description="Fraction of the 36 km grid cell that is denoted as frozen.  Based on binary flag that specifies freeze thaw conditions in each of the component 3 km grid cells."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_grid_surface_status_pm", description="Indicates if the grid point lies on land (0) or water (1)."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_landcover_class_fraction_pm", description="The fraction of the grid cell that contains the most common land cover in that area based on the IGBP landcover map."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_landcover_class_pm", description="An enumerated type that specifies the most common landcover class in the grid cell based on the IGBP landcover map. The array order is longitude (ascending), followed by latitude (descending), and followed by IGBP land cover type descending dominance (only the first three types are listed)"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_radar_water_body_fraction_pm", description="The fraction of the area of the 36 km grid cell that is covered by water based on the radar detection algorithm."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_retrieval_qual_flag_dca_pm", description="Bit flags that record the conditions and the quality of the DCA retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_retrieval_qual_flag_pm", description="Bit flags that record the conditions and the quality of the SCA-V retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_retrieval_qual_flag_scah_pm", description="Bit flags that record the conditions and the quality of the SCA-H retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_retrieval_qual_flag_scav_pm", description="Bit flags that record the conditions and the quality of the SCA-V retrieval algorithms that generate soil moisture for the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_roughness_coefficient_dca_pm", description="A unitless value that is indicative of bare soil roughness used in DCA retrievals within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_roughness_coefficient_pm", description="A unitless value that is indicative of bare soil roughness used in SCA-V retrievals within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_roughness_coefficient_scah_pm", description="A unitless value that is indicative of bare soil roughness used in SCA-H retrievals within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_roughness_coefficient_scav_pm", description="A unitless value that is indicative of bare soil roughness used in SCA-V retrievals within the 36 km grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_soil_moisture_dca_pm", description="Representative DCA soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_soil_moisture_error_pm", description="Net uncertainty measure of soil moisture measure for the Earth based grid cell. - Calculation method is TBD."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_soil_moisture_pm", description="Representative SCA-V soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_soil_moisture_scah_pm", description="Representative SCA-H soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_soil_moisture_scav_pm", description="Representative SCA-V soil moisture measurement for the Earth based grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_static_water_body_fraction_pm", description="The fraction of the area of the 36 km grid cell that is covered by static water based on a Digital Elevation Map."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_surface_flag_pm", description="Bit flags that record ambient surface conditions for the grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_surface_temperature_pm", description="Temperature at land surface based on GMAO GEOS-5 data."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_surface_water_fraction_mb_h_pm", description="Gain weighted fraction of static water within the radiometer horizontal polarization brightness temperature antenna pattern in 36 km Earth grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_surface_water_fraction_mb_v_pm", description="Gain weighted fraction of static water within the radiometer vertical polarization brightness temperature antenna pattern in 36 km Earth grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_3_corrected_pm", description="Third stokes parameter for each 36 km grid cell calculated with an adjustment for the presence of water bodies"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_4_corrected_pm", description="Fourth stokes parameter for each 36 km grid cell calculated with an adjustment for the presence of water bodies"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_h_corrected_pm", description="Horizontal polarization brightness temperature in 36 km Earth grid cell adjusted for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_h_uncorrected_pm", description="Horizontal polarization brightness temperature in 36 km Earth grid cell before adjustment for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_qual_flag_3_pm", description="Bit flags that represent the quality of the 3rd Stokes brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_qual_flag_4_pm", description="Bit flags that represent the quality of the 4th Stokes brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_qual_flag_h_pm", description="Bit flags that represent the quality of the horizontal polarization brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_qual_flag_v_pm", description="Bit flags that represent the quality of the vertical polarization brightness temperature within each grid cell"),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_time_seconds_pm", description="Arithmetic average of the acquisition time of all of the brightness temperature footprints with a center that falls within the EASE grid cell in seconds since noon on January 1, 2000 UTC."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_tb_v_corrected_pm", description="Vertical polarization brightness temperature in 36 km Earth grid cell adjusted for the presence of water bodies."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_vegetation_opacity_dca_pm", description="The measured opacity of the vegetation used in DCA retrievals in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_vegetation_opacity_pm", description="The measured opacity of the vegetation used in SCA-V retrievals in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_vegetation_opacity_scah_pm", description="The measured opacity of the vegetation used in SCA-H retrievals in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_vegetation_opacity_scav_pm", description="The measured opacity of the vegetation used in SCA-V retrievals in the grid cell."),
            Band(name="Soil_Moisture_Retrieval_Data_PM_vegetation_water_content_pm", description="Representative measure of water in the vegetation within the 36 km grid cell."),
        ]
    ),
    Product(
        product_id="SPL4CMDL.007",
        description="Carbon Net Ecosystem Exchange",
        bands=[
            Band(name="EC_emult_mean", description="Environmental-constraint multiplier."),
            Band(name="EC_frozen_area", description="Frozen area percentage (environmental-constraint)."),
            Band(name="EC_tmult_mean", description="Environmental-constraint on temperature."),
            Band(name="EC_wmult_mean", description="Environmental-constraint on moisture."),
            Band(name="GPP_gpp_mean", description="Global daily 9km Gross Primary Productivity (GPP) mean."),
            Band(name="GPP_gpp_pft1_mean", description="Global daily 9km Gross Primary Productivity (GPP) mean for PFT 1."),
            Band(name="GPP_gpp_pft2_mean", description="Global daily 9km Gross Primary Productivity (GPP) mean for PFT 2."),
            Band(name="GPP_gpp_pft3_mean", description="Global daily 9km Gross Primary Productivity (GPP) mean for PFT 3."),
            Band(name="GPP_gpp_pft4_mean", description="Global daily 9km Gross Primary Productivity (GPP) mean for PFT 4."),
            Band(name="GPP_gpp_pft5_mean", description="Global daily 9km Gross Primary Productivity (GPP) mean for PFT 5."),
            Band(name="GPP_gpp_pft6_mean", description="Global daily 9km Gross Primary Productivity (GPP) mean for PFT 6."),
            Band(name="GPP_gpp_pft7_mean", description="Global daily 9km Gross Primary Productivity (GPP) mean for PFT 7."),
            Band(name="GPP_gpp_pft8_mean", description="Global daily 9km Gross Primary Productivity (GPP) mean for PFT 8."),
            Band(name="GPP_gpp_std_dev", description="Global daily 9km Gross Primary Productivity (GPP) standard deviation."),
            Band(name="NEE_nee_mean", description="Global daily 9km Net Ecosystem Exchange (mean)."),
            Band(name="NEE_nee_pft1_mean", description="Global daily 9km Net ecosystem exchange mean for PFT 1."),
            Band(name="NEE_nee_pft2_mean", description="Global daily 9km Net ecosystem exchange mean for PFT 2."),
            Band(name="NEE_nee_pft3_mean", description="Global daily 9km Net ecosystem exchange mean for PFT 3."),
            Band(name="NEE_nee_pft4_mean", description="Global daily 9km Net ecosystem exchange mean for PFT 4."),
            Band(name="NEE_nee_pft5_mean", description="Global daily 9km Net ecosystem exchange mean for PFT 5."),
            Band(name="NEE_nee_pft6_mean", description="Global daily 9km Net ecosystem exchange mean for PFT 6."),
            Band(name="NEE_nee_pft7_mean", description="Global daily 9km Net ecosystem exchange mean for PFT 7."),
            Band(name="NEE_nee_pft8_mean", description="Global daily 9km Net ecosystem exchange mean for PFT 8."),
            Band(name="NEE_nee_std_dev", description="Global daily 9km Net Ecosystem Exchange standard deviation."),
            Band(name="QA_carbon_model_bitflag", description="carbon model quality bitflags."),
            Band(name="QA_nee_rmse_mean", description="NEE unbiased RMSE estimate (units: gCm^-2day^-1)"),
            Band(name="QA_nee_rmse_pft1_mean", description="NEE unbiased RMSE estimate (units: gCm^-2day^-1) for PFT 1"),
            Band(name="QA_nee_rmse_pft2_mean", description="NEE unbiased RMSE estimate (units: gCm^-2day^-1) for PFT 2"),
            Band(name="QA_nee_rmse_pft3_mean", description="NEE unbiased RMSE estimate (units: gCm^-2day^-1) for PFT 3"),
            Band(name="QA_nee_rmse_pft4_mean", description="NEE unbiased RMSE estimate (units: gCm^-2day^-1) for PFT 4"),
            Band(name="QA_nee_rmse_pft5_mean", description="NEE unbiased RMSE estimate (units: gCm^-2day^-1) for PFT 5"),
            Band(name="QA_nee_rmse_pft6_mean", description="NEE unbiased RMSE estimate (units: gCm^-2day^-1) for PFT 6"),
            Band(name="QA_nee_rmse_pft7_mean", description="NEE unbiased RMSE estimate (units: gCm^-2day^-1) for PFT 7"),
            Band(name="QA_nee_rmse_pft8_mean", description="NEE unbiased RMSE estimate (units: gCm^-2day^-1) for PFT 8"),
            Band(name="QA_qa_count", description="carbon model QA count 0 to 81 (overall)."),
            Band(name="QA_qa_count_pft1", description="QA count for PFT 1."),
            Band(name="QA_qa_count_pft2", description="QA count for PFT 2."),
            Band(name="QA_qa_count_pft3", description="QA count for PFT 3."),
            Band(name="QA_qa_count_pft4", description="QA count for PFT 4."),
            Band(name="QA_qa_count_pft5", description="QA count for PFT 5."),
            Band(name="QA_qa_count_pft6", description="QA count for PFT 6."),
            Band(name="QA_qa_count_pft7", description="QA count for PFT 7."),
            Band(name="QA_qa_count_pft8", description="QA count for PFT 8."),
            Band(name="RH_rh_mean", description="Global daily 9km heterotrophic respiration mean."),
            Band(name="RH_rh_pft1_mean", description="Global daily 9km heterotrophic respiration mean for PFT 1."),
            Band(name="RH_rh_pft2_mean", description="Global daily 9km heterotrophic respiration mean for PFT 2."),
            Band(name="RH_rh_pft3_mean", description="Global daily 9km heterotrophic respiration mean for PFT 3."),
            Band(name="RH_rh_pft4_mean", description="Global daily 9km heterotrophic respiration mean for PFT 4."),
            Band(name="RH_rh_pft5_mean", description="Global daily 9km heterotrophic respiration mean for PFT 5."),
            Band(name="RH_rh_pft6_mean", description="Global daily 9km heterotrophic respiration mean for PFT 6."),
            Band(name="RH_rh_pft7_mean", description="Global daily 9km heterotrophic respiration mean for PFT 7."),
            Band(name="RH_rh_pft8_mean", description="Global daily 9km heterotrophic respiration mean for PFT 8."),
            Band(name="RH_rh_std_dev", description="Global daily 9km heterotrophic respiration standard deviation."),
            Band(name="SOC_soc_mean", description="Global daily 9km soil organic carbon mean."),
            Band(name="SOC_soc_pft1_mean", description="Global daily 9km soil organic carbon mean for PFT"),
            Band(name="SOC_soc_pft2_mean", description="Global daily 9km soil organic carbon mean for PFT 2."),
            Band(name="SOC_soc_pft3_mean", description="Global daily 9km soil organic carbon mean for PFT 3."),
            Band(name="SOC_soc_pft4_mean", description="Global daily 9km soil organic carbon mean for PFT 4."),
            Band(name="SOC_soc_pft5_mean", description="Global daily 9km soil organic carbon mean for PFT 5."),
            Band(name="SOC_soc_pft6_mean", description="Global daily 9km soil organic carbon mean for PFT 6."),
            Band(name="SOC_soc_pft7_mean", description="Global daily 9km soil organic carbon mean for PFT 7."),
            Band(name="SOC_soc_pft8_mean", description="Global daily 9km soil organic carbon mean for PFT 8."),
            Band(name="SOC_soc_std_dev", description="Global daily 9km soil organic carbon standard deviation."),
        ]
    ),
    Product(
        product_id="SPL4SMGP.007",
        description="Surface and Root Zone Soil Moisture",
        bands=[
            Band(name="Geophysical_Data_baseflow_flux", description="Baseflow"),
            Band(name="Geophysical_Data_depth_to_water_table_from_surface_in_peat", description="Depth to water table from mean surface elevation in peatlands (positive above ground)"),
            Band(name="Geophysical_Data_free_surface_water_on_peat_flux", description="Change in free surface water storage on peatlands"),
            Band(name="Geophysical_Data_heat_flux_ground", description="Downward ground heat flux into layer 1 of soil heat diffusion model"),
            Band(name="Geophysical_Data_heat_flux_latent", description="Latent heat flux from land (excluding areas of open water and permanent ice)"),
            Band(name="Geophysical_Data_heat_flux_sensible", description="Sensible heat flux from land (excluding areas of open water and permanent ice)"),
            Band(name="Geophysical_Data_height_lowatmmodlay", description="Center height of lowest atmospheric model layer"),
            Band(name="Geophysical_Data_land_evapotranspiration_flux", description="Evapotranspiration from land (excluding areas of open water and permanent ice)"),
            Band(name="Geophysical_Data_land_fraction_saturated", description="Fractional land area that is saturated and snow-free (excluding areas of open water and permanent ice)"),
            Band(name="Geophysical_Data_land_fraction_snow_covered", description="Fractional land area that is snow-covered (excluding areas of open water and permanent ice)"),
            Band(name="Geophysical_Data_land_fraction_unsaturated", description="Fractional land area that is unsaturated (but non-wilting) and snow-free (excluding areas of open water and permanent ice)"),
            Band(name="Geophysical_Data_land_fraction_wilting", description="Fractional land area that is wilting and snow-free (excluding areas of open water and permanent ice)"),
            Band(name="Geophysical_Data_leaf_area_index", description="Vegetation leaf area index"),
            Band(name="Geophysical_Data_mwrtm_vegopacity", description="Microwave radiative transfer model: Vegetation opacity."),
            Band(name="Geophysical_Data_net_downward_longwave_flux", description="Net downward longwave flux over land (excluding areas of open water and permanent ice)"),
            Band(name="Geophysical_Data_net_downward_shortwave_flux", description="Net downward shortwave flux over land (excluding areas of open water and permanent ice)"),
            Band(name="Geophysical_Data_overland_runoff_flux", description="Overland (surface) runoff (including throughflow - excluding areas of open water and permanent ice)"),
            Band(name="Geophysical_Data_precipitation_total_surface_flux", description="Total surface precipitation (incl. snow fall)"),
            Band(name="Geophysical_Data_radiation_longwave_absorbed_flux", description="Absorbed (downward) longwave radiation at the surface"),
            Band(name="Geophysical_Data_radiation_shortwave_downward_flux", description="Downward shortwave flux incident on the surface"),
            Band(name="Geophysical_Data_sm_profile", description="Total profile soil moisture (0 cm to model bedrock depth)"),
            Band(name="Geophysical_Data_sm_profile_pctl", description="Total profile soil moisture (0 cm to model bedrock depth; percentile units)"),
            Band(name="Geophysical_Data_sm_profile_wetness", description="Total profile soil wetness (0 cm to model bedrock depth; wetness units). Soil wetness units (dimensionless) vary between 0 and 1, indicating relative saturation between completely dry conditions and completely saturated conditions, respectively.  See also Appendix E in the PSD."),
            Band(name="Geophysical_Data_sm_rootzone", description="Root zone soil moisture (0-100 cm)"),
            Band(name="Geophysical_Data_sm_rootzone_pctl", description="Root zone soil moisture (0-100 cm; percentile units)"),
            Band(name="Geophysical_Data_sm_rootzone_wetness", description="Root zone soil wetness (0-100 cm; wetness units). Soil wetness units (dimensionless) vary between 0 and 1, indicating relative saturation between completely dry conditions and completely saturated conditions, respectively.  See also Appendix E in the PSD."),
            Band(name="Geophysical_Data_sm_surface", description="Top layer soil moisture (0-5 cm)"),
            Band(name="Geophysical_Data_sm_surface_wetness", description="Top layer soil wetness (0-5 cm; wetness units). Soil wetness units (dimensionless) vary between 0 and 1, indicating relative saturation between completely dry conditions and completely saturated conditions, respectively.  See also Appendix E in the PSD."),
            Band(name="Geophysical_Data_snow_depth", description="Snow depth within snow-covered land fraction of grid cell (excluding areas of open water and permanent ice)"),
            Band(name="Geophysical_Data_snow_mass", description="Average snow mass (or snow water equivalent) over land fraction of grid cell (excluding areas of open water and permanent ice)"),
            Band(name="Geophysical_Data_snow_melt_flux", description="Snowmelt (excluding areas of open water and permanent ice)"),
            Band(name="Geophysical_Data_snowfall_surface_flux", description="Surface snow fall"),
            Band(name="Geophysical_Data_soil_temp_layer1", description="Soil temperature in layer 1 of soil heat diffusion model"),
            Band(name="Geophysical_Data_soil_temp_layer2", description="Soil temperature in layer 2 of soil heat diffusion model"),
            Band(name="Geophysical_Data_soil_temp_layer3", description="Soil temperature in layer 3 of soil heat diffusion model"),
            Band(name="Geophysical_Data_soil_temp_layer4", description="Soil temperature in layer 4 of soil heat diffusion model"),
            Band(name="Geophysical_Data_soil_temp_layer5", description="Soil temperature in layer 5 of soil heat diffusion model"),
            Band(name="Geophysical_Data_soil_temp_layer6", description="Soil temperature in layer 6 of soil heat diffusion model"),
            Band(name="Geophysical_Data_soil_water_infiltration_flux", description="Soil water infiltration rate"),
            Band(name="Geophysical_Data_specific_humidity_lowatmmodlay", description="Air specific humidity at center height of lowest atmospheric model layer"),
            Band(name="Geophysical_Data_surface_pressure", description="Surface pressure"),
            Band(name="Geophysical_Data_surface_temp", description="Mean land surface temperature (incl. snow-covered land area). Excluding areas of open water and permanent ice."),
            Band(name="Geophysical_Data_temp_lowatmmodlay", description="Air temperature at center height of lowest atmospheric model layer"),
            Band(name="Geophysical_Data_vegetation_greenness_fraction", description="Vegetation \"greenness\" or fraction of transpiring leaves averaged over the land area (excluding areas of open water and permanent ice) of the grid cell"),
            Band(name="Geophysical_Data_windspeed_lowatmmodlay", description="Surface wind speed at center height of lowest atmospheric model layer"),
        ]
    ),
    Product(
        product_id="SPL3FTP.003",
        description="Freeze/Thaw State",
        bands=[
            Band(name="Freeze_Thaw_Retrieval_Data_Global_EASE_column_index", description="The column index of the 36 km EASE grid cell that contains the associated data. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_EASE_row_index", description="The row index of the 36 km EASE grid cell that contains the associated data. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_FT_SCV_threshold", description="Threshold for the SCV algorithm based on reference V-pol TB to differentiate between freeze and thaw conditions. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_altitude_dem", description="The Earth surface elevation within the grid cell. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_altitude_std_dev", description="The standard deviation of the Earth surface elevation within the grid cell.  This element provides a surface roughness measure. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_data_sampling_density", description="Total number of radiometer data samples in the grid cell.  The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_freeze_reference", description="Reference normalized polarization ratio value used as a basis to indicate frozen conditions. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_freeze_thaw", description="Boolean that indicates whether soil within cell is frozen or thawed.  A value of 0 implies thawed conditions, a value of 1 implies frozen. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_freeze_thaw_time_seconds", description="Time of the freeze-thaw determination for this particular element in seconds from the standard epoch. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_landcover_class", description="An enumerated type that specifies the predominant surface vegetation found in the grid cell. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_normalized_polarization_ratio", description="Normalized Tb polarization ratio at the Earth based grid cell, defined as (TBH-TBV)/(TBH+TBV). The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_open_water_body_fraction", description="Fraction of the area of the grid cell surface covered by open water.  Open water areas do not have vegetation at or on the water surface. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_reference_image_threshold", description="Threshold based on reference freeze and thaw to differentiate between freeze and thaw conditions. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_retrieval_algorithm_flag", description="Boolean that indicates whether the NPR change detection algorithm or the single-channel V-pol threshold algorithm was used to retrieve freeze-thaw state.  A value of 0 indicates the NPR algorithm, a value of 1 indicates the SCV algorithm. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_retrieval_qual_flag", description="Sequence of bit flags that indicate the conditions and the quality of the freeze-thaw retrieval. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_surface_flag", description="Bit flags that record ambient surface conditions for the grid cell"),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_tbh_error", description="Overall error measure for H-pol brightness temperature within the grid cell, includes calibration, RFI and contamination effects. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_tbh_mean", description="Mean of H-pol brightness temperature in the 36 km Earth grid cell. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_tbh_qual_flag", description="Bit flags that represent the quality of the horizontal polarization brightness temperature within each grid cell"),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_tbv_error", description="Overall error measure for V-pol brightness temperature within the grid cell, includes calibration, RFI and contamination effects. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_tbv_mean", description="Mean of V-pol brightness temperature in the 36 km Earth grid cell. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_tbv_qual_flag", description="Bit flags that represent the quality of the vertical polarization brightness temperature within each grid cell"),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_thaw_reference", description="Reference normalized polarization ratio value used as a basis to indicate thawed conditions. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_transition_direction", description="Boolean that indicates transitional direction.  0 indicates AM frozen, PM thawed, 1 indicates AM thawed, PM frozen. Value is always zero if not in transition state."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_transition_state_flag", description="Boolean that indicates whether soil is in transitional state from AM to PM on the same day.  0 indicates state is not in transition, 1 indicates state is in transition."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_EASE_column_index", description="The column index of the 36 km EASE grid cell that contains the associated data. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_EASE_row_index", description="The row index of the 36 km EASE grid cell that contains the associated data. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_FT_SCV_threshold", description="Threshold for the SCV algorithm based on reference V-pol TB to differentiate between freeze and thaw conditions. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_altitude_dem", description="The Earth surface elevation within the grid cell. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_altitude_std_dev", description="The standard deviation of the Earth surface elevation within the grid cell.  This element provides a surface roughness measure. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_data_sampling_density", description="Total number of radiometer data samples in the grid cell.  The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_freeze_reference", description="Reference normalized polarization ratio value used as a basis to indicate frozen conditions. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_freeze_thaw", description="Boolean that indicates whether soil within cell is frozen or thawed.  A value of 0 implies thawed conditions, a value of 1 implies frozen. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_freeze_thaw_time_seconds", description="Time of the freeze-thaw determination for this particular element in seconds from the standard epoch. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_landcover_class", description="An enumerated type that specifies the predominant surface vegetation found in the grid cell. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_normalized_polarization_ratio", description="Normalized Tb polarization ratio at the Earth based grid cell, defined as (TBH-TBV)/(TBH+TBV). The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_open_water_body_fraction", description="Fraction of the area of the grid cell surface covered by open water.  Open water areas do not have vegetation at or on the water surface. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_reference_image_threshold", description="Threshold based on reference freeze and thaw to differentiate between freeze and thaw conditions. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_retrieval_algorithm_flag", description="Boolean that indicates whether the NPR change detection algorithm or the single-channel V-pol threshold algorithm was used to retrieve freeze-thaw state.  A value of 0 indicates the NPR algorithm, a value of 1 indicates the SCV algorithm. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_retrieval_qual_flag", description="Sequence of bit flags that indicate the conditions and the quality of the freeze-thaw retrieval. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_surface_flag", description="Bit flags that record ambient surface conditions for the grid cell"),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_tbh_error", description="Overall error measure for H-pol brightness temperature within the grid cell, includes calibration, RFI and contamination effects. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_tbh_mean", description="Mean of H-pol brightness temperature in the 36 km Earth grid cell. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_tbh_qual_flag", description="Bit flags that represent the quality of the horizontal polarization brightness temperature within each grid cell"),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_tbv_error", description="Overall error measure for V-pol brightness temperature within the grid cell, includes calibration, RFI and contamination effects. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_tbv_mean", description="Mean of V-pol brightness temperature in the 36 km Earth grid cell. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_tbv_qual_flag", description="Bit flags that represent the quality of the vertical polarization brightness temperature within each grid cell"),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_thaw_reference", description="Reference normalized polarization ratio value used as a basis to indicate thawed conditions. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_transition_direction", description="Boolean that indicates transitional direction.  0 indicates AM frozen, PM thawed, 1 indicates AM thawed, PM frozen. Value is always zero if not in transition state."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_transition_state_flag", description="Boolean that indicates whether soil is in transitional state from AM to PM on the same day.  0 indicates state is not in transition, 1 indicates state is in transition."),
        ]
    ),
    Product(
        product_id="SPL3FTP.004",
        description="Freeze/Thaw State",
        bands=[
            Band(name="Freeze_Thaw_Retrieval_Data_Global_EASE_column_index", description="The column index of the 36 km EASE grid cell that contains the associated data. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_EASE_row_index", description="The row index of the 36 km EASE grid cell that contains the associated data. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_FT_SCV_threshold", description="Threshold for the SCV algorithm based on reference V-pol TB to differentiate between freeze and thaw conditions. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_altitude_dem", description="The Earth surface elevation within the grid cell. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_altitude_std_dev", description="The standard deviation of the Earth surface elevation within the grid cell.  This element provides a surface roughness measure. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_data_sampling_density", description="Total number of radiometer data samples in the grid cell.  The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_freeze_reference", description="Reference normalized polarization ratio value used as a basis to indicate frozen conditions. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_freeze_thaw", description="Boolean that indicates whether soil within cell is frozen or thawed.  A value of 0 implies thawed conditions, a value of 1 implies frozen. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_freeze_thaw_time_seconds", description="Time of the freeze-thaw determination for this particular element in seconds from the standard epoch. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_landcover_class", description="An enumerated type that specifies the predominant surface vegetation found in the grid cell. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_normalized_polarization_ratio", description="Normalized Tb polarization ratio at the Earth based grid cell, defined as (TBH-TBV)/(TBH+TBV). The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_open_water_body_fraction", description="Fraction of the area of the grid cell surface covered by open water.  Open water areas do not have vegetation at or on the water surface. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_reference_image_threshold", description="Threshold based on reference freeze and thaw to differentiate between freeze and thaw conditions. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_retrieval_algorithm_flag", description="Boolean that indicates whether the NPR change detection algorithm or the single-channel V-pol threshold algorithm was used to retrieve freeze-thaw state.  A value of 0 indicates the NPR algorithm, a value of 1 indicates the SCV algorithm. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_retrieval_qual_flag", description="Sequence of bit flags that indicate the conditions and the quality of the freeze-thaw retrieval. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_surface_flag", description="Bit flags that record ambient surface conditions for the grid cell"),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_tbh_error", description="Overall error measure for H-pol brightness temperature within the grid cell, includes calibration, RFI and contamination effects. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_tbh_mean", description="Mean of H-pol brightness temperature in the 36 km Earth grid cell. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_tbh_qual_flag", description="Bit flags that represent the quality of the horizontal polarization brightness temperature within each grid cell"),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_tbv_error", description="Overall error measure for V-pol brightness temperature within the grid cell, includes calibration, RFI and contamination effects. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_tbv_mean", description="Mean of V-pol brightness temperature in the 36 km Earth grid cell. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_tbv_qual_flag", description="Bit flags that represent the quality of the vertical polarization brightness temperature within each grid cell"),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_thaw_reference", description="Reference normalized polarization ratio value used as a basis to indicate thawed conditions. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_transition_direction", description="Boolean that indicates transitional direction.  0 indicates AM frozen, PM thawed, 1 indicates AM thawed, PM frozen. Value is always zero if not in transition state."),
            Band(name="Freeze_Thaw_Retrieval_Data_Global_transition_state_flag", description="Boolean that indicates whether soil is in transitional state from AM to PM on the same day.  0 indicates state is not in transition, 1 indicates state is in transition."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_EASE_column_index", description="The column index of the 36 km EASE grid cell that contains the associated data. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_EASE_row_index", description="The row index of the 36 km EASE grid cell that contains the associated data. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_FT_SCV_threshold", description="Threshold for the SCV algorithm based on reference V-pol TB to differentiate between freeze and thaw conditions. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_altitude_dem", description="The Earth surface elevation within the grid cell. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_altitude_std_dev", description="The standard deviation of the Earth surface elevation within the grid cell.  This element provides a surface roughness measure. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_data_sampling_density", description="Total number of radiometer data samples in the grid cell.  The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_freeze_reference", description="Reference normalized polarization ratio value used as a basis to indicate frozen conditions. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_freeze_thaw", description="Boolean that indicates whether soil within cell is frozen or thawed.  A value of 0 implies thawed conditions, a value of 1 implies frozen. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_freeze_thaw_time_seconds", description="Time of the freeze-thaw determination for this particular element in seconds from the standard epoch. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_landcover_class", description="An enumerated type that specifies the predominant surface vegetation found in the grid cell. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_normalized_polarization_ratio", description="Normalized Tb polarization ratio at the Earth based grid cell, defined as (TBH-TBV)/(TBH+TBV). The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_open_water_body_fraction", description="Fraction of the area of the grid cell surface covered by open water.  Open water areas do not have vegetation at or on the water surface. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_reference_image_threshold", description="Threshold based on reference freeze and thaw to differentiate between freeze and thaw conditions. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_retrieval_algorithm_flag", description="Boolean that indicates whether the NPR change detection algorithm or the single-channel V-pol threshold algorithm was used to retrieve freeze-thaw state.  A value of 0 indicates the NPR algorithm, a value of 1 indicates the SCV algorithm. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_retrieval_qual_flag", description="Sequence of bit flags that indicate the conditions and the quality of the freeze-thaw retrieval. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_surface_flag", description="Bit flags that record ambient surface conditions for the grid cell"),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_tbh_error", description="Overall error measure for H-pol brightness temperature within the grid cell, includes calibration, RFI and contamination effects. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_tbh_mean", description="Mean of H-pol brightness temperature in the 36 km Earth grid cell. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_tbh_qual_flag", description="Bit flags that represent the quality of the horizontal polarization brightness temperature within each grid cell"),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_tbv_error", description="Overall error measure for V-pol brightness temperature within the grid cell, includes calibration, RFI and contamination effects. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_tbv_mean", description="Mean of V-pol brightness temperature in the 36 km Earth grid cell. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_tbv_qual_flag", description="Bit flags that represent the quality of the vertical polarization brightness temperature within each grid cell"),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_thaw_reference", description="Reference normalized polarization ratio value used as a basis to indicate thawed conditions. The AM (dimension AMPM=0) and PM (AMPM=1) observations are stored separately in the array."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_transition_direction", description="Boolean that indicates transitional direction.  0 indicates AM frozen, PM thawed, 1 indicates AM thawed, PM frozen. Value is always zero if not in transition state."),
            Band(name="Freeze_Thaw_Retrieval_Data_Polar_transition_state_flag", description="Boolean that indicates whether soil is in transitional state from AM to PM on the same day.  0 indicates state is not in transition, 1 indicates state is in transition."),
        ]
    ),
    Product(
        product_id="SRTMGL1_NC.003",
        description="Elevation (DEM)",
        bands=[
            Band(name="SRTMGL1_DEM", description="Elevation"),
        ]
    ),
    Product(
        product_id="SRTMGL1_NUMNC.003",
        description="Source (DEM)",
        bands=[
            Band(name="SRTMGL1_NUM", description="Quality Assurance"),
        ]
    ),
    Product(
        product_id="SRTMGL3_NC.003",
        description="Elevation (DEM)",
        bands=[
            Band(name="SRTMGL3_DEM", description="Elevation"),
        ]
    ),
    Product(
        product_id="SRTMGL3_NUMNC.003",
        description="Source (DEM)",
        bands=[
            Band(name="SRTMGL3_NUM", description="Quality Assurance"),
        ]
    ),
    Product(
        product_id="ASTGTM_NC.003",
        description="Elevation",
        bands=[
            Band(name="ASTER_GDEM_DEM", description="Digital Elevation Model"),
        ]
    ),
    Product(
        product_id="ASTGTM_NUMNC.003",
        description="Source",
        bands=[
            Band(name="ASTER_GDEM_NUM", description="Number of DEM tiles and sources"),
        ]
    ),
    Product(
        product_id="ASTWBD_ATTNC.001",
        description="Water Bodies Database Attributes",
        bands=[
            Band(name="ASTWBD_att", description="ASTER Water Body Database - Attributes"),
        ]
    ),
    Product(
        product_id="ASTWBD_NC.001",
        description="Water Bodies Database Elevation",
        bands=[
            Band(name="ASTWBD_dem", description="ASTER Water Body Database - Digital Elevation Model"),
        ]
    ),
    Product(
        product_id="VNP09H1.001",
        description="Surface Reflectance",
        bands=[
            Band(name="SurfReflect_I1", description="Surface_reflectance_for_band_I1"),
            Band(name="SurfReflect_I2", description="Surface_reflectance_for_band_I2"),
            Band(name="SurfReflect_I3", description="Surface_reflectance_for_band_I3"),
            Band(name="SurfReflect_QC_500m", description="Surface_reflectance_250m_quality_control_flags"),
            Band(name="SurfReflect_State_500m", description="Surface_reflectance_250m_state_flags"),
        ]
    ),
    Product(
        product_id="VNP09A1.001",
        description="Surface Reflectance",
        bands=[
            Band(name="RelativeAzimuth", description="Relative_azimuth"),
            Band(name="SensorZenith", description="View_zenith"),
            Band(name="SolarZenith", description="Solar_zenith"),
            Band(name="SurfReflect_Day_Of_Year", description="Surface_reflectance_day_of_year"),
            Band(name="SurfReflect_M1", description="Surface_reflectance_for_band_M1"),
            Band(name="SurfReflect_M10", description="Surface_reflectance_for_band_M10"),
            Band(name="SurfReflect_M11", description="Surface_reflectance_for_band_M11"),
            Band(name="SurfReflect_M2", description="Surface_reflectance_for_band_M2"),
            Band(name="SurfReflect_M3", description="Surface_reflectance_for_band_M3"),
            Band(name="SurfReflect_M4", description="Surface_reflectance_for_band_M4"),
            Band(name="SurfReflect_M5", description="Surface_reflectance_for_band_M5"),
            Band(name="SurfReflect_M7", description="Surface_reflectance_for_band_M7"),
            Band(name="SurfReflect_M8", description="Surface_reflectance_for_band_M8"),
            Band(name="SurfReflect_QC", description="Surface_reflectance_500m_quality_control_flags"),
            Band(name="SurfReflect_State", description="Surface_reflectance_500m_state_flags"),
        ]
    ),
    Product(
        product_id="VNP09GA.001",
        description="Surface Reflectance",
        bands=[
            Band(name="VNP_Grid_1km_2D_SensorAzimuth_1", description="Sensor azimuth"),
            Band(name="VNP_Grid_1km_2D_SensorZenith_1", description="Sensor zenith"),
            Band(name="VNP_Grid_1km_2D_SolarAzimuth_1", description="Solar azimuth"),
            Band(name="VNP_Grid_1km_2D_SolarZenith_1", description="Solar zenith"),
            Band(name="VNP_Grid_1km_2D_SurfReflect_M10_1", description="Moderate (750m) Surface Reflectance Band 10"),
            Band(name="VNP_Grid_1km_2D_SurfReflect_M11_1", description="Moderate (750m) Surface Reflectance Band 11"),
            Band(name="VNP_Grid_1km_2D_SurfReflect_M1_1", description="Moderate (750m) Surface Reflectance Band 1"),
            Band(name="VNP_Grid_1km_2D_SurfReflect_M2_1", description="Moderate (750m) Surface Reflectance Band 2"),
            Band(name="VNP_Grid_1km_2D_SurfReflect_M3_1", description="Moderate (750m) Surface Reflectance Band 3"),
            Band(name="VNP_Grid_1km_2D_SurfReflect_M4_1", description="Moderate (750m) Surface Reflectance Band 4"),
            Band(name="VNP_Grid_1km_2D_SurfReflect_M5_1", description="Moderate (750m) Surface Reflectance Band 5"),
            Band(name="VNP_Grid_1km_2D_SurfReflect_M7_1", description="Moderate (750m) Surface Reflectance Band 7"),
            Band(name="VNP_Grid_1km_2D_SurfReflect_M8_1", description="Moderate (750m) Surface Reflectance Band 8"),
            Band(name="VNP_Grid_1km_2D_SurfReflect_QF1_1", description="Moderate (750m) Land Quality Flags Byte 1"),
            Band(name="VNP_Grid_1km_2D_SurfReflect_QF2_1", description="Moderate (750m) Land Quality Flags Byte 2"),
            Band(name="VNP_Grid_1km_2D_SurfReflect_QF3_1", description="Moderate (750m) Land Quality Flags Byte 3"),
            Band(name="VNP_Grid_1km_2D_SurfReflect_QF4_1", description="Moderate (750m) Land Quality Flags Byte 4"),
            Band(name="VNP_Grid_1km_2D_SurfReflect_QF5_1", description="Moderate (750m) Land Quality Flags Byte 5"),
            Band(name="VNP_Grid_1km_2D_SurfReflect_QF6_1", description="Moderate (750m) Land Quality Flags Byte 6"),
            Band(name="VNP_Grid_1km_2D_SurfReflect_QF7_1", description="Moderate (750m) Land Quality Flags Byte 7"),
            Band(name="VNP_Grid_1km_2D_num_observations_1km", description="Number of Observations"),
            Band(name="VNP_Grid_1km_2D_obscov_1km_1", description="Observation coverage"),
            Band(name="VNP_Grid_1km_2D_orbit_pnt_1", description="Orbit pointer"),
            Band(name="VNP_Grid_500m_2D_SurfReflect_I1_1", description="Imagery (375m) Surface Reflectance Band 1"),
            Band(name="VNP_Grid_500m_2D_SurfReflect_I2_1", description="Imagery (375m) Surface Reflectance Band 2"),
            Band(name="VNP_Grid_500m_2D_SurfReflect_I3_1", description="Imagery (375m) Surface Reflectance Band 3"),
            Band(name="VNP_Grid_500m_2D_iobs_res_1", description="observation number in coarser grid"),
            Band(name="VNP_Grid_500m_2D_num_observations_500m", description="Number of Observations"),
            Band(name="VNP_Grid_500m_2D_obscov_500m_1", description="Observation coverage"),
        ]
    ),
    Product(
        product_id="VNP13A1.001",
        description="Vegetation Indices (NDVI & EVI)",
        bands=[
            Band(name="_500_m_16_days_EVI", description="3 band Enhanced Vegetation Index"),
            Band(name="_500_m_16_days_EVI2", description="2 band Enhanced Vegetation Index"),
            Band(name="_500_m_16_days_NDVI", description="Normalized Difference Vegetation Index"),
            Band(name="_500_m_16_days_NIR_reflectance", description="Near-infrared Radiation reflectance (846-885 nm)"),
            Band(name="_500_m_16_days_SWIR1_reflectance", description="Shortwave Infrared Radiation reflectance (1230-1250 nm)"),
            Band(name="_500_m_16_days_SWIR2_reflectance", description="Shortwave Infrared Radiation reflectance (1580-1640 nm)"),
            Band(name="_500_m_16_days_SWIR3_reflectance", description="Shortwave Infrared Radiation reflectance (2225-2275 nm)"),
            Band(name="_500_m_16_days_VI_Quality", description="Bit field that assigns each pixel a Quality Assessment (QA) attribute"),
            Band(name="_500_m_16_days_blue_reflectance", description="Blue band reflectance (478-498 nm)"),
            Band(name="_500_m_16_days_composite_day_of_the_year", description="Day of year for the pixel"),
            Band(name="_500_m_16_days_green_reflectance", description="Green band reflectance (545-565 nm)"),
            Band(name="_500_m_16_days_pixel_reliability", description="500 m 16 days pixel reliability"),
            Band(name="_500_m_16_days_red_reflectance", description="Red band reflectance (600-680 nm)"),
            Band(name="_500_m_16_days_relative_azimuth_angle", description="Relative azimuth angle for each pixel"),
            Band(name="_500_m_16_days_sun_zenith_angle", description="Sun zenith angle for each pixel"),
            Band(name="_500_m_16_days_view_zenith_angle", description="500 m 16 days view zenith angle"),
        ]
    ),
    Product(
        product_id="VNP13A2.001",
        description="Vegetation Indices (NDVI & EVI)",
        bands=[
            Band(name="_1_km_16_days_EVI", description="3 band Enhanced Vegetation Index"),
            Band(name="_1_km_16_days_EVI2", description="2 band Enhanced Vegetation Index"),
            Band(name="_1_km_16_days_NDVI", description="Normalized Difference Vegetation Index"),
            Band(name="_1_km_16_days_NIR_reflectance", description="Near-infrared Radiation reflectance (846-885 nm)"),
            Band(name="_1_km_16_days_SWIR1_reflectance", description="Shortwave Infrared Radiation reflectance (1230-1250 nm)"),
            Band(name="_1_km_16_days_SWIR2_reflectance", description="Shortwave Infrared Radiation reflectance (1580-1640 nm)"),
            Band(name="_1_km_16_days_SWIR3_reflectance", description="Shortwave Infrared Radiation reflectance (2225-2275 nm)"),
            Band(name="_1_km_16_days_VI_Quality", description="Bit field that assigns each pixel a Quality Assessment (QA) attribute"),
            Band(name="_1_km_16_days_blue_reflectance", description="Blue band reflectance (478-498 nm)"),
            Band(name="_1_km_16_days_composite_day_of_the_year", description="Day of year for the pixel"),
            Band(name="_1_km_16_days_green_reflectance", description="Green band reflectance (545-565 nm)"),
            Band(name="_1_km_16_days_pixel_reliability", description="1 km 16 days pixel reliability"),
            Band(name="_1_km_16_days_red_reflectance", description="Red band reflectance (600-680 nm)"),
            Band(name="_1_km_16_days_relative_azimuth_angle", description="Relative azimuth angle for each pixel"),
            Band(name="_1_km_16_days_sun_zenith_angle", description="Sun zenith angle for each pixel"),
            Band(name="_1_km_16_days_view_zenith_angle", description="View zenith angle for each pixel"),
        ]
    ),
    Product(
        product_id="VNP13A3.001",
        description="Vegetation Indices (NDVI & EVI)",
        bands=[
            Band(name="_1_km_monthly_EVI", description="3 band Enhanced Vegetation Index"),
            Band(name="_1_km_monthly_EVI2", description="2 band Enhanced Vegetation Index"),
            Band(name="_1_km_monthly_NDVI", description="Normalized Difference Vegetation Index"),
            Band(name="_1_km_monthly_NIR_reflectance", description="Near-infrared Radiation reflectance (846-885 nm)"),
            Band(name="_1_km_monthly_SWIR1_reflectance", description="Shortwave Infrared Radiation reflectance (1230-1250 nm)"),
            Band(name="_1_km_monthly_SWIR2_reflectance", description="Shortwave Infrared Radiation reflectance (1580-1640 nm)"),
            Band(name="_1_km_monthly_SWIR3_reflectance", description="Shortwave Infrared Radiation reflectance (2225-2275 nm)"),
            Band(name="_1_km_monthly_VI_Quality", description="Bit field that assigns each pixel a Quality Assessment (QA) attribute"),
            Band(name="_1_km_monthly_blue_reflectance", description="Blue band reflectance (478-498 nm)"),
            Band(name="_1_km_monthly_green_reflectance", description="1 km monthly green reflectance"),
            Band(name="_1_km_monthly_pixel_reliability", description="1 km monthly pixel reliability"),
            Band(name="_1_km_monthly_red_reflectance", description="Red band reflectance (600-680 nm)"),
            Band(name="_1_km_monthly_relative_azimuth_angle", description="Relative azimuth angle for each pixel"),
            Band(name="_1_km_monthly_sun_zenith_angle", description="Sun zenith angle for each pixel"),
            Band(name="_1_km_monthly_view_zenith_angle", description="1 km monthly view zenith angle"),
        ]
    ),
    Product(
        product_id="VNP14A1.001",
        description="Thermal Anomalies/Fire",
        bands=[
            Band(name="FireMask", description="Confidence of fire"),
            Band(name="MaxFRP", description="Maximum Fire Radiative Power"),
            Band(name="QA", description="Pixel Quality Indicators"),
            Band(name="sample", description="Position of a fire pixel within scan"),
        ]
    ),
    Product(
        product_id="VNP15A2H.001",
        description="Leaf Area Index (LAI) and Fraction of Photosynthetically Active Radiation (FPAR)",
        bands=[
            Band(name="Fpar", description="Fraction of Photosynthetically Active Radiation"),
            Band(name="FparExtra_QC", description="Pass-through Quality Control (QC) for FPAR"),
            Band(name="FparLai_QC", description="Quality for LAI and FPAR"),
            Band(name="FparStdDev", description="Standard deviation of FPAR"),
            Band(name="Lai", description="Leaf Area Index"),
            Band(name="LaiStdDev", description="Standard deviation for LAI"),
        ]
    ),
    Product(
        product_id="VNP21A1D.001",
        description="Land Surface Temperature & Emissivity Day (LST&E)",
        bands=[
            Band(name="Emis_14", description="DailyM14 emissivity"),
            Band(name="Emis_15", description="DailyM15 emissivity"),
            Band(name="Emis_16", description="DailyM16 emissivity"),
            Band(name="LST_1KM", description="Daily 1 km Land Surface Temperature"),
            Band(name="QC", description="DailyQuality control for LST and emissivity"),
            Band(name="View_Angle", description="View zenith angle of LST"),
            Band(name="View_Time", description="Time of LST observation"),
        ]
    ),
    Product(
        product_id="VNP21A1N.001",
        description="Land Surface Temperature & Emissivity Night (LST&E)",
        bands=[
            Band(name="Emis_14", description="DailyM14 emissivity"),
            Band(name="Emis_15", description="DailyM15 emissivity"),
            Band(name="Emis_16", description="DailyM16 emissivity"),
            Band(name="LST_1KM", description="Daily 1 km Land Surface Temperature"),
            Band(name="QC", description="DailyQuality control for LST and emissivity"),
            Band(name="View_Angle", description="View zenith angle of LST"),
            Band(name="View_Time", description="Time of LST observation"),
        ]
    ),
    Product(
        product_id="VNP21A2.001",
        description="Land Surface Temperature & Emissivity (LST&E)",
        bands=[
            Band(name="Emis_14", description="M14 emissivity"),
            Band(name="Emis_15", description="M15 emissivity"),
            Band(name="Emis_16", description="M16 emissivity"),
            Band(name="LST_Day_1KM", description="Day Land Surface Temperature"),
            Band(name="LST_Night_1KM", description="Night 1 km Land Surface Temperature"),
            Band(name="QC_Day", description="Day Quality control for LST and emissivity"),
            Band(name="QC_Night", description="Night Quality control for LST and emissivity"),
            Band(name="View_Angle_Day", description="Day View zenith angle of LST"),
            Band(name="View_Angle_Night", description="Night View zenith angle of LST"),
            Band(name="View_Time_Day", description="Day Time of LST observation"),
            Band(name="View_Time_Night", description="Night Time of LST observation"),
        ]
    ),
    Product(
        product_id="VNP22Q2.001",
        description="Global Land Surface Phenology (GLSP)",
        bands=[
            Band(name="Cycle_1_Date_Mid_Greenup_Phase_1", description="Date at a mid-greenup phase in Cycle 1"),
            Band(name="Cycle_1_Date_Mid_Senescence_Phase_1", description="Date at a mid-senescence phase in Cycle 1"),
            Band(name="Cycle_1_EVI2_Growing_Season_Area_1", description="Integrated EVI2 during a growing season in Cycle 1"),
            Band(name="Cycle_1_EVI2_Onset_Greenness_Increase_1", description="EVI2 value at greenup onset in Cycle 1"),
            Band(name="Cycle_1_EVI2_Onset_Greenness_Maximum_1", description="EVI2 value at maturity onset in Cycle 1"),
            Band(name="Cycle_1_GLSP_QC_1", description="Global Land Surface Phenology Quality Control in Cycle 1"),
            Band(name="Cycle_1_Greenness_Agreement_Growing_Season_1", description="EVI2 agreement between modeled values and raw observations in Cycle 1"),
            Band(name="Cycle_1_Growing_Season_Length_1", description="Growing Season Length in Cycle 1"),
            Band(name="Cycle_1_Onset_Greenness_Decrease_1", description="Date at which canopy greenness begins to decrease in Cycle 1"),
            Band(name="Cycle_1_Onset_Greenness_Increase_1", description="Date of onset of greenness increase in Cycle 1"),
            Band(name="Cycle_1_Onset_Greenness_Maximum_1", description="Date at which canopy greenness approaches its seasonal maximum in Cycle 1"),
            Band(name="Cycle_1_Onset_Greenness_Minimum_1", description="Date at which canopy greenness reaches a minimum in Cycle 1"),
            Band(name="Cycle_1_PGQ_Growing_Season_1", description="Proportion of good quality of VIIRS observations during a vegetation growing season in Cycle 1"),
            Band(name="Cycle_1_PGQ_Onset_Greenness_Decrease_1", description="Proportion of good quality around senescence onset in Cycle 1"),
            Band(name="Cycle_1_PGQ_Onset_Greenness_Increase_1", description="Proportion of good quality around greenup onset in Cycle 1"),
            Band(name="Cycle_1_PGQ_Onset_Greenness_Maximum_1", description="Proportion of good quality around maturity onset in Cycle 1"),
            Band(name="Cycle_1_PGQ_Onset_Greenness_Minimum_1", description="Proportion of good quality around dormancy onset in Cycle 1"),
            Band(name="Cycle_1_Rate_Greenness_Decrease_1", description="Rates of change in EVI2 values during a senescence phase in Cycle 1"),
            Band(name="Cycle_1_Rate_Greenness_Increase_1", description="Rates of change in EVI2 values during a greenup phase in Cycle 1"),
            Band(name="Cycle_2_Date_Mid_Greenup_Phase_2", description="Date at a mid-greenup phase in Cycle 2"),
            Band(name="Cycle_2_Date_Mid_Senescence_Phase_2", description="Date at a mid-senescence phase in Cycle 2"),
            Band(name="Cycle_2_EVI2_Growing_Season_Area_2", description="Integrated EVI2 during a growing season in Cycle 2"),
            Band(name="Cycle_2_EVI2_Onset_Greenness_Increase_2", description="EVI2 value at greenup onset in Cycle 2"),
            Band(name="Cycle_2_EVI2_Onset_Greenness_Maximum_2", description="EVI2 value at maturity onset in Cycle 2"),
            Band(name="Cycle_2_GLSP_QC_2", description="Global Land Surface Phenology Quality Control in Cycle 2"),
            Band(name="Cycle_2_Greenness_Agreement_Growing_Season_2", description="EVI2 agreement between modeled values and raw observations in Cycle 2"),
            Band(name="Cycle_2_Growing_Season_Length_2", description="Growing Season Length in Cycle 2"),
            Band(name="Cycle_2_Onset_Greenness_Decrease_2", description="Date at which canopy greenness begins to decrease in Cycle 2"),
            Band(name="Cycle_2_Onset_Greenness_Increase_2", description="Date of onset of greenness increase in Cycle 2"),
            Band(name="Cycle_2_Onset_Greenness_Maximum_2", description="Date at which canopy greenness approaches its seasonal maximum in Cycle 2"),
            Band(name="Cycle_2_Onset_Greenness_Minimum_2", description="Date at which canopy greenness reaches a minimum in Cycle 2"),
            Band(name="Cycle_2_PGQ_Growing_Season_2", description="Proportion of good quality of VIIRS observations during a vegetation growing season in Cycle 2"),
            Band(name="Cycle_2_PGQ_Onset_Greenness_Decrease_2", description="Proportion of good quality around senescence onset in Cycle 2"),
            Band(name="Cycle_2_PGQ_Onset_Greenness_Increase_2", description="Proportion of good quality around greenup onset in Cycle 2"),
            Band(name="Cycle_2_PGQ_Onset_Greenness_Maximum_2", description="Proportion of good quality around maturity onset in Cycle 2"),
            Band(name="Cycle_2_PGQ_Onset_Greenness_Minimum_2", description="Proportion of good quality around dormancy onset in Cycle 2"),
            Band(name="Cycle_2_Rate_Greenness_Decrease_2", description="Rates of change in EVI2 values during a senescence phase in Cycle 2"),
            Band(name="Cycle_2_Rate_Greenness_Increase_2", description="Rates of change in EVI2 values during a greenup phase in Cycle 2"),
        ]
    ),
    Product(
        product_id="VNP43IA1.001",
        description="BRDF-Albedo Model Parameters",
        bands=[
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_I1", description="BRDF/Albedo mandatory quality for band I1"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_I2", description="BRDF/Albedo mandatory quality for band I2"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_I3", description="BRDF/Albedo mandatory quality for band I3"),
            Band(name="BRDF_Albedo_Parameters_I1", description="Multi-dimensional layer for band I1 of parameters: fiso, fvol, and fgeo"),
            Band(name="BRDF_Albedo_Parameters_I2", description="Multi-dimensional layer for band I2 of parameters: fiso, fvol, and fgeo"),
            Band(name="BRDF_Albedo_Parameters_I3", description="Multi-dimensional layer for band I3 of parameters: fiso, fvol, and fgeo"),
        ]
    ),
    Product(
        product_id="VNP43IA2.001",
        description="BRDF-Albedo Quality",
        bands=[
            Band(name="BRDF_Albedo_Band_Quality_I1", description="BRDF inversion information"),
            Band(name="BRDF_Albedo_Band_Quality_I2", description="BRDF inversion information"),
            Band(name="BRDF_Albedo_Band_Quality_I3", description="BRDF inversion information"),
            Band(name="BRDF_Albedo_LandWaterType", description="Land/Water type"),
            Band(name="BRDF_Albedo_LocalSolarNoon", description="Solar zenith angle at local solar noon"),
            Band(name="BRDF_Albedo_Platform", description="Platform name"),
            Band(name="BRDF_Albedo_Uncertainty", description="Weight of Determination (WoD) of WSA"),
            Band(name="BRDF_Albedo_ValidObs_I1", description="Days of valid observation within 16-day period for band I1"),
            Band(name="BRDF_Albedo_ValidObs_I2", description="Days of valid observation within 16-day period for band I2"),
            Band(name="BRDF_Albedo_ValidObs_I3", description="Days of valid observation within 16-day period for band I3"),
            Band(name="Snow_BRDF_Albedo", description="Snow flag"),
        ]
    ),
    Product(
        product_id="VNP43IA3.001",
        description="Albedo (BRDF)",
        bands=[
            Band(name="Albedo_BSA_I1", description="BSA (at local solar noon) for band I1"),
            Band(name="Albedo_BSA_I2", description="BSA (at local solar noon) for band I2"),
            Band(name="Albedo_BSA_I3", description="BSA (at local solar noon) for band I3"),
            Band(name="Albedo_WSA_I1", description="WSA for band I1"),
            Band(name="Albedo_WSA_I2", description="WSA for band I2"),
            Band(name="Albedo_WSA_I3", description="WSA for band I3"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_I1", description="BRDF/Albedo mandatory quality band for I1"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_I2", description="BRDF/Albedo mandatory quality band for I2"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_I3", description="BRDF/Albedo mandatory quality band for I3"),
        ]
    ),
    Product(
        product_id="VNP43IA4.001",
        description="Nadir BRDF-Adjusted Reflectance",
        bands=[
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_I1", description="BRDF/Albedo mandatory quality band for I1"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_I2", description="BRDF/Albedo mandatory quality band for I2"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_I3", description="BRDF/Albedo mandatory quality band for I3"),
            Band(name="Nadir_Reflectance_I1", description="Nadir BRDF/Albedo Reflectance at local solar noon for band I1"),
            Band(name="Nadir_Reflectance_I2", description="Nadir BRDF/Albedo Reflectance at local solar noon for band I2"),
            Band(name="Nadir_Reflectance_I3", description="Nadir BRDF/Albedo Reflectance at local solar noon for band I3"),
        ]
    ),
    Product(
        product_id="VNP43MA1.001",
        description="BRDF-Albedo Model Parameters",
        bands=[
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M1", description="BRDF/Albedo mandatory quality for band M1"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M10", description="BRDF/Albedo mandatory quality for band M10"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M11", description="BRDF/Albedo mandatory quality for band M11"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M2", description="BRDF/Albedo mandatory quality for band M2"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M3", description="BRDF/Albedo mandatory quality for band M3"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M4", description="BRDF/Albedo mandatory quality for band M4"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M5", description="BRDF/Albedo mandatory quality for band M5"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M7", description="BRDF/Albedo mandatory quality for band M7"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M8", description="BRDF/Albedo mandatory quality for band M8"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_nir", description="BRDF/Albedo mandatory quality for the NIR broadband"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_shortwave", description="BRDF/Albedo mandatory shortwave broadband"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_vis", description="BRDF/Albedo mandatory the visible broadband"),
            Band(name="BRDF_Albedo_Parameters_M1", description="Multi-dimensional layer for band M1 of parameters: fiso, fvol, and fgeo"),
            Band(name="BRDF_Albedo_Parameters_M10", description="Multi-dimensional layer for band M10 of parameters: fiso, fvol, and fgeo"),
            Band(name="BRDF_Albedo_Parameters_M11", description="Multi-dimensional layer for band M11 of parameters: fiso, fvol, and fgeo"),
            Band(name="BRDF_Albedo_Parameters_M2", description="Multi-dimensional layer for band M2 of parameters: fiso, fvol, and fgeo"),
            Band(name="BRDF_Albedo_Parameters_M3", description="Multi-dimensional layer for band M3 of parameters: fiso, fvol, and fgeo"),
            Band(name="BRDF_Albedo_Parameters_M4", description="Multi-dimensional layer for band M4 of parameters: fiso, fvol, and fgeo"),
            Band(name="BRDF_Albedo_Parameters_M5", description="Multi-dimensional layer for band M5 of parameters: fiso, fvol, and fgeo"),
            Band(name="BRDF_Albedo_Parameters_M7", description="Multi-dimensional layer for band M7 of parameters: fiso, fvol, and fgeo"),
            Band(name="BRDF_Albedo_Parameters_M8", description="Multi-dimensional layer for band M8 of parameters: fiso, fvol, and fgeo"),
            Band(name="BRDF_Albedo_Parameters_nir", description="Multi-dimensional layer for the NIR broadband of parameters: fiso, fvol, and fgeo"),
            Band(name="BRDF_Albedo_Parameters_shortwave", description="Multi-dimensional layer for the shortwave broadband of parameters: fiso, fvol, and fgeo"),
            Band(name="BRDF_Albedo_Parameters_vis", description="Multi-dimensional layer for the VIS broadband of parameters: fiso, fvol, and fgeo"),
        ]
    ),
    Product(
        product_id="VNP43MA2.001",
        description="BRDF-Albedo Quality",
        bands=[
            Band(name="BRDF_Albedo_Band_Quality_M1", description="BRDF inversion information"),
            Band(name="BRDF_Albedo_Band_Quality_M10", description="BRDF inversion information"),
            Band(name="BRDF_Albedo_Band_Quality_M11", description="BRDF inversion information"),
            Band(name="BRDF_Albedo_Band_Quality_M2", description="BRDF inversion information"),
            Band(name="BRDF_Albedo_Band_Quality_M3", description="BRDF inversion information"),
            Band(name="BRDF_Albedo_Band_Quality_M4", description="BRDF inversion information"),
            Band(name="BRDF_Albedo_Band_Quality_M5", description="BRDF inversion information"),
            Band(name="BRDF_Albedo_Band_Quality_M7", description="BRDF inversion information"),
            Band(name="BRDF_Albedo_Band_Quality_M8", description="BRDF inversion information"),
            Band(name="BRDF_Albedo_LandWaterType", description="Land/Water type"),
            Band(name="BRDF_Albedo_LocalSolarNoon", description="Solar zenith angle at local solar noon"),
            Band(name="BRDF_Albedo_Platform", description="Platform name"),
            Band(name="BRDF_Albedo_Uncertainty", description="Weight of Determination (WoD) of WSA"),
            Band(name="BRDF_Albedo_ValidObs_M1", description="Days of valid observation within 16-day period for band M1"),
            Band(name="BRDF_Albedo_ValidObs_M10", description="Days of valid observation within 16-day period for band M10"),
            Band(name="BRDF_Albedo_ValidObs_M11", description="Days of valid observation within 16-day period for band M11"),
            Band(name="BRDF_Albedo_ValidObs_M2", description="Days of valid observation within 16-day period for band M2"),
            Band(name="BRDF_Albedo_ValidObs_M3", description="Days of valid observation within 16-day period for band M3"),
            Band(name="BRDF_Albedo_ValidObs_M4", description="Days of valid observation within 16-day period for band M4"),
            Band(name="BRDF_Albedo_ValidObs_M5", description="Days of valid observation within 16-day period for band M5"),
            Band(name="BRDF_Albedo_ValidObs_M7", description="Days of valid observation within 16-day period for band M7"),
            Band(name="BRDF_Albedo_ValidObs_M8", description="Days of valid observation within 16-day period for band M8"),
            Band(name="Snow_BRDF_Albedo", description="Snow flag"),
        ]
    ),
    Product(
        product_id="VNP43MA3.001",
        description="Albedo (BRDF)",
        bands=[
            Band(name="Albedo_BSA_M1", description="BSA (at local solar noon) for band M1"),
            Band(name="Albedo_BSA_M10", description="BSA (at local solar noon) for band M10"),
            Band(name="Albedo_BSA_M11", description="BSA (at local solar noon) for band M11"),
            Band(name="Albedo_BSA_M2", description="BSA (at local solar noon) for band M2"),
            Band(name="Albedo_BSA_M3", description="BSA (at local solar noon) for band M3"),
            Band(name="Albedo_BSA_M4", description="BSA (at local solar noon) for band M4"),
            Band(name="Albedo_BSA_M5", description="BSA (at local solar noon) for band M5"),
            Band(name="Albedo_BSA_M7", description="BSA (at local solar noon) for band M7"),
            Band(name="Albedo_BSA_M8", description="BSA (at local solar noon) for band M8"),
            Band(name="Albedo_BSA_nir", description="BSA (at local solar noon) for the NIR broadboad"),
            Band(name="Albedo_BSA_shortwave", description="BSA (at local solar noon) for the SWIR broadboad"),
            Band(name="Albedo_BSA_vis", description="BSA (at local solar noon) for the VIS broadband"),
            Band(name="Albedo_WSA_M1", description="WSA for band M1"),
            Band(name="Albedo_WSA_M10", description="WSA for band M10"),
            Band(name="Albedo_WSA_M11", description="WSA for band M11"),
            Band(name="Albedo_WSA_M2", description="WSA for band M2"),
            Band(name="Albedo_WSA_M3", description="WSA for band M3"),
            Band(name="Albedo_WSA_M4", description="WSA for band M4"),
            Band(name="Albedo_WSA_M5", description="WSA for band M5"),
            Band(name="Albedo_WSA_M7", description="WSA for band M7"),
            Band(name="Albedo_WSA_M8", description="WSA for band M8"),
            Band(name="Albedo_WSA_nir", description="WSA for the NIR broadband"),
            Band(name="Albedo_WSA_shortwave", description="WSA for the SWIR broadband"),
            Band(name="Albedo_WSA_vis", description="WSA for the VIS broadband"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M1", description="BRDF/Albedo mandatory quality band for band M1"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M10", description="BRDF/Albedo mandatory quality band for band M10"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M11", description="BRDF/Albedo mandatory quality band for band M11"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M2", description="BRDF/Albedo mandatory quality band for band M2"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M3", description="BRDF/Albedo mandatory quality band for band M3"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M4", description="BRDF/Albedo mandatory quality band for band M4"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M5", description="BRDF/Albedo mandatory quality band for band M5"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M7", description="BRDF/Albedo mandatory quality band for band M7"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M8", description="BRDF/Albedo mandatory quality band for band M8"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_nir", description="BRDF/Albedo mandatory quality band for the NIR broadband"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_shortwave", description="BRDF/Albedo mandatory quality band for the shotwarve broadband"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_vis", description="BRDF/Albedo mandatory quality band for the VIS broadband"),
        ]
    ),
    Product(
        product_id="VNP43MA4.001",
        description="Nadir BRDF-Adjusted Reflectance",
        bands=[
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M1", description="BRDF/Albedo mandatory quality for band M1"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M10", description="BRDF/Albedo mandatory quality for band M10"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M11", description="BRDF/Albedo mandatory quality for band M11"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M2", description="BRDF/Albedo mandatory quality for band M2"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M3", description="BRDF/Albedo mandatory quality for band M3"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M4", description="BRDF/Albedo mandatory quality for band M4"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M5", description="BRDF/Albedo mandatory quality for band M5"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M7", description="BRDF/Albedo mandatory quality for band M7"),
            Band(name="BRDF_Albedo_Band_Mandatory_Quality_M8", description="BRDF/Albedo mandatory quality for band M8"),
            Band(name="Nadir_Reflectance_M1", description="Nadir BRDF/Albedo reflectance at local solar noon for band M1"),
            Band(name="Nadir_Reflectance_M10", description="Nadir BRDF/Albedo reflectance at local solar noon for band M10"),
            Band(name="Nadir_Reflectance_M11", description="Nadir BRDF/Albedo reflectance at local solar noon for band M11"),
            Band(name="Nadir_Reflectance_M2", description="Nadir BRDF/Albedo reflectance at local solar noon for band M2"),
            Band(name="Nadir_Reflectance_M3", description="Nadir BRDF/Albedo reflectance at local solar noon for band M3"),
            Band(name="Nadir_Reflectance_M4", description="Nadir BRDF/Albedo reflectance at local solar noon for band M4"),
            Band(name="Nadir_Reflectance_M5", description="Nadir BRDF/Albedo reflectance at local solar noon for band M5"),
            Band(name="Nadir_Reflectance_M7", description="Nadir BRDF/Albedo reflectance at local solar noon for band M7"),
            Band(name="Nadir_Reflectance_M8", description="Nadir BRDF/Albedo reflectance at local solar noon for band M8"),
        ]
    ),
    Product(
        product_id="L04.002",
        description="Landsat Collection 2 ARD Surface Reflectance - Landsat 4",
        bands=[
            Band(name="QA_LINEAGE", description="Lineage QA"),
            Band(name="QA_PIXEL", description="Pixel Quality Assessment"),
            Band(name="QA_RADSAT", description="Radiometric Saturation QA"),
            Band(name="SR_ATMOS_OPACITY", description="Internal SR Atmospheric Opacity"),
            Band(name="SR_B1", description="Band 1 Surface Reflectance"),
            Band(name="SR_B2", description="Band 2 Surface Reflectance"),
            Band(name="SR_B3", description="Band 3 Surface Reflectance"),
            Band(name="SR_B4", description="Band 4 Surface Reflectance"),
            Band(name="SR_B5", description="Band 5 Surface Reflectance"),
            Band(name="SR_B7", description="Band 7 Surface Reflectance"),
            Band(name="SR_CLOUD_QA", description="Internal SR QA"),
        ]
    ),
    Product(
        product_id="L05.002",
        description="Landsat Collection 2 ARD Surface Reflectance - Landsat 5",
        bands=[
            Band(name="QA_LINEAGE", description="Lineage QA"),
            Band(name="QA_PIXEL", description="Pixel Quality Assessment"),
            Band(name="QA_RADSAT", description="Radiometric Saturation QA"),
            Band(name="SR_ATMOS_OPACITY", description="Internal SR Atmospheric Opacity"),
            Band(name="SR_B1", description="Band 1 Surface Reflectance"),
            Band(name="SR_B2", description="Band 2 Surface Reflectance"),
            Band(name="SR_B3", description="Band 3 Surface Reflectance"),
            Band(name="SR_B4", description="Band 4 Surface Reflectance"),
            Band(name="SR_B5", description="Band 5 Surface Reflectance"),
            Band(name="SR_B7", description="Band 7 Surface Reflectance"),
            Band(name="SR_CLOUD_QA", description="Internal SR QA"),
        ]
    ),
    Product(
        product_id="L07.002",
        description="Landsat Collection 2 ARD Surface Reflectance - Landsat 7",
        bands=[
            Band(name="QA_LINEAGE", description="Lineage QA"),
            Band(name="QA_PIXEL", description="Pixel Quality Assessment"),
            Band(name="QA_RADSAT", description="Radiometric Saturation QA"),
            Band(name="SR_ATMOS_OPACITY", description="Internal SR Atmospheric Opacity"),
            Band(name="SR_B1", description="Band 1 Surface Reflectance"),
            Band(name="SR_B2", description="Band 2 Surface Reflectance"),
            Band(name="SR_B3", description="Band 3 Surface Reflectance"),
            Band(name="SR_B4", description="Band 4 Surface Reflectance"),
            Band(name="SR_B5", description="Band 5 Surface Reflectance"),
            Band(name="SR_B7", description="Band 7 Surface Reflectance"),
            Band(name="SR_CLOUD_QA", description="Internal SR QA"),
        ]
    ),
    Product(
        product_id="L08.002",
        description="Landsat Collection 2 ARD Surface Reflectance - Landsat 8",
        bands=[
            Band(name="QA_LINEAGE", description="Lineage QA"),
            Band(name="QA_PIXEL", description="Pixel Quality Assessment"),
            Band(name="QA_RADSAT", description="Radiometric Saturation QA"),
            Band(name="SR_B1", description="Band 1 Surface Reflectance"),
            Band(name="SR_B2", description="Band 2 Surface Reflectance"),
            Band(name="SR_B3", description="Band 3 Surface Reflectance"),
            Band(name="SR_B4", description="Band 4 Surface Reflectance"),
            Band(name="SR_B5", description="Band 5 Surface Reflectance"),
            Band(name="SR_B6", description="Band 6 Surface Reflectance"),
            Band(name="SR_B7", description="Band 7 Surface Reflectance"),
            Band(name="SR_QA_AEROSOL", description="Aerosol QA"),
        ]
    ),
    Product(
        product_id="L09.002",
        description="Landsat Collection 2 ARD Surface Reflectance - Landsat 9",
        bands=[
            Band(name="QA_LINEAGE", description="Lineage QA"),
            Band(name="QA_PIXEL", description="Pixel Quality Assessment"),
            Band(name="QA_RADSAT", description="Radiometric Saturation QA"),
            Band(name="SR_B1", description="Band 1 Surface Reflectance"),
            Band(name="SR_B2", description="Band 2 Surface Reflectance"),
            Band(name="SR_B3", description="Band 3 Surface Reflectance"),
            Band(name="SR_B4", description="Band 4 Surface Reflectance"),
            Band(name="SR_B5", description="Band 5 Surface Reflectance"),
            Band(name="SR_B6", description="Band 6 Surface Reflectance"),
            Band(name="SR_B7", description="Band 7 Surface Reflectance"),
            Band(name="SR_QA_AEROSOL", description="Aerosol QA"),
        ]
    ),
    Product(
        product_id="DAYMET.004",
        description="Daily Surface Weather Data for North America",
        bands=[
            Band(name="dayl", description="Day length"),
            Band(name="prcp", description="Precipitation"),
            Band(name="srad", description="Shortwave radiation"),
            Band(name="swe", description="Snow water equivalent"),
            Band(name="tmax", description="Maximum air temperature"),
            Band(name="tmin", description="Minimum air temperature"),
            Band(name="vp", description="Water vapor pressure"),
        ]
    ),
    Product(
        product_id="ECO2LSTE.001",
        description="Land Surface Temperature & Emissivity (LST&E)",
        bands=[
            Band(name="SDS_Emis1", description="Band 1 Emissivity"),
            Band(name="SDS_Emis1_err", description="Band 1 Emissivity error"),
            Band(name="SDS_Emis2", description="Band 2 Emissivity"),
            Band(name="SDS_Emis2_err", description="Band 2 Emissivity error"),
            Band(name="SDS_Emis3", description="Band 3 Emissivity"),
            Band(name="SDS_Emis3_err", description="Band 3 Emissivity error"),
            Band(name="SDS_Emis4", description="Band 4 Emissivity"),
            Band(name="SDS_Emis4_err", description="Band 4 Emissivity error"),
            Band(name="SDS_Emis5", description="Band 5 Emissivity"),
            Band(name="SDS_Emis5_err", description="Band 5 Emissivity error"),
            Band(name="SDS_EmisWB", description="Wide Band Emissivity"),
            Band(name="SDS_LST", description="Land Surface Temperature"),
            Band(name="SDS_LST_err", description="Land Surface Temperature error"),
            Band(name="SDS_PWV", description="Precipitable Water Vapor"),
            Band(name="SDS_QC", description="Quality Control for LST and emissivity"),
        ]
    ),
    Product(
        product_id="ECO2CLD.001",
        description="Cloud Mask",
        bands=[
            Band(name="SDS_CloudMask", description="Cloud Mask"),
        ]
    ),
    Product(
        product_id="ECO3ETPTJPL.001",
        description="Evapotranspiration PT-JPL",
        bands=[
            Band(name="EVAPOTRANSPIRATION_PT_JPL_ETcanopy", description="Canopy Evaporation"),
            Band(name="EVAPOTRANSPIRATION_PT_JPL_ETdaily", description="Daily Latent Heat Flux"),
            Band(name="EVAPOTRANSPIRATION_PT_JPL_ETinst", description="Instantaneous Latent Heat Flux"),
            Band(name="EVAPOTRANSPIRATION_PT_JPL_ETinstUncertainty", description="ETinst Uncertainty"),
            Band(name="EVAPOTRANSPIRATION_PT_JPL_ETinterception", description="Interception Evaporation"),
            Band(name="EVAPOTRANSPIRATION_PT_JPL_ETsoil", description="Soil Evaporation"),
        ]
    ),
    Product(
        product_id="ECO3ANCQA.001",
        description="L3/L4 Ancillary Data Quality Assurance (QA) Flags",
        bands=[
            Band(name="L3_L4_QA_ECOSTRESS_L2_QC", description="ECOSTRESS Cloud Mask Daily L2 Global 70m"),
            Band(name="L3_L4_QA_Landsat8_QC", description="Landsat 8 Quality Flags"),
            Band(name="L3_L4_QA_MCD12Q1_QC", description="Land Cover Type Yearly L3 Global 500m SIN Grid"),
            Band(name="L3_L4_QA_MCD43A3_QC", description="Albedo 16-day L3 Global 500m"),
            Band(name="L3_L4_QA_MOD04_QC", description="MODIS Terra Aerosol"),
            Band(name="L3_L4_QA_MOD06_1km_QC", description="MODIS Terra Cloud 1km"),
            Band(name="L3_L4_QA_MOD06_5km_QC", description="MODIS Terra Cloud 5km"),
            Band(name="L3_L4_QA_MOD07_QC", description="MODIS Terra Atmospheric Profile"),
            Band(name="L3_L4_QA_MOD13Q1_QC", description="Vegetation Indices 16-day L3 Global 250m"),
            Band(name="L3_L4_QA_MOD17A2H_QC", description="MODIS Terra Gross Primary Productivity 8-day L4 Global 500m SIN Grid"),
            Band(name="L3_L4_QA_MOD44W_QC", description="MODIS 250m Water Mask"),
        ]
    ),
    Product(
        product_id="ECO4ESIPTJPL.001",
        description="Evaporative Stress Index PT-JPL",
        bands=[
            Band(name="Evaporative_Stress_Index_PT_JPL_ESIavg", description="Evaporative Stress Index"),
            Band(name="Evaporative_Stress_Index_PT_JPL_PET", description="Potential Evapotranspiration"),
        ]
    ),
    Product(
        product_id="ECO4WUE.001",
        description="Water Use Efficiency",
        bands=[
            Band(name="Water_Use_Efficiency_WUEavg", description="Water Use Efficiency"),
        ]
    ),
    Product(
        product_id="ECO1BGEO.001",
        description="Geolocation",
        bands=[
            Band(name="Geolocation_height", description=""),
            Band(name="Geolocation_land_fraction", description=""),
            Band(name="Geolocation_solar_azimuth", description=""),
            Band(name="Geolocation_solar_zenith", description=""),
            Band(name="Geolocation_view_azimuth", description=""),
            Band(name="Geolocation_view_zenith", description=""),
        ]
    ),
    Product(
        product_id="ECO1BMAPRAD.001",
        description="Resampled Radiance",
        bands=[
            Band(name="Mapped_data_quality_1", description="Data Quality Indicators for radiance_1"),
            Band(name="Mapped_data_quality_2", description="Data Quality Indicators for radiance_2"),
            Band(name="Mapped_data_quality_3", description="Data Quality Indicators for radiance_3"),
            Band(name="Mapped_data_quality_4", description="Data Quality Indicators for radiance_4"),
            Band(name="Mapped_data_quality_5", description="Data Quality Indicators for radiance_5"),
            Band(name="Mapped_height", description="Surface Height"),
            Band(name="Mapped_radiance_1", description="TIR 8.285 microns"),
            Band(name="Mapped_radiance_2", description="TIR 8.785 microns"),
            Band(name="Mapped_radiance_3", description="TIR 9.060 microns"),
            Band(name="Mapped_radiance_4", description="TIR 10.522 microns"),
            Band(name="Mapped_radiance_5", description="TIR 12.001 microns"),
            Band(name="Mapped_solar_azimuth", description="Solar azimuth angle"),
            Band(name="Mapped_solar_zenith", description="Solar zenith angle"),
            Band(name="Mapped_swir_dn", description="Uncalibrated SWIR data with Dark Current subtracted"),
            Band(name="Mapped_view_azimuth", description="View azimuth angle"),
            Band(name="Mapped_view_zenith", description="View zenith angle"),
        ]
    ),
    Product(
        product_id="ECO3ETALEXI.001",
        description="Evapotranspiration dis-ALEXI",
        bands=[
            Band(name="EVAPOTRANSPIRATION_ALEXI_ETdaily", description="Evapotranspiration Daily"),
            Band(name="EVAPOTRANSPIRATION_ALEXI_ETdailyUncertainty", description="Evapotranspiration Daily Uncertainty"),
            Band(name="EVAPOTRANSPIRATION_ALEXI_QualityFlag", description="QualityFlag"),
        ]
    ),
    Product(
        product_id="ECO4ESIALEXI.001",
        description="Evaporative Stress Index dis-ALEXI",
        bands=[
            Band(name="EVAPORATIVE_STRESS_INDEX_ALEXI_ESIdaily", description="Evaporative Stress Index Daily"),
            Band(name="EVAPORATIVE_STRESS_INDEX_ALEXI_ESIdailyUncertainty", description="Evaporative Stress Index Daily Uncertainty"),
            Band(name="EVAPORATIVE_STRESS_INDEX_ALEXI_QualityFlag", description="QualityFlag"),
        ]
    ),
    Product(
        product_id="ECO_L1B_GEO.002",
        description="Geolocation",
        bands=[
            Band(name="height", description=""),
            Band(name="land_fraction", description=""),
            Band(name="solar_azimuth", description=""),
            Band(name="solar_zenith", description=""),
            Band(name="view_azimuth", description=""),
            Band(name="view_zenith", description=""),
        ]
    ),
    Product(
        product_id="ECO_L2_CLOUD.002",
        description="Cloud Mask Instantaneous",
        bands=[
            Band(name="Cloud_confidence", description="Cloud confidence"),
            Band(name="Cloud_final", description="Final Cloud Mask"),
        ]
    ),
    Product(
        product_id="ECO_L2_LSTE.002",
        description="Swath Land Surface Temperature and Emissivity Instantaneous",
        bands=[
            Band(name="Emis1", description="Band 1 Emissivity"),
            Band(name="Emis1_err", description="Band 1 Emissivity error"),
            Band(name="Emis2", description="Band 2 Emissivity"),
            Band(name="Emis2_err", description="Band 2 Emissivity error"),
            Band(name="Emis3", description="Band 3 Emissivity"),
            Band(name="Emis3_err", description="Band 3 Emissivity error"),
            Band(name="Emis4", description="Band 4 Emissivity"),
            Band(name="Emis4_err", description="Band 4 Emissivity error"),
            Band(name="Emis5", description="Band 5 Emissivity"),
            Band(name="Emis5_err", description="Band 5 Emissivity error"),
            Band(name="EmisWB", description="Wide Band Emissivity"),
            Band(name="LST", description="Land Surface Temperature"),
            Band(name="LST_err", description="Land Surface Temperature error"),
            Band(name="PWV", description="Precipitable Water Vapor"),
            Band(name="QC", description="Quality Control for LST and emissivity"),
            Band(name="cloud_mask", description="Final cloud mask"),
            Band(name="water_mask", description="water mask"),
        ]
    ),
    Product(
        product_id="ECO_L2T_LSTE.002",
        description="Tiled Land Surface Temperature and Emissivity",
        bands=[
            Band(name="EmisWB", description="Wide Band Emissivity"),
            Band(name="LST", description="Land Surface Temperature"),
            Band(name="LST_err", description="Land Surface Temperature error"),
            Band(name="QC", description="Quality Control for LST and emissivity"),
            Band(name="cloud", description="Cloud Mask"),
            Band(name="height", description="height"),
            Band(name="water", description="Water Mask"),
        ]
    ),
    Product(
        product_id="ECO_L1CT_RAD.002",
        description="Tiled Top of Atmosphere Calibrated Radiance Instantaneous",
        bands=[
            Band(name="cloud", description="Cloud mask"),
            Band(name="data_quality_1", description="Data Quality Indicators for radiance_1"),
            Band(name="data_quality_2", description="Data Quality Indicators for radiance_2"),
            Band(name="data_quality_3", description="Data Quality Indicators for radiance_3"),
            Band(name="data_quality_4", description="Data Quality Indicators for radiance_4"),
            Band(name="data_quality_5", description="Data Quality Indicators for radiance_5"),
            Band(name="radiance_1", description="TIR 8.285 microns"),
            Band(name="radiance_2", description="TIR 8.785 microns"),
            Band(name="radiance_3", description="TIR 9.060 microns"),
            Band(name="radiance_4", description="TIR 10.522 microns"),
            Band(name="radiance_5", description="TIR 12.001 microns"),
            Band(name="water", description="Water mask"),
        ]
    ),
    Product(
        product_id="HLSS30.020",
        description="Land Surface Reflectance",
        bands=[
            Band(name="B01", description="B01 - Coastal Aerosol (0.43 - 0.45 µm)"),
            Band(name="B02", description="B02 - Blue (0.45 - 0.51 µm)"),
            Band(name="B03", description="B03 - Green (0.53 - 0.59 µm)"),
            Band(name="B04", description="B04 - Red (0.64 - 0.67 µm)"),
            Band(name="B05", description="B05 - Red Edge1 (0.69 - 0.71 µm)"),
            Band(name="B06", description="B06 - Red Edge2 (0.73 - 0.75 µm)"),
            Band(name="B07", description="B07 - Red Edge3 (0.77 - 0.79 µm)"),
            Band(name="B08", description="B08 - NIR Broad (0.78 - 0.88 µm)"),
            Band(name="B09", description="B09 - Water Vapor (0.93 - 0.95 µm)"),
            Band(name="B10", description="B10 - Cirrus (1.36 - 1.38 µm)"),
            Band(name="B11", description="B11 - SWIR1 (1.57 - 1.65 µm)"),
            Band(name="B12", description="B12 - SWIR2 (2.11 - 2.29 µm)"),
            Band(name="B8A", description="B8A - NIR Narrow (0.85 - 0.88 µm)"),
            Band(name="Fmask", description="Quality Bits"),
            Band(name="SAA", description="Sun Azimuth Angle"),
            Band(name="SZA", description="Sun Zenith Angle"),
            Band(name="VAA", description="View Azimuth Angle"),
            Band(name="VZA", description="View Zenith Angle"),
        ]
    ),
    Product(
        product_id="HLSL30.020",
        description="Land Surface Reflectance",
        bands=[
            Band(name="B01", description="B01 - Coastal Aerosol (0.43 - 0.45 µm)"),
            Band(name="B02", description="B02 - Blue (0.45 - 0.51 µm)"),
            Band(name="B03", description="B03 - Green (0.53 - 0.59 µm)"),
            Band(name="B04", description="B04 - Red (0.64 - 0.67 µm)"),
            Band(name="B05", description="B05 - NIR (0.85 - 0.88 µm)"),
            Band(name="B06", description="B06 - SWIR1 (1.57 - 1.65 µm)"),
            Band(name="B07", description="B07 - SWIR2 (2.11 - 2.29 µm)"),
            Band(name="B09", description="B09 - Cirrus (1.36 - 1.38 µm)"),
            Band(name="B10", description="B10 - TIRS1 (10.60 - 11.19 µm)"),
            Band(name="B11", description="B11 - TIRS2 (11.50 - 12.51 µm)"),
            Band(name="Fmask", description="Quality Bits"),
            Band(name="SAA", description="Sun Azimuth Angle"),
            Band(name="SZA", description="Sun Zenith Angle"),
            Band(name="VAA", description="View Azimuth Angle"),
            Band(name="VZA", description="View Zenith Angle"),
        ]
    ),
    Product(
        product_id="GEOLST4KHR.002",
        description="Geostationary Earth Orbit Land Surface Temperature Hourly North and South America 4KM V002",
        bands=[
            Band(name="cloud", description="Cloud Mask"),
            Band(name="lst", description="Land Surface Temperature"),
            Band(name="lst_err", description="Land Surface Temperature Error"),
        ]
    ),
    Product(
        product_id="WaterBalance_Daily_Historical_GRIDMET.015",
        description="NPS Water Balance",
        bands=[
            Band(name="AET", description="Actual Evapotranspiration (mm), water balance most closely related to vegetation growth"),
            Band(name="Accumswe", description="Accumulated Snow Water Equivalent (mm), total SWE at each location"),
            Band(name="Deficit", description="Moisture Deficit (mm), Deficit = PET - AET the amount of water vegetation would use if it was available"),
            Band(name="PET", description="Potential Evapotranspiration (mm), The amount of evaporation and transpiration (movement of water into the atmosphere by plants) that would occur if soil moisture were unlimited."),
            Band(name="Rain", description="Rain = total daily precipitation - daily snow accumulation, where snow is taken directly as Snow Water Equivalent (SWE) increase from the Daymet input dataset"),
            Band(name="Runoff", description="Water exceeding the amount that is held in the soil"),
            Band(name="Soilwater", description="The amount of water that is held in the soil"),
        ]
    ),
    Product(
        product_id="WaterBalance_Monthly_Historical_GRIDMET.015",
        description="NPS Water Balance",
        bands=[
            Band(name="AET", description="Actual Evapotranspiration (mm), water balance most closely related to vegetation growth"),
            Band(name="Accumswe", description="Accumulated Snow Water Equivalent (mm), total SWE at each location"),
            Band(name="Deficit", description="Moisture Deficit (mm), Deficit = PET - AET the amount of water vegetation would use if it was available"),
            Band(name="PET", description="Potential Evapotranspiration (mm), The amount of evaporation and transpiration (movement of water into the atmosphere by plants) that would occur if soil moisture were unlimited."),
            Band(name="Rain", description="Rain = total daily precipitation - daily snow accumulation, where snow is taken directly as Snow Water Equivalent (SWE) increase from the Daymet input dataset"),
            Band(name="Runoff", description="Water exceeding the amount that is held in the soil"),
            Band(name="Soilwater", description="The amount of water that is held in the soil"),
        ]
    ),
    Product(
        product_id="VNP14A1.002",
        description="Thermal Anomalies and Fire",
        bands=[
            Band(name="FireMask", description="Fire Mask"),
            Band(name="MaxFRP", description="Maximum Fire Radiative Power"),
            Band(name="QA", description="Pixel Quality Indicators"),
            Band(name="sample", description="Sample number within a swath"),
        ]
    ),
    Product(
        product_id="VJ114A1.002",
        description="Thermal Anomalies and Fire",
        bands=[
            Band(name="FireMask", description="Fire Mask"),
            Band(name="MaxFRP", description="Maximum Fire Radiative Power"),
            Band(name="QA", description="Pixel Quality Indicators"),
            Band(name="sample", description="Sample number within a swath"),
        ]
    ),
    Product(
        product_id="VNP15A2H.002",
        description="Leaf Area Index (LAI) and Fraction of Photosynthetically Active Radiation (FPAR)",
        bands=[
            Band(name="Fpar", description="VIIRS Gridded 500M FPAR (8-day composite)"),
            Band(name="FparExtra_QC", description="VIIRS pass-through QC for FPAR and LAI (8-day composite)"),
            Band(name="FparLai_QC", description="VIIRS QC for FPAR and LAI (8-day composite)"),
            Band(name="FparStdDev", description="VIIRS Gridded 500M Standard Deviation FPAR (8-day composite)"),
            Band(name="Lai", description="VIIRS Gridded 500M Leaf Area Index LAI (8-day composite)"),
            Band(name="LaiStdDev", description="VIIRS Gridded 500M Standard Deviation Leaf Area Index (8-day composite)"),
        ]
    ),
    Product(
        product_id="VJ115A2H.002",
        description="Leaf Area Index (LAI) and Fraction of Photosynthetically Active Radiation (FPAR)",
        bands=[
            Band(name="Fpar", description="VIIRS Gridded 500M FPAR (8-day composite)"),
            Band(name="FparExtra_QC", description="VIIRS pass-through QC for FPAR and LAI (8-day composite)"),
            Band(name="FparLai_QC", description="VIIRS QC for FPAR and LAI (8-day composite)"),
            Band(name="FparStdDev", description="VIIRS Gridded 500M Standard Deviation FPAR (8-day composite)"),
            Band(name="Lai", description="VIIRS Gridded 500M Leaf Area Index LAI (8-day composite)"),
            Band(name="LaiStdDev", description="VIIRS Gridded 500M Standard Deviation Leaf Area Index (8-day composite)"),
        ]
    ),
    Product(
        product_id="VNP13A1.002",
        description="Vegetation Indices",
        bands=[
            Band(name="500_m_16_days_EVI", description="500 m 16 days EVI"),
            Band(name="500_m_16_days_EVI2", description="500 m 16 days EVI2"),
            Band(name="500_m_16_days_NDVI", description="500 m 16 days NDVI"),
            Band(name="500_m_16_days_NIR_reflectance", description="500 m 16 days NIR reflectance (846-885 nm)"),
            Band(name="500_m_16_days_SWIR1_reflectance", description="500 m 16 days SWIR1 reflectance (1230-1250 nm)"),
            Band(name="500_m_16_days_SWIR2_reflectance", description="500 m 16 days SWIR2 reflectance (1580-1640 nm)"),
            Band(name="500_m_16_days_SWIR3_reflectance", description="500 m 16 days SWIR3 reflectance (2225-2275 nm)"),
            Band(name="500_m_16_days_VI_Quality", description="500 m 16 days VI Quality"),
            Band(name="500_m_16_days_blue_reflectance", description="500 m 16 days blue reflectance (478-498 nm)"),
            Band(name="500_m_16_days_composite_day_of_the_year", description="500 m 16 days composite day of the year"),
            Band(name="500_m_16_days_green_reflectance", description="500 m 16 days green reflectance (545-565 nm)"),
            Band(name="500_m_16_days_pixel_reliability", description="500 m 16 days pixel reliability"),
            Band(name="500_m_16_days_red_reflectance", description="500 m 16 days red reflectance (600-680 nm)"),
            Band(name="500_m_16_days_relative_azimuth_angle", description="500 m 16 days relative azimuth angle"),
            Band(name="500_m_16_days_sun_zenith_angle", description="500 m 16 days sun zenith angle"),
            Band(name="500_m_16_days_view_zenith_angle", description="500 m 16 days view zenith angle"),
        ]
    ),
    Product(
        product_id="VJ113A1.002",
        description="Vegetation Indices",
        bands=[
            Band(name="500_m_16_days_EVI", description="500 m 16 days EVI"),
            Band(name="500_m_16_days_EVI2", description="500 m 16 days EVI2"),
            Band(name="500_m_16_days_NDVI", description="500 m 16 days NDVI"),
            Band(name="500_m_16_days_NIR_reflectance", description="500 m 16 days NIR reflectance (846-885 nm)"),
            Band(name="500_m_16_days_SWIR1_reflectance", description="500 m 16 days SWIR1 reflectance (1230-1250 nm)"),
            Band(name="500_m_16_days_SWIR2_reflectance", description="500 m 16 days SWIR2 reflectance (1580-1640 nm)"),
            Band(name="500_m_16_days_SWIR3_reflectance", description="500 m 16 days SWIR3 reflectance (2225-2275 nm)"),
            Band(name="500_m_16_days_VI_Quality", description="500 m 16 days VI Quality"),
            Band(name="500_m_16_days_blue_reflectance", description="500 m 16 days blue reflectance (478-498 nm)"),
            Band(name="500_m_16_days_composite_day_of_the_year", description="500 m 16 days composite day of the year"),
            Band(name="500_m_16_days_green_reflectance", description="500 m 16 days green reflectance (545-565 nm)"),
            Band(name="500_m_16_days_pixel_reliability", description="500 m 16 days pixel reliability"),
            Band(name="500_m_16_days_red_reflectance", description="500 m 16 days red reflectance (600-680 nm)"),
            Band(name="500_m_16_days_relative_azimuth_angle", description="500 m 16 days relative azimuth angle"),
            Band(name="500_m_16_days_sun_zenith_angle", description="500 m 16 days sun zenith angle"),
            Band(name="500_m_16_days_view_zenith_angle", description="500 m 16 days view zenith angle"),
        ]
    ),
    Product(
        product_id="VNP13A2.002",
        description="Vegetation Indices",
        bands=[
            Band(name="1_km_16_days_EVI", description="3 band Enhanced Vegetation Index"),
            Band(name="1_km_16_days_EVI2", description="2 band Enhanced Vegetation Index"),
            Band(name="1_km_16_days_NDVI", description="Normalized Difference Vegetation Index"),
            Band(name="1_km_16_days_NIR_reflectance", description="Near-infrared Radiation reflectance (846-885 nm)"),
            Band(name="1_km_16_days_SWIR1_reflectance", description="Shortwave Infrared Radiation reflectance (1230-1250 nm)"),
            Band(name="1_km_16_days_SWIR2_reflectance", description="Shortwave Infrared Radiation reflectance (1580-1640 nm)"),
            Band(name="1_km_16_days_SWIR3_reflectance", description="Shortwave Infrared Radiation reflectance (2225-2275 nm)"),
            Band(name="1_km_16_days_VI_Quality", description="Bit field that assigns each pixel a Quality Assessment (QA) attribute"),
            Band(name="1_km_16_days_blue_reflectance", description="Blue band reflectance (478-498 nm)"),
            Band(name="1_km_16_days_composite_day_of_the_year", description="Day of year for the pixel"),
            Band(name="1_km_16_days_green_reflectance", description="Green band reflectance (545-565 nm)"),
            Band(name="1_km_16_days_pixel_reliability", description="1 km 16 days pixel reliability"),
            Band(name="1_km_16_days_red_reflectance", description="Red band reflectance (600-680 nm)"),
            Band(name="1_km_16_days_relative_azimuth_angle", description="Relative azimuth angle for each pixel"),
            Band(name="1_km_16_days_sun_zenith_angle", description="Sun zenith angle for each pixel"),
            Band(name="1_km_16_days_view_zenith_angle", description="View zenith angle for each pixel"),
        ]
    ),
    Product(
        product_id="VJ113A2.002",
        description="Vegetation Indices",
        bands=[
            Band(name="1_km_16_days_EVI", description="3 band Enhanced Vegetation Index"),
            Band(name="1_km_16_days_EVI2", description="2 band Enhanced Vegetation Index"),
            Band(name="1_km_16_days_NDVI", description="Normalized Difference Vegetation Index"),
            Band(name="1_km_16_days_NIR_reflectance", description="Near-infrared Radiation reflectance (846-885 nm)"),
            Band(name="1_km_16_days_SWIR1_reflectance", description="Shortwave Infrared Radiation reflectance (1230-1250 nm)"),
            Band(name="1_km_16_days_SWIR2_reflectance", description="Shortwave Infrared Radiation reflectance (1580-1640 nm)"),
            Band(name="1_km_16_days_SWIR3_reflectance", description="Shortwave Infrared Radiation reflectance (2225-2275 nm)"),
            Band(name="1_km_16_days_VI_Quality", description="Bit field that assigns each pixel a Quality Assessment (QA) attribute"),
            Band(name="1_km_16_days_blue_reflectance", description="Blue band reflectance (478-498 nm)"),
            Band(name="1_km_16_days_composite_day_of_the_year", description="Day of year for the pixel"),
            Band(name="1_km_16_days_green_reflectance", description="Green band reflectance (545-565 nm)"),
            Band(name="1_km_16_days_pixel_reliability", description="1 km 16 days pixel reliability"),
            Band(name="1_km_16_days_red_reflectance", description="Red band reflectance (600-680 nm)"),
            Band(name="1_km_16_days_relative_azimuth_angle", description="Relative azimuth angle for each pixel"),
            Band(name="1_km_16_days_sun zenith_angle", description="Sun zenith angle for each pixel"),
            Band(name="1_km_16_days_view zenith_angle", description="View zenith angle for each pixel"),
        ]
    ),
    Product(
        product_id="VNP13A3.002",
        description="Vegetation Indices",
        bands=[
            Band(name="1_km_monthly_EVI", description="3 band Enhanced Vegetation Index"),
            Band(name="1_km_monthly_EVI2", description="2 band Enhanced Vegetation Index"),
            Band(name="1_km_monthly_NDVI", description="Normalized Difference Vegetation Index"),
            Band(name="1_km_monthly_NIR_reflectance", description="Near-infrared Radiation reflectance (846-885 nm)"),
            Band(name="1_km_monthly_SWIR1_reflectance", description="Shortwave Infrared Radiation reflectance (1230-1250 nm)"),
            Band(name="1_km_monthly_SWIR2_reflectance", description="Shortwave Infrared Radiation reflectance (1580-1640 nm)"),
            Band(name="1_km_monthly_SWIR3_reflectance", description="Shortwave Infrared Radiation reflectance (2225-2275 nm)"),
            Band(name="1_km_monthly_VI_Quality", description="Bit field that assigns each pixel a Quality Assessment (QA) attribute"),
            Band(name="1_km_monthly_blue_reflectance", description="Blue band reflectance (478-498 nm)"),
            Band(name="1_km_monthly_green_reflectance", description="1 km monthly green reflectance"),
            Band(name="1_km_monthly_pixel_reliability", description="1 km monthly pixel reliability"),
            Band(name="1_km_monthly_red_reflectance", description="Red band reflectance (600-680 nm)"),
            Band(name="1_km_monthly_relative_azimuth_angle", description="Relative azimuth angle for each pixel"),
            Band(name="1_km_monthly_sun_zenith_angle", description="Sun zenith angle for each pixel"),
            Band(name="1_km_monthly_view_zenith_angle", description="1 km monthly view zenith angle"),
        ]
    ),
    Product(
        product_id="VJ113A3.002",
        description="Vegetation Indices",
        bands=[
            Band(name="1_km_monthly_EVI", description="3 band Enhanced Vegetation Index"),
            Band(name="1_km_monthly_EVI2", description="2 band Enhanced Vegetation Index"),
            Band(name="1_km_monthly_NDVI", description="Normalized Difference Vegetation Index"),
            Band(name="1_km_monthly_NIR_reflectance", description="Near-infrared Radiation reflectance (846-885 nm)"),
            Band(name="1_km_monthly_SWIR1_reflectance", description="Shortwave Infrared Radiation reflectance (1230-1250 nm)"),
            Band(name="1_km_monthly_SWIR2_reflectance", description="Shortwave Infrared Radiation reflectance (1580-1640 nm)"),
            Band(name="1_km_monthly_SWIR3_reflectance", description="Shortwave Infrared Radiation reflectance (2225-2275 nm)"),
            Band(name="1_km_monthly_VI_Quality", description="Bit field that assigns each pixel a Quality Assessment (QA) attribute"),
            Band(name="1_km_monthly_blue_reflectance", description="Blue band reflectance (478-498 nm)"),
            Band(name="1_km_monthly_green_reflectance", description="1 km monthly green reflectance"),
            Band(name="1_km_monthly_pixel_reliability", description="1 km monthly pixel reliability"),
            Band(name="1_km_monthly_red_reflectance", description="Red band reflectance (600-680 nm)"),
            Band(name="1_km_monthly_relative_azimuth_angle", description="Relative azimuth angle for each pixel"),
            Band(name="1_km_monthly_sun_zenith_angle", description="Sun zenith angle for each pixel"),
            Band(name="1_km_monthly_view_zenith_angle", description="1 km monthly view zenith angle"),
        ]
    ),
    Product(
        product_id="VNP21A1D.002",
        description="Land Surface Temperature and Emissivity (LST&E) Day",
        bands=[
            Band(name="Emis_14", description="DailyM14 emissivity"),
            Band(name="Emis_15", description="DailyM15 emissivity"),
            Band(name="Emis_16", description="DailyM16 emissivity"),
            Band(name="LST_1KM", description="Daily 1 km Land Surface Temperature"),
            Band(name="QC", description="Daily Quality control for LST and emissivity"),
            Band(name="View_Angle", description="View zenith angle of LST"),
            Band(name="View_Time", description="Time of LST observation"),
        ]
    ),
    Product(
        product_id="VJ121A1D.002",
        description="Land Surface Temperature and Emissivity (LST&E) Day",
        bands=[
            Band(name="Emis_14", description="DailyM14 emissivity"),
            Band(name="Emis_15", description="DailyM15 emissivity"),
            Band(name="Emis_16", description="DailyM16 emissivity"),
            Band(name="LST_1KM", description="Daily 1 km Land Surface Temperature"),
            Band(name="QC", description="Daily Quality control for LST and emissivity"),
            Band(name="View_Angle", description="View zenith angle of LST"),
            Band(name="View_Time", description="Time of LST observation"),
        ]
    ),
    Product(
        product_id="VNP21A1N.002",
        description="Land Surface Temperature and Emissivity (LST&E) Night",
        bands=[
            Band(name="Emis_14", description="DailyM14 emissivity"),
            Band(name="Emis_15", description="DailyM15 emissivity"),
            Band(name="Emis_16", description="DailyM16 emissivity"),
            Band(name="LST_1KM", description="Daily 1 km Land Surface Temperature"),
            Band(name="QC", description="Daily Quality control for LST and emissivity"),
            Band(name="View_Angle", description="View zenith angle of LST"),
            Band(name="View_Time", description="Time of LST observation"),
        ]
    ),
    Product(
        product_id="VJ121A1N.002",
        description="Land Surface Temperature and Emissivity (LST&E) Night",
        bands=[
            Band(name="Emis_14", description="DailyM14 emissivity"),
            Band(name="Emis_15", description="DailyM15 emissivity"),
            Band(name="Emis_16", description="DailyM16 emissivity"),
            Band(name="LST_1KM", description="Daily 1 km Land Surface Temperature"),
            Band(name="QC", description="Daily Quality control for LST and emissivity"),
            Band(name="View_Angle", description="View zenith angle of LST"),
            Band(name="View_Time", description="Time of LST observation"),
        ]
    ),
    Product(
        product_id="VNP21A2.002",
        description="Land Surface Temperature and Emissivity (LST&E)",
        bands=[
            Band(name="Emis_14", description="M14 emissivity"),
            Band(name="Emis_15", description="M15 emissivity"),
            Band(name="Emis_16", description="M16 emissivity"),
            Band(name="LST_Day_1KM", description="Day Land Surface Temperature"),
            Band(name="LST_Night_1KM", description="Night 1 km Land Surface Temperature"),
            Band(name="QC_Day", description="Day Quality control for LST and emissivity"),
            Band(name="QC_Night", description="Night Quality control for LST and emissivity"),
            Band(name="View_Angle_Day", description="Day View zenith angle of LST"),
            Band(name="View_Angle_Night", description="Night View zenith angle of LST"),
            Band(name="View_Time_Day", description="Day Time of LST observation"),
            Band(name="View_Time_Night", description="Night Time of LST observation"),
        ]
    ),
    Product(
        product_id="VJ121A2.002",
        description="Land Surface Temperature and Emissivity (LST&E)",
        bands=[
            Band(name="Emis_14", description="M14 emissivity"),
            Band(name="Emis_15", description="M15 emissivity"),
            Band(name="Emis_16", description="M16 emissivity"),
            Band(name="LST_Day_1KM", description="Day Land Surface Temperature"),
            Band(name="LST_Night_1KM", description="Night 1 km Land Surface Temperature"),
            Band(name="QC_Day", description="Day Quality control for LST and emissivity"),
            Band(name="QC_Night", description="Night Quality control for LST and emissivity"),
            Band(name="View_Angle_Day", description="Day View zenith angle of LST"),
            Band(name="View_Angle_Night", description="Night View zenith angle of LST"),
            Band(name="View_Time_Day", description="Day Time of LST observation"),
            Band(name="View_Time_Night", description="Night Time of LST observation"),
        ]
    ),
    Product(
        product_id="VNP09A1.002",
        description="Surface Reflectance",
        bands=[
            Band(name="RelativeAzimuth", description="Relative_azimuth"),
            Band(name="SensorZenith", description="View_zenith"),
            Band(name="SolarZenith", description="Solar_zenith"),
            Band(name="SurfReflect_Day_Of_Year", description="Surface_reflectance_day_of_year"),
            Band(name="SurfReflect_M1", description="1 km Surface Reflectance Band M1"),
            Band(name="SurfReflect_M10", description="1 km Surface Reflectance Band M10"),
            Band(name="SurfReflect_M11", description="1 km Surface Reflectance Band M11"),
            Band(name="SurfReflect_M2", description="1 km Surface Reflectance Band M2"),
            Band(name="SurfReflect_M3", description="1 km Surface Reflectance Band M3"),
            Band(name="SurfReflect_M4", description="1 km Surface Reflectance Band M4"),
            Band(name="SurfReflect_M5", description="1 km Surface Reflectance Band M5"),
            Band(name="SurfReflect_M7", description="1 km Surface Reflectance Band M7"),
            Band(name="SurfReflect_M8", description="1 km Surface Reflectance Band M8"),
            Band(name="SurfReflect_QC", description="Surface_reflectance_500m_quality_control_flags"),
            Band(name="SurfReflect_State", description="Surface_reflectance_500m_state_flags"),
        ]
    ),
    Product(
        product_id="VJ109A1.002",
        description="Surface Reflectance",
        bands=[
            Band(name="RelativeAzimuth", description="Relative_azimuth"),
            Band(name="SensorZenith", description="View_zenith"),
            Band(name="SolarZenith", description="Solar_zenith"),
            Band(name="SurfReflect_Day_Of_Year", description="Surface_reflectance_day_of_year"),
            Band(name="SurfReflect_M1", description="1 km Surface Reflectance Band M1"),
            Band(name="SurfReflect_M10", description="1 km Surface Reflectance Band M10"),
            Band(name="SurfReflect_M11", description="1 km Surface Reflectance Band M11"),
            Band(name="SurfReflect_M2", description="1 km Surface Reflectance Band M2"),
            Band(name="SurfReflect_M3", description="1 km Surface Reflectance Band M3"),
            Band(name="SurfReflect_M4", description="1 km Surface Reflectance Band M4"),
            Band(name="SurfReflect_M5", description="1 km Surface Reflectance Band M5"),
            Band(name="SurfReflect_M7", description="1 km Surface Reflectance Band M7"),
            Band(name="SurfReflect_M8", description="1 km Surface Reflectance Band M8"),
            Band(name="SurfReflect_QC", description="Surface_reflectance_500m_quality_control_flags"),
            Band(name="SurfReflect_State", description="Surface_reflectance_500m_state_flags"),
        ]
    ),
    Product(
        product_id="VNP09GA.002",
        description="Surface Reflectance",
        bands=[
            Band(name="SensorAzimuth_1", description="Sensor Azimuth Angle"),
            Band(name="SensorZenith_1", description="Sensor Zenith Angle"),
            Band(name="SolarAzimuth_1", description="Solar Azimuth Angle"),
            Band(name="SolarZenith_1", description="Solar Zenith Angle"),
            Band(name="SurfReflect_I1_1", description="Imagery (375m) Surface Reflectance Band 1"),
            Band(name="SurfReflect_I2_1", description="Imagery (375m) Surface Reflectance Band 2"),
            Band(name="SurfReflect_I3_1", description="Imagery (375m) Surface Reflectance Band 3"),
            Band(name="SurfReflect_M10_1", description="Moderate (750m) Surface Reflectance Band 10"),
            Band(name="SurfReflect_M11_1", description="Moderate (750m) Surface Reflectance Band 11"),
            Band(name="SurfReflect_M1_1", description="Moderate (750m) Surface Reflectance Band 1"),
            Band(name="SurfReflect_M2_1", description="Moderate (750m) Surface Reflectance Band 2"),
            Band(name="SurfReflect_M3_1", description="Moderate (750m) Surface Reflectance Band 3"),
            Band(name="SurfReflect_M4_1", description="Moderate (750m) Surface Reflectance Band 4"),
            Band(name="SurfReflect_M5_1", description="Moderate (750m) Surface Reflectance Band 5"),
            Band(name="SurfReflect_M7_1", description="Moderate (750m) Surface Reflectance Band 7"),
            Band(name="SurfReflect_M8_1", description="Moderate (750m) Surface Reflectance Band 8"),
            Band(name="SurfReflect_QF1_1", description="Moderate (750m) Land Quality Flags Byte 1"),
            Band(name="SurfReflect_QF2_1", description="Moderate (750m) Land Quality Flags Byte 2"),
            Band(name="SurfReflect_QF3_1", description="Moderate (750m) Land Quality Flags Byte 3"),
            Band(name="SurfReflect_QF4_1", description="Moderate (750m) Land Quality Flags Byte 4"),
            Band(name="SurfReflect_QF5_1", description="Moderate (750m) Land Quality Flags Byte 5"),
            Band(name="SurfReflect_QF6_1", description="Moderate (750m) Land Quality Flags Byte 6"),
            Band(name="SurfReflect_QF7_1", description="Moderate (750m) Land Quality Flags Byte 7"),
            Band(name="iobs_res_1", description="observation number in coarser grid - first layer"),
            Band(name="land_water_mask_1", description="Moderate (750m) Land Water Mask"),
            Band(name="num_observations_1km", description="Number of additional observations per row"),
            Band(name="num_observations_500m", description="Number of Observations"),
            Band(name="obscov_1km_1", description="Observations coverage 1 km"),
            Band(name="obscov_500m_1", description="Observation coverage - first layer"),
            Band(name="orbit_pnt_1", description="Orbit Pointer"),
        ]
    ),
    Product(
        product_id="VJ109GA.002",
        description="Surface Reflectance",
        bands=[
            Band(name="SensorAzimuth_1", description="Sensor Azimuth Angle"),
            Band(name="SensorZenith_1", description="Sensor Zenith Angle"),
            Band(name="SolarAzimuth_1", description="Solar Azimuth Angle"),
            Band(name="SolarZenith_1", description="Solar Zenith Angle"),
            Band(name="SurfReflect_I1_1", description="Imagery (375m) Surface Reflectance Band 1"),
            Band(name="SurfReflect_I2_1", description="Imagery (375m) Surface Reflectance Band 2"),
            Band(name="SurfReflect_I3_1", description="Imagery (375m) Surface Reflectance Band 3"),
            Band(name="SurfReflect_M10_1", description="Moderate (750m) Surface Reflectance Band 10"),
            Band(name="SurfReflect_M11_1", description="Moderate (750m) Surface Reflectance Band 11"),
            Band(name="SurfReflect_M1_1", description="Moderate (750m) Surface Reflectance Band 1"),
            Band(name="SurfReflect_M2_1", description="Moderate (750m) Surface Reflectance Band 2"),
            Band(name="SurfReflect_M3_1", description="Moderate (750m) Surface Reflectance Band 3"),
            Band(name="SurfReflect_M4_1", description="Moderate (750m) Surface Reflectance Band 4"),
            Band(name="SurfReflect_M5_1", description="Moderate (750m) Surface Reflectance Band 5"),
            Band(name="SurfReflect_M7_1", description="Moderate (750m) Surface Reflectance Band 7"),
            Band(name="SurfReflect_M8_1", description="Moderate (750m) Surface Reflectance Band 8"),
            Band(name="SurfReflect_QF1_1", description="Moderate (750m) Land Quality Flags Byte 1"),
            Band(name="SurfReflect_QF2_1", description="Moderate (750m) Land Quality Flags Byte 2"),
            Band(name="SurfReflect_QF3_1", description="Moderate (750m) Land Quality Flags Byte 3"),
            Band(name="SurfReflect_QF4_1", description="Moderate (750m) Land Quality Flags Byte 4"),
            Band(name="SurfReflect_QF5_1", description="Moderate (750m) Land Quality Flags Byte 5"),
            Band(name="SurfReflect_QF6_1", description="Moderate (750m) Land Quality Flags Byte 6"),
            Band(name="SurfReflect_QF7_1", description="Moderate (750m) Land Quality Flags Byte 7"),
            Band(name="iobs_res_1", description="observation number in coarser grid - first layer"),
            Band(name="land_water_mask_1", description="Moderate (750m) Land Water Mask"),
            Band(name="num_observations_1km", description="Number of additional observations per row"),
            Band(name="num_observations_500m", description="Number of Observations"),
            Band(name="obscov_1km_1", description="Observations coverage 1 km"),
            Band(name="obscov_500m_1", description="Observation coverage - first layer"),
            Band(name="orbit_pnt_1", description="Orbit Pointer"),
        ]
    ),
    Product(
        product_id="VNP09H1.002",
        description="Surface Reflectance",
        bands=[
            Band(name="SurfReflect_I1", description="Surface_reflectance_for_band_I1"),
            Band(name="SurfReflect_I2", description="Surface_reflectance_for_band_I2"),
            Band(name="SurfReflect_I3", description="Surface_reflectance_for_band_I3"),
            Band(name="SurfReflect_QC_500m", description="Surface_reflectance_250m_quality_control_flags"),
            Band(name="SurfReflect_State_500m", description="Surface_reflectance_250m_state_flags"),
        ]
    ),
    Product(
        product_id="VJ109H1.002",
        description="Surface Reflectance",
        bands=[
            Band(name="SurfReflect_I1", description="Surface_reflectance_for_band_I1"),
            Band(name="SurfReflect_I2", description="Surface_reflectance_for_band_I2"),
            Band(name="SurfReflect_I3", description="Surface_reflectance_for_band_I3"),
            Band(name="SurfReflect_QC_500m", description="Surface_reflectance_250m_quality_control_flags"),
            Band(name="SurfReflect_State_500m", description="Surface_reflectance_250m_state_flags"),
        ]
    ),
    Product(
        product_id="EMIT_L1B_RAD.001",
        description="At-Sensor Calibrated Radiance and Geolocation Data",
        bands=[
            Band(name="B001", description="Radiance for Wavelength: 381.006 nm, FWHM: 8.415 nm"),
            Band(name="B002", description="Radiance for Wavelength: 388.409 nm, FWHM: 8.415 nm"),
            Band(name="B003", description="Radiance for Wavelength: 395.816 nm, FWHM: 8.415 nm"),
            Band(name="B004", description="Radiance for Wavelength: 403.225 nm, FWHM: 8.415 nm"),
            Band(name="B005", description="Radiance for Wavelength: 410.638 nm, FWHM: 8.417 nm"),
            Band(name="B006", description="Radiance for Wavelength: 418.054 nm, FWHM: 8.418 nm"),
            Band(name="B007", description="Radiance for Wavelength: 425.472 nm, FWHM: 8.419 nm"),
            Band(name="B008", description="Radiance for Wavelength: 432.893 nm, FWHM: 8.421 nm"),
            Band(name="B009", description="Radiance for Wavelength: 440.317 nm, FWHM: 8.422 nm"),
            Band(name="B010", description="Radiance for Wavelength: 447.743 nm, FWHM: 8.424 nm"),
            Band(name="B011", description="Radiance for Wavelength: 455.170 nm, FWHM: 8.425 nm"),
            Band(name="B012", description="Radiance for Wavelength: 462.599 nm, FWHM: 8.426 nm"),
            Band(name="B013", description="Radiance for Wavelength: 470.030 nm, FWHM: 8.428 nm"),
            Band(name="B014", description="Radiance for Wavelength: 477.463 nm, FWHM: 8.429 nm"),
            Band(name="B015", description="Radiance for Wavelength: 484.897 nm, FWHM: 8.431 nm"),
            Band(name="B016", description="Radiance for Wavelength: 492.333 nm, FWHM: 8.432 nm"),
            Band(name="B017", description="Radiance for Wavelength: 499.771 nm, FWHM: 8.433 nm"),
            Band(name="B018", description="Radiance for Wavelength: 507.210 nm, FWHM: 8.435 nm"),
            Band(name="B019", description="Radiance for Wavelength: 514.650 nm, FWHM: 8.436 nm"),
            Band(name="B020", description="Radiance for Wavelength: 522.091 nm, FWHM: 8.438 nm"),
            Band(name="B021", description="Radiance for Wavelength: 529.533 nm, FWHM: 8.439 nm"),
            Band(name="B022", description="Radiance for Wavelength: 536.977 nm, FWHM: 8.440 nm"),
            Band(name="B023", description="Radiance for Wavelength: 544.421 nm, FWHM: 8.442 nm"),
            Band(name="B024", description="Radiance for Wavelength: 551.867 nm, FWHM: 8.443 nm"),
            Band(name="B025", description="Radiance for Wavelength: 559.314 nm, FWHM: 8.445 nm"),
            Band(name="B026", description="Radiance for Wavelength: 566.762 nm, FWHM: 8.446 nm"),
            Band(name="B027", description="Radiance for Wavelength: 574.209 nm, FWHM: 8.447 nm"),
            Band(name="B028", description="Radiance for Wavelength: 581.659 nm, FWHM: 8.449 nm"),
            Band(name="B029", description="Radiance for Wavelength: 589.108 nm, FWHM: 8.450 nm"),
            Band(name="B030", description="Radiance for Wavelength: 596.558 nm, FWHM: 8.452 nm"),
            Band(name="B031", description="Radiance for Wavelength: 604.010 nm, FWHM: 8.453 nm"),
            Band(name="B032", description="Radiance for Wavelength: 611.462 nm, FWHM: 8.454 nm"),
            Band(name="B033", description="Radiance for Wavelength: 618.915 nm, FWHM: 8.456 nm"),
            Band(name="B034", description="Radiance for Wavelength: 626.368 nm, FWHM: 8.457 nm"),
            Band(name="B035", description="Radiance for Wavelength: 633.821 nm, FWHM: 8.459 nm"),
            Band(name="B036", description="Radiance for Wavelength: 641.276 nm, FWHM: 8.460 nm"),
            Band(name="B037", description="Radiance for Wavelength: 648.730 nm, FWHM: 8.461 nm"),
            Band(name="B038", description="Radiance for Wavelength: 656.186 nm, FWHM: 8.463 nm"),
            Band(name="B039", description="Radiance for Wavelength: 663.641 nm, FWHM: 8.464 nm"),
            Band(name="B040", description="Radiance for Wavelength: 671.098 nm, FWHM: 8.466 nm"),
            Band(name="B041", description="Radiance for Wavelength: 678.554 nm, FWHM: 8.467 nm"),
            Band(name="B042", description="Radiance for Wavelength: 686.010 nm, FWHM: 8.468 nm"),
            Band(name="B043", description="Radiance for Wavelength: 693.468 nm, FWHM: 8.470 nm"),
            Band(name="B044", description="Radiance for Wavelength: 700.925 nm, FWHM: 8.471 nm"),
            Band(name="B045", description="Radiance for Wavelength: 708.384 nm, FWHM: 8.473 nm"),
            Band(name="B046", description="Radiance for Wavelength: 715.841 nm, FWHM: 8.474 nm"),
            Band(name="B047", description="Radiance for Wavelength: 723.299 nm, FWHM: 8.475 nm"),
            Band(name="B048", description="Radiance for Wavelength: 730.759 nm, FWHM: 8.477 nm"),
            Band(name="B049", description="Radiance for Wavelength: 738.217 nm, FWHM: 8.478 nm"),
            Band(name="B050", description="Radiance for Wavelength: 745.677 nm, FWHM: 8.480 nm"),
            Band(name="B051", description="Radiance for Wavelength: 753.136 nm, FWHM: 8.481 nm"),
            Band(name="B052", description="Radiance for Wavelength: 760.596 nm, FWHM: 8.482 nm"),
            Band(name="B053", description="Radiance for Wavelength: 768.056 nm, FWHM: 8.484 nm"),
            Band(name="B054", description="Radiance for Wavelength: 775.516 nm, FWHM: 8.485 nm"),
            Band(name="B055", description="Radiance for Wavelength: 782.978 nm, FWHM: 8.487 nm"),
            Band(name="B056", description="Radiance for Wavelength: 790.438 nm, FWHM: 8.488 nm"),
            Band(name="B057", description="Radiance for Wavelength: 797.899 nm, FWHM: 8.489 nm"),
            Band(name="B058", description="Radiance for Wavelength: 805.362 nm, FWHM: 8.491 nm"),
            Band(name="B059", description="Radiance for Wavelength: 812.823 nm, FWHM: 8.492 nm"),
            Band(name="B060", description="Radiance for Wavelength: 820.285 nm, FWHM: 8.494 nm"),
            Band(name="B061", description="Radiance for Wavelength: 827.746 nm, FWHM: 8.495 nm"),
            Band(name="B062", description="Radiance for Wavelength: 835.207 nm, FWHM: 8.496 nm"),
            Band(name="B063", description="Radiance for Wavelength: 842.670 nm, FWHM: 8.498 nm"),
            Band(name="B064", description="Radiance for Wavelength: 850.131 nm, FWHM: 8.499 nm"),
            Band(name="B065", description="Radiance for Wavelength: 857.594 nm, FWHM: 8.501 nm"),
            Band(name="B066", description="Radiance for Wavelength: 865.055 nm, FWHM: 8.502 nm"),
            Band(name="B067", description="Radiance for Wavelength: 872.518 nm, FWHM: 8.503 nm"),
            Band(name="B068", description="Radiance for Wavelength: 879.980 nm, FWHM: 8.505 nm"),
            Band(name="B069", description="Radiance for Wavelength: 887.441 nm, FWHM: 8.506 nm"),
            Band(name="B070", description="Radiance for Wavelength: 894.904 nm, FWHM: 8.508 nm"),
            Band(name="B071", description="Radiance for Wavelength: 902.366 nm, FWHM: 8.509 nm"),
            Band(name="B072", description="Radiance for Wavelength: 909.829 nm, FWHM: 8.510 nm"),
            Band(name="B073", description="Radiance for Wavelength: 917.291 nm, FWHM: 8.512 nm"),
            Band(name="B074", description="Radiance for Wavelength: 924.754 nm, FWHM: 8.513 nm"),
            Band(name="B075", description="Radiance for Wavelength: 932.216 nm, FWHM: 8.515 nm"),
            Band(name="B076", description="Radiance for Wavelength: 939.679 nm, FWHM: 8.516 nm"),
            Band(name="B077", description="Radiance for Wavelength: 947.140 nm, FWHM: 8.517 nm"),
            Band(name="B078", description="Radiance for Wavelength: 954.603 nm, FWHM: 8.519 nm"),
            Band(name="B079", description="Radiance for Wavelength: 962.064 nm, FWHM: 8.520 nm"),
            Band(name="B080", description="Radiance for Wavelength: 969.527 nm, FWHM: 8.522 nm"),
            Band(name="B081", description="Radiance for Wavelength: 976.988 nm, FWHM: 8.523 nm"),
            Band(name="B082", description="Radiance for Wavelength: 984.450 nm, FWHM: 8.524 nm"),
            Band(name="B083", description="Radiance for Wavelength: 991.911 nm, FWHM: 8.526 nm"),
            Band(name="B084", description="Radiance for Wavelength: 999.373 nm, FWHM: 8.527 nm"),
            Band(name="B085", description="Radiance for Wavelength: 1006.834 nm, FWHM: 8.529 nm"),
            Band(name="B086", description="Radiance for Wavelength: 1014.295 nm, FWHM: 8.530 nm"),
            Band(name="B087", description="Radiance for Wavelength: 1021.757 nm, FWHM: 8.531 nm"),
            Band(name="B088", description="Radiance for Wavelength: 1029.217 nm, FWHM: 8.533 nm"),
            Band(name="B089", description="Radiance for Wavelength: 1036.678 nm, FWHM: 8.534 nm"),
            Band(name="B090", description="Radiance for Wavelength: 1044.138 nm, FWHM: 8.536 nm"),
            Band(name="B091", description="Radiance for Wavelength: 1051.599 nm, FWHM: 8.537 nm"),
            Band(name="B092", description="Radiance for Wavelength: 1059.060 nm, FWHM: 8.538 nm"),
            Band(name="B093", description="Radiance for Wavelength: 1066.520 nm, FWHM: 8.540 nm"),
            Band(name="B094", description="Radiance for Wavelength: 1073.980 nm, FWHM: 8.541 nm"),
            Band(name="B095", description="Radiance for Wavelength: 1081.440 nm, FWHM: 8.543 nm"),
            Band(name="B096", description="Radiance for Wavelength: 1088.900 nm, FWHM: 8.544 nm"),
            Band(name="B097", description="Radiance for Wavelength: 1096.360 nm, FWHM: 8.545 nm"),
            Band(name="B098", description="Radiance for Wavelength: 1103.818 nm, FWHM: 8.547 nm"),
            Band(name="B099", description="Radiance for Wavelength: 1111.278 nm, FWHM: 8.548 nm"),
            Band(name="B100", description="Radiance for Wavelength: 1118.737 nm, FWHM: 8.550 nm"),
            Band(name="B101", description="Radiance for Wavelength: 1126.196 nm, FWHM: 8.551 nm"),
            Band(name="B102", description="Radiance for Wavelength: 1133.655 nm, FWHM: 8.552 nm"),
            Band(name="B103", description="Radiance for Wavelength: 1141.113 nm, FWHM: 8.554 nm"),
            Band(name="B104", description="Radiance for Wavelength: 1148.572 nm, FWHM: 8.555 nm"),
            Band(name="B105", description="Radiance for Wavelength: 1156.030 nm, FWHM: 8.557 nm"),
            Band(name="B106", description="Radiance for Wavelength: 1163.488 nm, FWHM: 8.558 nm"),
            Band(name="B107", description="Radiance for Wavelength: 1170.946 nm, FWHM: 8.559 nm"),
            Band(name="B108", description="Radiance for Wavelength: 1178.404 nm, FWHM: 8.561 nm"),
            Band(name="B109", description="Radiance for Wavelength: 1185.862 nm, FWHM: 8.562 nm"),
            Band(name="B110", description="Radiance for Wavelength: 1193.318 nm, FWHM: 8.564 nm"),
            Band(name="B111", description="Radiance for Wavelength: 1200.776 nm, FWHM: 8.565 nm"),
            Band(name="B112", description="Radiance for Wavelength: 1208.233 nm, FWHM: 8.566 nm"),
            Band(name="B113", description="Radiance for Wavelength: 1215.690 nm, FWHM: 8.568 nm"),
            Band(name="B114", description="Radiance for Wavelength: 1223.147 nm, FWHM: 8.569 nm"),
            Band(name="B115", description="Radiance for Wavelength: 1230.604 nm, FWHM: 8.571 nm"),
            Band(name="B116", description="Radiance for Wavelength: 1238.060 nm, FWHM: 8.572 nm"),
            Band(name="B117", description="Radiance for Wavelength: 1245.515 nm, FWHM: 8.573 nm"),
            Band(name="B118", description="Radiance for Wavelength: 1252.972 nm, FWHM: 8.575 nm"),
            Band(name="B119", description="Radiance for Wavelength: 1260.428 nm, FWHM: 8.576 nm"),
            Band(name="B120", description="Radiance for Wavelength: 1267.883 nm, FWHM: 8.578 nm"),
            Band(name="B121", description="Radiance for Wavelength: 1275.339 nm, FWHM: 8.579 nm"),
            Band(name="B122", description="Radiance for Wavelength: 1282.794 nm, FWHM: 8.580 nm"),
            Band(name="B123", description="Radiance for Wavelength: 1290.250 nm, FWHM: 8.582 nm"),
            Band(name="B124", description="Radiance for Wavelength: 1297.705 nm, FWHM: 8.583 nm"),
            Band(name="B125", description="Radiance for Wavelength: 1305.160 nm, FWHM: 8.585 nm"),
            Band(name="B126", description="Radiance for Wavelength: 1312.614 nm, FWHM: 8.586 nm"),
            Band(name="B127", description="Radiance for Wavelength: 1320.068 nm, FWHM: 8.587 nm"),
            Band(name="B128", description="Radiance for Wavelength: 1327.522 nm, FWHM: 8.589 nm"),
            Band(name="B129", description="Radiance for Wavelength: 1334.976 nm, FWHM: 8.590 nm"),
            Band(name="B130", description="Radiance for Wavelength: 1342.429 nm, FWHM: 8.592 nm"),
            Band(name="B131", description="Radiance for Wavelength: 1349.882 nm, FWHM: 8.593 nm"),
            Band(name="B132", description="Radiance for Wavelength: 1357.335 nm, FWHM: 8.594 nm"),
            Band(name="B133", description="Radiance for Wavelength: 1364.787 nm, FWHM: 8.596 nm"),
            Band(name="B134", description="Radiance for Wavelength: 1372.238 nm, FWHM: 8.597 nm"),
            Band(name="B135", description="Radiance for Wavelength: 1379.691 nm, FWHM: 8.599 nm"),
            Band(name="B136", description="Radiance for Wavelength: 1387.142 nm, FWHM: 8.600 nm"),
            Band(name="B137", description="Radiance for Wavelength: 1394.593 nm, FWHM: 8.601 nm"),
            Band(name="B138", description="Radiance for Wavelength: 1402.043 nm, FWHM: 8.603 nm"),
            Band(name="B139", description="Radiance for Wavelength: 1409.494 nm, FWHM: 8.604 nm"),
            Band(name="B140", description="Radiance for Wavelength: 1416.944 nm, FWHM: 8.606 nm"),
            Band(name="B141", description="Radiance for Wavelength: 1424.393 nm, FWHM: 8.607 nm"),
            Band(name="B142", description="Radiance for Wavelength: 1431.843 nm, FWHM: 8.608 nm"),
            Band(name="B143", description="Radiance for Wavelength: 1439.292 nm, FWHM: 8.610 nm"),
            Band(name="B144", description="Radiance for Wavelength: 1446.740 nm, FWHM: 8.611 nm"),
            Band(name="B145", description="Radiance for Wavelength: 1454.189 nm, FWHM: 8.613 nm"),
            Band(name="B146", description="Radiance for Wavelength: 1461.637 nm, FWHM: 8.614 nm"),
            Band(name="B147", description="Radiance for Wavelength: 1469.085 nm, FWHM: 8.615 nm"),
            Band(name="B148", description="Radiance for Wavelength: 1476.532 nm, FWHM: 8.617 nm"),
            Band(name="B149", description="Radiance for Wavelength: 1483.980 nm, FWHM: 8.618 nm"),
            Band(name="B150", description="Radiance for Wavelength: 1491.426 nm, FWHM: 8.620 nm"),
            Band(name="B151", description="Radiance for Wavelength: 1498.873 nm, FWHM: 8.621 nm"),
            Band(name="B152", description="Radiance for Wavelength: 1506.319 nm, FWHM: 8.622 nm"),
            Band(name="B153", description="Radiance for Wavelength: 1513.765 nm, FWHM: 8.624 nm"),
            Band(name="B154", description="Radiance for Wavelength: 1521.210 nm, FWHM: 8.625 nm"),
            Band(name="B155", description="Radiance for Wavelength: 1528.655 nm, FWHM: 8.627 nm"),
            Band(name="B156", description="Radiance for Wavelength: 1536.101 nm, FWHM: 8.628 nm"),
            Band(name="B157", description="Radiance for Wavelength: 1543.545 nm, FWHM: 8.629 nm"),
            Band(name="B158", description="Radiance for Wavelength: 1550.989 nm, FWHM: 8.631 nm"),
            Band(name="B159", description="Radiance for Wavelength: 1558.433 nm, FWHM: 8.632 nm"),
            Band(name="B160", description="Radiance for Wavelength: 1565.877 nm, FWHM: 8.634 nm"),
            Band(name="B161", description="Radiance for Wavelength: 1573.319 nm, FWHM: 8.635 nm"),
            Band(name="B162", description="Radiance for Wavelength: 1580.762 nm, FWHM: 8.636 nm"),
            Band(name="B163", description="Radiance for Wavelength: 1588.205 nm, FWHM: 8.638 nm"),
            Band(name="B164", description="Radiance for Wavelength: 1595.647 nm, FWHM: 8.639 nm"),
            Band(name="B165", description="Radiance for Wavelength: 1603.089 nm, FWHM: 8.641 nm"),
            Band(name="B166", description="Radiance for Wavelength: 1610.530 nm, FWHM: 8.642 nm"),
            Band(name="B167", description="Radiance for Wavelength: 1617.970 nm, FWHM: 8.643 nm"),
            Band(name="B168", description="Radiance for Wavelength: 1625.410 nm, FWHM: 8.645 nm"),
            Band(name="B169", description="Radiance for Wavelength: 1632.851 nm, FWHM: 8.646 nm"),
            Band(name="B170", description="Radiance for Wavelength: 1640.290 nm, FWHM: 8.648 nm"),
            Band(name="B171", description="Radiance for Wavelength: 1647.730 nm, FWHM: 8.649 nm"),
            Band(name="B172", description="Radiance for Wavelength: 1655.169 nm, FWHM: 8.650 nm"),
            Band(name="B173", description="Radiance for Wavelength: 1662.607 nm, FWHM: 8.652 nm"),
            Band(name="B174", description="Radiance for Wavelength: 1670.046 nm, FWHM: 8.653 nm"),
            Band(name="B175", description="Radiance for Wavelength: 1677.484 nm, FWHM: 8.655 nm"),
            Band(name="B176", description="Radiance for Wavelength: 1684.921 nm, FWHM: 8.656 nm"),
            Band(name="B177", description="Radiance for Wavelength: 1692.358 nm, FWHM: 8.657 nm"),
            Band(name="B178", description="Radiance for Wavelength: 1699.795 nm, FWHM: 8.659 nm"),
            Band(name="B179", description="Radiance for Wavelength: 1707.231 nm, FWHM: 8.660 nm"),
            Band(name="B180", description="Radiance for Wavelength: 1714.667 nm, FWHM: 8.662 nm"),
            Band(name="B181", description="Radiance for Wavelength: 1722.103 nm, FWHM: 8.663 nm"),
            Band(name="B182", description="Radiance for Wavelength: 1729.538 nm, FWHM: 8.664 nm"),
            Band(name="B183", description="Radiance for Wavelength: 1736.973 nm, FWHM: 8.666 nm"),
            Band(name="B184", description="Radiance for Wavelength: 1744.407 nm, FWHM: 8.667 nm"),
            Band(name="B185", description="Radiance for Wavelength: 1751.841 nm, FWHM: 8.669 nm"),
            Band(name="B186", description="Radiance for Wavelength: 1759.275 nm, FWHM: 8.670 nm"),
            Band(name="B187", description="Radiance for Wavelength: 1766.708 nm, FWHM: 8.671 nm"),
            Band(name="B188", description="Radiance for Wavelength: 1774.142 nm, FWHM: 8.673 nm"),
            Band(name="B189", description="Radiance for Wavelength: 1781.574 nm, FWHM: 8.674 nm"),
            Band(name="B190", description="Radiance for Wavelength: 1789.007 nm, FWHM: 8.676 nm"),
            Band(name="B191", description="Radiance for Wavelength: 1796.438 nm, FWHM: 8.677 nm"),
            Band(name="B192", description="Radiance for Wavelength: 1803.870 nm, FWHM: 8.678 nm"),
            Band(name="B193", description="Radiance for Wavelength: 1811.301 nm, FWHM: 8.680 nm"),
            Band(name="B194", description="Radiance for Wavelength: 1818.731 nm, FWHM: 8.681 nm"),
            Band(name="B195", description="Radiance for Wavelength: 1826.161 nm, FWHM: 8.683 nm"),
            Band(name="B196", description="Radiance for Wavelength: 1833.591 nm, FWHM: 8.684 nm"),
            Band(name="B197", description="Radiance for Wavelength: 1841.021 nm, FWHM: 8.685 nm"),
            Band(name="B198", description="Radiance for Wavelength: 1848.449 nm, FWHM: 8.687 nm"),
            Band(name="B199", description="Radiance for Wavelength: 1855.877 nm, FWHM: 8.688 nm"),
            Band(name="B200", description="Radiance for Wavelength: 1863.305 nm, FWHM: 8.690 nm"),
            Band(name="B201", description="Radiance for Wavelength: 1870.733 nm, FWHM: 8.691 nm"),
            Band(name="B202", description="Radiance for Wavelength: 1878.160 nm, FWHM: 8.692 nm"),
            Band(name="B203", description="Radiance for Wavelength: 1885.587 nm, FWHM: 8.694 nm"),
            Band(name="B204", description="Radiance for Wavelength: 1893.013 nm, FWHM: 8.695 nm"),
            Band(name="B205", description="Radiance for Wavelength: 1900.439 nm, FWHM: 8.697 nm"),
            Band(name="B206", description="Radiance for Wavelength: 1907.864 nm, FWHM: 8.698 nm"),
            Band(name="B207", description="Radiance for Wavelength: 1915.289 nm, FWHM: 8.699 nm"),
            Band(name="B208", description="Radiance for Wavelength: 1922.713 nm, FWHM: 8.701 nm"),
            Band(name="B209", description="Radiance for Wavelength: 1930.137 nm, FWHM: 8.702 nm"),
            Band(name="B210", description="Radiance for Wavelength: 1937.561 nm, FWHM: 8.704 nm"),
            Band(name="B211", description="Radiance for Wavelength: 1944.984 nm, FWHM: 8.705 nm"),
            Band(name="B212", description="Radiance for Wavelength: 1952.407 nm, FWHM: 8.706 nm"),
            Band(name="B213", description="Radiance for Wavelength: 1959.829 nm, FWHM: 8.708 nm"),
            Band(name="B214", description="Radiance for Wavelength: 1967.252 nm, FWHM: 8.709 nm"),
            Band(name="B215", description="Radiance for Wavelength: 1974.673 nm, FWHM: 8.711 nm"),
            Band(name="B216", description="Radiance for Wavelength: 1982.095 nm, FWHM: 8.712 nm"),
            Band(name="B217", description="Radiance for Wavelength: 1989.515 nm, FWHM: 8.714 nm"),
            Band(name="B218", description="Radiance for Wavelength: 1996.936 nm, FWHM: 8.715 nm"),
            Band(name="B219", description="Radiance for Wavelength: 2004.355 nm, FWHM: 8.716 nm"),
            Band(name="B220", description="Radiance for Wavelength: 2011.775 nm, FWHM: 8.718 nm"),
            Band(name="B221", description="Radiance for Wavelength: 2019.193 nm, FWHM: 8.719 nm"),
            Band(name="B222", description="Radiance for Wavelength: 2026.612 nm, FWHM: 8.721 nm"),
            Band(name="B223", description="Radiance for Wavelength: 2034.030 nm, FWHM: 8.722 nm"),
            Band(name="B224", description="Radiance for Wavelength: 2041.447 nm, FWHM: 8.723 nm"),
            Band(name="B225", description="Radiance for Wavelength: 2048.865 nm, FWHM: 8.725 nm"),
            Band(name="B226", description="Radiance for Wavelength: 2056.281 nm, FWHM: 8.726 nm"),
            Band(name="B227", description="Radiance for Wavelength: 2063.697 nm, FWHM: 8.727 nm"),
            Band(name="B228", description="Radiance for Wavelength: 2071.112 nm, FWHM: 8.729 nm"),
            Band(name="B229", description="Radiance for Wavelength: 2078.527 nm, FWHM: 8.730 nm"),
            Band(name="B230", description="Radiance for Wavelength: 2085.942 nm, FWHM: 8.732 nm"),
            Band(name="B231", description="Radiance for Wavelength: 2093.356 nm, FWHM: 8.733 nm"),
            Band(name="B232", description="Radiance for Wavelength: 2100.769 nm, FWHM: 8.734 nm"),
            Band(name="B233", description="Radiance for Wavelength: 2108.182 nm, FWHM: 8.736 nm"),
            Band(name="B234", description="Radiance for Wavelength: 2115.594 nm, FWHM: 8.737 nm"),
            Band(name="B235", description="Radiance for Wavelength: 2123.006 nm, FWHM: 8.739 nm"),
            Band(name="B236", description="Radiance for Wavelength: 2130.417 nm, FWHM: 8.740 nm"),
            Band(name="B237", description="Radiance for Wavelength: 2137.829 nm, FWHM: 8.741 nm"),
            Band(name="B238", description="Radiance for Wavelength: 2145.239 nm, FWHM: 8.743 nm"),
            Band(name="B239", description="Radiance for Wavelength: 2152.648 nm, FWHM: 8.744 nm"),
            Band(name="B240", description="Radiance for Wavelength: 2160.058 nm, FWHM: 8.746 nm"),
            Band(name="B241", description="Radiance for Wavelength: 2167.467 nm, FWHM: 8.747 nm"),
            Band(name="B242", description="Radiance for Wavelength: 2174.875 nm, FWHM: 8.748 nm"),
            Band(name="B243", description="Radiance for Wavelength: 2182.283 nm, FWHM: 8.750 nm"),
            Band(name="B244", description="Radiance for Wavelength: 2189.690 nm, FWHM: 8.751 nm"),
            Band(name="B245", description="Radiance for Wavelength: 2197.097 nm, FWHM: 8.753 nm"),
            Band(name="B246", description="Radiance for Wavelength: 2204.503 nm, FWHM: 8.754 nm"),
            Band(name="B247", description="Radiance for Wavelength: 2211.909 nm, FWHM: 8.755 nm"),
            Band(name="B248", description="Radiance for Wavelength: 2219.315 nm, FWHM: 8.757 nm"),
            Band(name="B249", description="Radiance for Wavelength: 2226.719 nm, FWHM: 8.758 nm"),
            Band(name="B250", description="Radiance for Wavelength: 2234.123 nm, FWHM: 8.760 nm"),
            Band(name="B251", description="Radiance for Wavelength: 2241.527 nm, FWHM: 8.761 nm"),
            Band(name="B252", description="Radiance for Wavelength: 2248.930 nm, FWHM: 8.763 nm"),
            Band(name="B253", description="Radiance for Wavelength: 2256.333 nm, FWHM: 8.764 nm"),
            Band(name="B254", description="Radiance for Wavelength: 2263.735 nm, FWHM: 8.765 nm"),
            Band(name="B255", description="Radiance for Wavelength: 2271.136 nm, FWHM: 8.767 nm"),
            Band(name="B256", description="Radiance for Wavelength: 2278.538 nm, FWHM: 8.768 nm"),
            Band(name="B257", description="Radiance for Wavelength: 2285.939 nm, FWHM: 8.770 nm"),
            Band(name="B258", description="Radiance for Wavelength: 2293.339 nm, FWHM: 8.771 nm"),
            Band(name="B259", description="Radiance for Wavelength: 2300.738 nm, FWHM: 8.772 nm"),
            Band(name="B260", description="Radiance for Wavelength: 2308.136 nm, FWHM: 8.774 nm"),
            Band(name="B261", description="Radiance for Wavelength: 2315.534 nm, FWHM: 8.775 nm"),
            Band(name="B262", description="Radiance for Wavelength: 2322.933 nm, FWHM: 8.777 nm"),
            Band(name="B263", description="Radiance for Wavelength: 2330.330 nm, FWHM: 8.778 nm"),
            Band(name="B264", description="Radiance for Wavelength: 2337.726 nm, FWHM: 8.779 nm"),
            Band(name="B265", description="Radiance for Wavelength: 2345.122 nm, FWHM: 8.781 nm"),
            Band(name="B266", description="Radiance for Wavelength: 2352.517 nm, FWHM: 8.782 nm"),
            Band(name="B267", description="Radiance for Wavelength: 2359.913 nm, FWHM: 8.783 nm"),
            Band(name="B268", description="Radiance for Wavelength: 2367.307 nm, FWHM: 8.785 nm"),
            Band(name="B269", description="Radiance for Wavelength: 2374.701 nm, FWHM: 8.786 nm"),
            Band(name="B270", description="Radiance for Wavelength: 2382.094 nm, FWHM: 8.788 nm"),
            Band(name="B271", description="Radiance for Wavelength: 2389.486 nm, FWHM: 8.789 nm"),
            Band(name="B272", description="Radiance for Wavelength: 2396.878 nm, FWHM: 8.790 nm"),
            Band(name="B273", description="Radiance for Wavelength: 2404.270 nm, FWHM: 8.792 nm"),
            Band(name="B274", description="Radiance for Wavelength: 2411.660 nm, FWHM: 8.793 nm"),
            Band(name="B275", description="Radiance for Wavelength: 2419.051 nm, FWHM: 8.795 nm"),
            Band(name="B276", description="Radiance for Wavelength: 2426.440 nm, FWHM: 8.796 nm"),
            Band(name="B277", description="Radiance for Wavelength: 2433.830 nm, FWHM: 8.797 nm"),
            Band(name="B278", description="Radiance for Wavelength: 2441.218 nm, FWHM: 8.799 nm"),
            Band(name="B279", description="Radiance for Wavelength: 2448.606 nm, FWHM: 8.800 nm"),
            Band(name="B280", description="Radiance for Wavelength: 2455.994 nm, FWHM: 8.802 nm"),
            Band(name="B281", description="Radiance for Wavelength: 2463.382 nm, FWHM: 8.803 nm"),
            Band(name="B282", description="Radiance for Wavelength: 2470.768 nm, FWHM: 8.804 nm"),
            Band(name="B283", description="Radiance for Wavelength: 2478.153 nm, FWHM: 8.806 nm"),
            Band(name="B284", description="Radiance for Wavelength: 2485.539 nm, FWHM: 8.807 nm"),
            Band(name="B285", description="Radiance for Wavelength: 2492.924 nm, FWHM: 8.809 nm"),
            Band(name="elev", description="Elevation"),
        ]
    ),
    Product(
        product_id="EMIT_L1B_OBS.001",
        description="L1B Observation Data",
        bands=[
            Band(name="aspect", description="Local surface aspect 0 to 360 degrees clockwise from N"),
            Band(name="cosine", description="Apparent local illumination factor based on DEM slope and aspect and to sun vector"),
            Band(name="earth_sun_distance", description="Distance between the Earth and the Sun"),
            Band(name="elev", description="Elevation"),
            Band(name="path_length", description="Distance between sensor and ground"),
            Band(name="slope", description="Local surface slope as derived from DEM in degrees"),
            Band(name="solar_phase", description="Degrees between to-sensor and to-sun vectors in principal plane"),
            Band(name="to_sensor_azimuth", description="0 to 360 degrees clockwise from N"),
            Band(name="to_sensor_zenith", description="0 to 90 degrees from zenith"),
            Band(name="to_sun_azimuth", description="0 to 360 degrees clockwise from N"),
            Band(name="to_sun_zenith", description="0 to 90 degrees from zenith"),
            Band(name="utc_time", description="Decimal hours since UTC midnight for mid-line pixels"),
        ]
    ),
    Product(
        product_id="EMIT_L2A_RFL.001",
        description="Estimated Surface Reflectance",
        bands=[
            Band(name="B001", description="Reflectance for Wavelength: 381.006 nm, FWHM: 8.415 nm"),
            Band(name="B001_GW", description="Usable wavelengths flag for Wavelength: 381.006 nm, FWHM: 8.415 nm"),
            Band(name="B002", description="Reflectance for Wavelength: 388.409 nm, FWHM: 8.415 nm"),
            Band(name="B002_GW", description="Usable wavelengths flag for Wavelength: 388.409 nm, FWHM: 8.415 nm"),
            Band(name="B003", description="Reflectance for Wavelength: 395.816 nm, FWHM: 8.415 nm"),
            Band(name="B003_GW", description="Usable wavelengths flag for Wavelength: 395.816 nm, FWHM: 8.415 nm"),
            Band(name="B004", description="Reflectance for Wavelength: 403.225 nm, FWHM: 8.415 nm"),
            Band(name="B004_GW", description="Usable wavelengths flag for Wavelength: 403.225 nm, FWHM: 8.415 nm"),
            Band(name="B005", description="Reflectance for Wavelength: 410.638 nm, FWHM: 8.417 nm"),
            Band(name="B005_GW", description="Usable wavelengths flag for Wavelength: 410.638 nm, FWHM: 8.417 nm"),
            Band(name="B006", description="Reflectance for Wavelength: 418.054 nm, FWHM: 8.418 nm"),
            Band(name="B006_GW", description="Usable wavelengths flag for Wavelength: 418.054 nm, FWHM: 8.418 nm"),
            Band(name="B007", description="Reflectance for Wavelength: 425.472 nm, FWHM: 8.419 nm"),
            Band(name="B007_GW", description="Usable wavelengths flag for Wavelength: 425.472 nm, FWHM: 8.419 nm"),
            Band(name="B008", description="Reflectance for Wavelength: 432.893 nm, FWHM: 8.421 nm"),
            Band(name="B008_GW", description="Usable wavelengths flag for Wavelength: 432.893 nm, FWHM: 8.421 nm"),
            Band(name="B009", description="Reflectance for Wavelength: 440.317 nm, FWHM: 8.422 nm"),
            Band(name="B009_GW", description="Usable wavelengths flag for Wavelength: 440.317 nm, FWHM: 8.422 nm"),
            Band(name="B010", description="Reflectance for Wavelength: 447.743 nm, FWHM: 8.424 nm"),
            Band(name="B010_GW", description="Usable wavelengths flag for Wavelength: 447.743 nm, FWHM: 8.424 nm"),
            Band(name="B011", description="Reflectance for Wavelength: 455.170 nm, FWHM: 8.425 nm"),
            Band(name="B011_GW", description="Usable wavelengths flag for Wavelength: 455.170 nm, FWHM: 8.425 nm"),
            Band(name="B012", description="Reflectance for Wavelength: 462.599 nm, FWHM: 8.426 nm"),
            Band(name="B012_GW", description="Usable wavelengths flag for Wavelength: 462.599 nm, FWHM: 8.426 nm"),
            Band(name="B013", description="Reflectance for Wavelength: 470.030 nm, FWHM: 8.428 nm"),
            Band(name="B013_GW", description="Usable wavelengths flag for Wavelength: 470.030 nm, FWHM: 8.428 nm"),
            Band(name="B014", description="Reflectance for Wavelength: 477.463 nm, FWHM: 8.429 nm"),
            Band(name="B014_GW", description="Usable wavelengths flag for Wavelength: 477.463 nm, FWHM: 8.429 nm"),
            Band(name="B015", description="Reflectance for Wavelength: 484.897 nm, FWHM: 8.431 nm"),
            Band(name="B015_GW", description="Usable wavelengths flag for Wavelength: 484.897 nm, FWHM: 8.431 nm"),
            Band(name="B016", description="Reflectance for Wavelength: 492.333 nm, FWHM: 8.432 nm"),
            Band(name="B016_GW", description="Usable wavelengths flag for Wavelength: 492.333 nm, FWHM: 8.432 nm"),
            Band(name="B017", description="Reflectance for Wavelength: 499.771 nm, FWHM: 8.433 nm"),
            Band(name="B017_GW", description="Usable wavelengths flag for Wavelength: 499.771 nm, FWHM: 8.433 nm"),
            Band(name="B018", description="Reflectance for Wavelength: 507.210 nm, FWHM: 8.435 nm"),
            Band(name="B018_GW", description="Usable wavelengths flag for Wavelength: 507.210 nm, FWHM: 8.435 nm"),
            Band(name="B019", description="Reflectance for Wavelength: 514.650 nm, FWHM: 8.436 nm"),
            Band(name="B019_GW", description="Usable wavelengths flag for Wavelength: 514.650 nm, FWHM: 8.436 nm"),
            Band(name="B020", description="Reflectance for Wavelength: 522.091 nm, FWHM: 8.438 nm"),
            Band(name="B020_GW", description="Usable wavelengths flag for Wavelength: 522.091 nm, FWHM: 8.438 nm"),
            Band(name="B021", description="Reflectance for Wavelength: 529.533 nm, FWHM: 8.439 nm"),
            Band(name="B021_GW", description="Usable wavelengths flag for Wavelength: 529.533 nm, FWHM: 8.439 nm"),
            Band(name="B022", description="Reflectance for Wavelength: 536.977 nm, FWHM: 8.440 nm"),
            Band(name="B022_GW", description="Usable wavelengths flag for Wavelength: 536.977 nm, FWHM: 8.440 nm"),
            Band(name="B023", description="Reflectance for Wavelength: 544.421 nm, FWHM: 8.442 nm"),
            Band(name="B023_GW", description="Usable wavelengths flag for Wavelength: 544.421 nm, FWHM: 8.442 nm"),
            Band(name="B024", description="Reflectance for Wavelength: 551.867 nm, FWHM: 8.443 nm"),
            Band(name="B024_GW", description="Usable wavelengths flag for Wavelength: 551.867 nm, FWHM: 8.443 nm"),
            Band(name="B025", description="Reflectance for Wavelength: 559.314 nm, FWHM: 8.445 nm"),
            Band(name="B025_GW", description="Usable wavelengths flag for Wavelength: 559.314 nm, FWHM: 8.445 nm"),
            Band(name="B026", description="Reflectance for Wavelength: 566.762 nm, FWHM: 8.446 nm"),
            Band(name="B026_GW", description="Usable wavelengths flag for Wavelength: 566.762 nm, FWHM: 8.446 nm"),
            Band(name="B027", description="Reflectance for Wavelength: 574.209 nm, FWHM: 8.447 nm"),
            Band(name="B027_GW", description="Usable wavelengths flag for Wavelength: 574.209 nm, FWHM: 8.447 nm"),
            Band(name="B028", description="Reflectance for Wavelength: 581.659 nm, FWHM: 8.449 nm"),
            Band(name="B028_GW", description="Usable wavelengths flag for Wavelength: 581.659 nm, FWHM: 8.449 nm"),
            Band(name="B029", description="Reflectance for Wavelength: 589.108 nm, FWHM: 8.450 nm"),
            Band(name="B029_GW", description="Usable wavelengths flag for Wavelength: 589.108 nm, FWHM: 8.450 nm"),
            Band(name="B030", description="Reflectance for Wavelength: 596.558 nm, FWHM: 8.452 nm"),
            Band(name="B030_GW", description="Usable wavelengths flag for Wavelength: 596.558 nm, FWHM: 8.452 nm"),
            Band(name="B031", description="Reflectance for Wavelength: 604.010 nm, FWHM: 8.453 nm"),
            Band(name="B031_GW", description="Usable wavelengths flag for Wavelength: 604.010 nm, FWHM: 8.453 nm"),
            Band(name="B032", description="Reflectance for Wavelength: 611.462 nm, FWHM: 8.454 nm"),
            Band(name="B032_GW", description="Usable wavelengths flag for Wavelength: 611.462 nm, FWHM: 8.454 nm"),
            Band(name="B033", description="Reflectance for Wavelength: 618.915 nm, FWHM: 8.456 nm"),
            Band(name="B033_GW", description="Usable wavelengths flag for Wavelength: 618.915 nm, FWHM: 8.456 nm"),
            Band(name="B034", description="Reflectance for Wavelength: 626.368 nm, FWHM: 8.457 nm"),
            Band(name="B034_GW", description="Usable wavelengths flag for Wavelength: 626.368 nm, FWHM: 8.457 nm"),
            Band(name="B035", description="Reflectance for Wavelength: 633.821 nm, FWHM: 8.459 nm"),
            Band(name="B035_GW", description="Usable wavelengths flag for Wavelength: 633.821 nm, FWHM: 8.459 nm"),
            Band(name="B036", description="Reflectance for Wavelength: 641.276 nm, FWHM: 8.460 nm"),
            Band(name="B036_GW", description="Usable wavelengths flag for Wavelength: 641.276 nm, FWHM: 8.460 nm"),
            Band(name="B037", description="Reflectance for Wavelength: 648.730 nm, FWHM: 8.461 nm"),
            Band(name="B037_GW", description="Usable wavelengths flag for Wavelength: 648.730 nm, FWHM: 8.461 nm"),
            Band(name="B038", description="Reflectance for Wavelength: 656.186 nm, FWHM: 8.463 nm"),
            Band(name="B038_GW", description="Usable wavelengths flag for Wavelength: 656.186 nm, FWHM: 8.463 nm"),
            Band(name="B039", description="Reflectance for Wavelength: 663.641 nm, FWHM: 8.464 nm"),
            Band(name="B039_GW", description="Usable wavelengths flag for Wavelength: 663.641 nm, FWHM: 8.464 nm"),
            Band(name="B040", description="Reflectance for Wavelength: 671.098 nm, FWHM: 8.466 nm"),
            Band(name="B040_GW", description="Usable wavelengths flag for Wavelength: 671.098 nm, FWHM: 8.466 nm"),
            Band(name="B041", description="Reflectance for Wavelength: 678.554 nm, FWHM: 8.467 nm"),
            Band(name="B041_GW", description="Usable wavelengths flag for Wavelength: 678.554 nm, FWHM: 8.467 nm"),
            Band(name="B042", description="Reflectance for Wavelength: 686.010 nm, FWHM: 8.468 nm"),
            Band(name="B042_GW", description="Usable wavelengths flag for Wavelength: 686.010 nm, FWHM: 8.468 nm"),
            Band(name="B043", description="Reflectance for Wavelength: 693.468 nm, FWHM: 8.470 nm"),
            Band(name="B043_GW", description="Usable wavelengths flag for Wavelength: 693.468 nm, FWHM: 8.470 nm"),
            Band(name="B044", description="Reflectance for Wavelength: 700.925 nm, FWHM: 8.471 nm"),
            Band(name="B044_GW", description="Usable wavelengths flag for Wavelength: 700.925 nm, FWHM: 8.471 nm"),
            Band(name="B045", description="Reflectance for Wavelength: 708.384 nm, FWHM: 8.473 nm"),
            Band(name="B045_GW", description="Usable wavelengths flag for Wavelength: 708.384 nm, FWHM: 8.473 nm"),
            Band(name="B046", description="Reflectance for Wavelength: 715.841 nm, FWHM: 8.474 nm"),
            Band(name="B046_GW", description="Usable wavelengths flag for Wavelength: 715.841 nm, FWHM: 8.474 nm"),
            Band(name="B047", description="Reflectance for Wavelength: 723.299 nm, FWHM: 8.475 nm"),
            Band(name="B047_GW", description="Usable wavelengths flag for Wavelength: 723.299 nm, FWHM: 8.475 nm"),
            Band(name="B048", description="Reflectance for Wavelength: 730.759 nm, FWHM: 8.477 nm"),
            Band(name="B048_GW", description="Usable wavelengths flag for Wavelength: 730.759 nm, FWHM: 8.477 nm"),
            Band(name="B049", description="Reflectance for Wavelength: 738.217 nm, FWHM: 8.478 nm"),
            Band(name="B049_GW", description="Usable wavelengths flag for Wavelength: 738.217 nm, FWHM: 8.478 nm"),
            Band(name="B050", description="Reflectance for Wavelength: 745.677 nm, FWHM: 8.480 nm"),
            Band(name="B050_GW", description="Usable wavelengths flag for Wavelength: 745.677 nm, FWHM: 8.480 nm"),
            Band(name="B051", description="Reflectance for Wavelength: 753.136 nm, FWHM: 8.481 nm"),
            Band(name="B051_GW", description="Usable wavelengths flag for Wavelength: 753.136 nm, FWHM: 8.481 nm"),
            Band(name="B052", description="Reflectance for Wavelength: 760.596 nm, FWHM: 8.482 nm"),
            Band(name="B052_GW", description="Usable wavelengths flag for Wavelength: 760.596 nm, FWHM: 8.482 nm"),
            Band(name="B053", description="Reflectance for Wavelength: 768.056 nm, FWHM: 8.484 nm"),
            Band(name="B053_GW", description="Usable wavelengths flag for Wavelength: 768.056 nm, FWHM: 8.484 nm"),
            Band(name="B054", description="Reflectance for Wavelength: 775.516 nm, FWHM: 8.485 nm"),
            Band(name="B054_GW", description="Usable wavelengths flag for Wavelength: 775.516 nm, FWHM: 8.485 nm"),
            Band(name="B055", description="Reflectance for Wavelength: 782.978 nm, FWHM: 8.487 nm"),
            Band(name="B055_GW", description="Usable wavelengths flag for Wavelength: 782.978 nm, FWHM: 8.487 nm"),
            Band(name="B056", description="Reflectance for Wavelength: 790.438 nm, FWHM: 8.488 nm"),
            Band(name="B056_GW", description="Usable wavelengths flag for Wavelength: 790.438 nm, FWHM: 8.488 nm"),
            Band(name="B057", description="Reflectance for Wavelength: 797.899 nm, FWHM: 8.489 nm"),
            Band(name="B057_GW", description="Usable wavelengths flag for Wavelength: 797.899 nm, FWHM: 8.489 nm"),
            Band(name="B058", description="Reflectance for Wavelength: 805.362 nm, FWHM: 8.491 nm"),
            Band(name="B058_GW", description="Usable wavelengths flag for Wavelength: 805.362 nm, FWHM: 8.491 nm"),
            Band(name="B059", description="Reflectance for Wavelength: 812.823 nm, FWHM: 8.492 nm"),
            Band(name="B059_GW", description="Usable wavelengths flag for Wavelength: 812.823 nm, FWHM: 8.492 nm"),
            Band(name="B060", description="Reflectance for Wavelength: 820.285 nm, FWHM: 8.494 nm"),
            Band(name="B060_GW", description="Usable wavelengths flag for Wavelength: 820.285 nm, FWHM: 8.494 nm"),
            Band(name="B061", description="Reflectance for Wavelength: 827.746 nm, FWHM: 8.495 nm"),
            Band(name="B061_GW", description="Usable wavelengths flag for Wavelength: 827.746 nm, FWHM: 8.495 nm"),
            Band(name="B062", description="Reflectance for Wavelength: 835.207 nm, FWHM: 8.496 nm"),
            Band(name="B062_GW", description="Usable wavelengths flag for Wavelength: 835.207 nm, FWHM: 8.496 nm"),
            Band(name="B063", description="Reflectance for Wavelength: 842.670 nm, FWHM: 8.498 nm"),
            Band(name="B063_GW", description="Usable wavelengths flag for Wavelength: 842.670 nm, FWHM: 8.498 nm"),
            Band(name="B064", description="Reflectance for Wavelength: 850.131 nm, FWHM: 8.499 nm"),
            Band(name="B064_GW", description="Usable wavelengths flag for Wavelength: 850.131 nm, FWHM: 8.499 nm"),
            Band(name="B065", description="Reflectance for Wavelength: 857.594 nm, FWHM: 8.501 nm"),
            Band(name="B065_GW", description="Usable wavelengths flag for Wavelength: 857.594 nm, FWHM: 8.501 nm"),
            Band(name="B066", description="Reflectance for Wavelength: 865.055 nm, FWHM: 8.502 nm"),
            Band(name="B066_GW", description="Usable wavelengths flag for Wavelength: 865.055 nm, FWHM: 8.502 nm"),
            Band(name="B067", description="Reflectance for Wavelength: 872.518 nm, FWHM: 8.503 nm"),
            Band(name="B067_GW", description="Usable wavelengths flag for Wavelength: 872.518 nm, FWHM: 8.503 nm"),
            Band(name="B068", description="Reflectance for Wavelength: 879.980 nm, FWHM: 8.505 nm"),
            Band(name="B068_GW", description="Usable wavelengths flag for Wavelength: 879.980 nm, FWHM: 8.505 nm"),
            Band(name="B069", description="Reflectance for Wavelength: 887.441 nm, FWHM: 8.506 nm"),
            Band(name="B069_GW", description="Usable wavelengths flag for Wavelength: 887.441 nm, FWHM: 8.506 nm"),
            Band(name="B070", description="Reflectance for Wavelength: 894.904 nm, FWHM: 8.508 nm"),
            Band(name="B070_GW", description="Usable wavelengths flag for Wavelength: 894.904 nm, FWHM: 8.508 nm"),
            Band(name="B071", description="Reflectance for Wavelength: 902.366 nm, FWHM: 8.509 nm"),
            Band(name="B071_GW", description="Usable wavelengths flag for Wavelength: 902.366 nm, FWHM: 8.509 nm"),
            Band(name="B072", description="Reflectance for Wavelength: 909.829 nm, FWHM: 8.510 nm"),
            Band(name="B072_GW", description="Usable wavelengths flag for Wavelength: 909.829 nm, FWHM: 8.510 nm"),
            Band(name="B073", description="Reflectance for Wavelength: 917.291 nm, FWHM: 8.512 nm"),
            Band(name="B073_GW", description="Usable wavelengths flag for Wavelength: 917.291 nm, FWHM: 8.512 nm"),
            Band(name="B074", description="Reflectance for Wavelength: 924.754 nm, FWHM: 8.513 nm"),
            Band(name="B074_GW", description="Usable wavelengths flag for Wavelength: 924.754 nm, FWHM: 8.513 nm"),
            Band(name="B075", description="Reflectance for Wavelength: 932.216 nm, FWHM: 8.515 nm"),
            Band(name="B075_GW", description="Usable wavelengths flag for Wavelength: 932.216 nm, FWHM: 8.515 nm"),
            Band(name="B076", description="Reflectance for Wavelength: 939.679 nm, FWHM: 8.516 nm"),
            Band(name="B076_GW", description="Usable wavelengths flag for Wavelength: 939.679 nm, FWHM: 8.516 nm"),
            Band(name="B077", description="Reflectance for Wavelength: 947.140 nm, FWHM: 8.517 nm"),
            Band(name="B077_GW", description="Usable wavelengths flag for Wavelength: 947.140 nm, FWHM: 8.517 nm"),
            Band(name="B078", description="Reflectance for Wavelength: 954.603 nm, FWHM: 8.519 nm"),
            Band(name="B078_GW", description="Usable wavelengths flag for Wavelength: 954.603 nm, FWHM: 8.519 nm"),
            Band(name="B079", description="Reflectance for Wavelength: 962.064 nm, FWHM: 8.520 nm"),
            Band(name="B079_GW", description="Usable wavelengths flag for Wavelength: 962.064 nm, FWHM: 8.520 nm"),
            Band(name="B080", description="Reflectance for Wavelength: 969.527 nm, FWHM: 8.522 nm"),
            Band(name="B080_GW", description="Usable wavelengths flag for Wavelength: 969.527 nm, FWHM: 8.522 nm"),
            Band(name="B081", description="Reflectance for Wavelength: 976.988 nm, FWHM: 8.523 nm"),
            Band(name="B081_GW", description="Usable wavelengths flag for Wavelength: 976.988 nm, FWHM: 8.523 nm"),
            Band(name="B082", description="Reflectance for Wavelength: 984.450 nm, FWHM: 8.524 nm"),
            Band(name="B082_GW", description="Usable wavelengths flag for Wavelength: 984.450 nm, FWHM: 8.524 nm"),
            Band(name="B083", description="Reflectance for Wavelength: 991.911 nm, FWHM: 8.526 nm"),
            Band(name="B083_GW", description="Usable wavelengths flag for Wavelength: 991.911 nm, FWHM: 8.526 nm"),
            Band(name="B084", description="Reflectance for Wavelength: 999.373 nm, FWHM: 8.527 nm"),
            Band(name="B084_GW", description="Usable wavelengths flag for Wavelength: 999.373 nm, FWHM: 8.527 nm"),
            Band(name="B085", description="Reflectance for Wavelength: 1006.834 nm, FWHM: 8.529 nm"),
            Band(name="B085_GW", description="Usable wavelengths flag for Wavelength: 1006.834 nm, FWHM: 8.529 nm"),
            Band(name="B086", description="Reflectance for Wavelength: 1014.295 nm, FWHM: 8.530 nm"),
            Band(name="B086_GW", description="Usable wavelengths flag for Wavelength: 1014.295 nm, FWHM: 8.530 nm"),
            Band(name="B087", description="Reflectance for Wavelength: 1021.757 nm, FWHM: 8.531 nm"),
            Band(name="B087_GW", description="Usable wavelengths flag for Wavelength: 1021.757 nm, FWHM: 8.531 nm"),
            Band(name="B088", description="Reflectance for Wavelength: 1029.217 nm, FWHM: 8.533 nm"),
            Band(name="B088_GW", description="Usable wavelengths flag for Wavelength: 1029.217 nm, FWHM: 8.533 nm"),
            Band(name="B089", description="Reflectance for Wavelength: 1036.678 nm, FWHM: 8.534 nm"),
            Band(name="B089_GW", description="Usable wavelengths flag for Wavelength: 1036.678 nm, FWHM: 8.534 nm"),
            Band(name="B090", description="Reflectance for Wavelength: 1044.138 nm, FWHM: 8.536 nm"),
            Band(name="B090_GW", description="Usable wavelengths flag for Wavelength: 1044.138 nm, FWHM: 8.536 nm"),
            Band(name="B091", description="Reflectance for Wavelength: 1051.599 nm, FWHM: 8.537 nm"),
            Band(name="B091_GW", description="Usable wavelengths flag for Wavelength: 1051.599 nm, FWHM: 8.537 nm"),
            Band(name="B092", description="Reflectance for Wavelength: 1059.060 nm, FWHM: 8.538 nm"),
            Band(name="B092_GW", description="Usable wavelengths flag for Wavelength: 1059.060 nm, FWHM: 8.538 nm"),
            Band(name="B093", description="Reflectance for Wavelength: 1066.520 nm, FWHM: 8.540 nm"),
            Band(name="B093_GW", description="Usable wavelengths flag for Wavelength: 1066.520 nm, FWHM: 8.540 nm"),
            Band(name="B094", description="Reflectance for Wavelength: 1073.980 nm, FWHM: 8.541 nm"),
            Band(name="B094_GW", description="Usable wavelengths flag for Wavelength: 1073.980 nm, FWHM: 8.541 nm"),
            Band(name="B095", description="Reflectance for Wavelength: 1081.440 nm, FWHM: 8.543 nm"),
            Band(name="B095_GW", description="Usable wavelengths flag for Wavelength: 1081.440 nm, FWHM: 8.543 nm"),
            Band(name="B096", description="Reflectance for Wavelength: 1088.900 nm, FWHM: 8.544 nm"),
            Band(name="B096_GW", description="Usable wavelengths flag for Wavelength: 1088.900 nm, FWHM: 8.544 nm"),
            Band(name="B097", description="Reflectance for Wavelength: 1096.360 nm, FWHM: 8.545 nm"),
            Band(name="B097_GW", description="Usable wavelengths flag for Wavelength: 1096.360 nm, FWHM: 8.545 nm"),
            Band(name="B098", description="Reflectance for Wavelength: 1103.818 nm, FWHM: 8.547 nm"),
            Band(name="B098_GW", description="Usable wavelengths flag for Wavelength: 1103.818 nm, FWHM: 8.547 nm"),
            Band(name="B099", description="Reflectance for Wavelength: 1111.278 nm, FWHM: 8.548 nm"),
            Band(name="B099_GW", description="Usable wavelengths flag for Wavelength: 1111.278 nm, FWHM: 8.548 nm"),
            Band(name="B100", description="Reflectance for Wavelength: 1118.737 nm, FWHM: 8.550 nm"),
            Band(name="B100_GW", description="Usable wavelengths flag for Wavelength: 1118.737 nm, FWHM: 8.550 nm"),
            Band(name="B101", description="Reflectance for Wavelength: 1126.196 nm, FWHM: 8.551 nm"),
            Band(name="B101_GW", description="Usable wavelengths flag for Wavelength: 1126.196 nm, FWHM: 8.551 nm"),
            Band(name="B102", description="Reflectance for Wavelength: 1133.655 nm, FWHM: 8.552 nm"),
            Band(name="B102_GW", description="Usable wavelengths flag for Wavelength: 1133.655 nm, FWHM: 8.552 nm"),
            Band(name="B103", description="Reflectance for Wavelength: 1141.113 nm, FWHM: 8.554 nm"),
            Band(name="B103_GW", description="Usable wavelengths flag for Wavelength: 1141.113 nm, FWHM: 8.554 nm"),
            Band(name="B104", description="Reflectance for Wavelength: 1148.572 nm, FWHM: 8.555 nm"),
            Band(name="B104_GW", description="Usable wavelengths flag for Wavelength: 1148.572 nm, FWHM: 8.555 nm"),
            Band(name="B105", description="Reflectance for Wavelength: 1156.030 nm, FWHM: 8.557 nm"),
            Band(name="B105_GW", description="Usable wavelengths flag for Wavelength: 1156.030 nm, FWHM: 8.557 nm"),
            Band(name="B106", description="Reflectance for Wavelength: 1163.488 nm, FWHM: 8.558 nm"),
            Band(name="B106_GW", description="Usable wavelengths flag for Wavelength: 1163.488 nm, FWHM: 8.558 nm"),
            Band(name="B107", description="Reflectance for Wavelength: 1170.946 nm, FWHM: 8.559 nm"),
            Band(name="B107_GW", description="Usable wavelengths flag for Wavelength: 1170.946 nm, FWHM: 8.559 nm"),
            Band(name="B108", description="Reflectance for Wavelength: 1178.404 nm, FWHM: 8.561 nm"),
            Band(name="B108_GW", description="Usable wavelengths flag for Wavelength: 1178.404 nm, FWHM: 8.561 nm"),
            Band(name="B109", description="Reflectance for Wavelength: 1185.862 nm, FWHM: 8.562 nm"),
            Band(name="B109_GW", description="Usable wavelengths flag for Wavelength: 1185.862 nm, FWHM: 8.562 nm"),
            Band(name="B110", description="Reflectance for Wavelength: 1193.318 nm, FWHM: 8.564 nm"),
            Band(name="B110_GW", description="Usable wavelengths flag for Wavelength: 1193.318 nm, FWHM: 8.564 nm"),
            Band(name="B111", description="Reflectance for Wavelength: 1200.776 nm, FWHM: 8.565 nm"),
            Band(name="B111_GW", description="Usable wavelengths flag for Wavelength: 1200.776 nm, FWHM: 8.565 nm"),
            Band(name="B112", description="Reflectance for Wavelength: 1208.233 nm, FWHM: 8.566 nm"),
            Band(name="B112_GW", description="Usable wavelengths flag for Wavelength: 1208.233 nm, FWHM: 8.566 nm"),
            Band(name="B113", description="Reflectance for Wavelength: 1215.690 nm, FWHM: 8.568 nm"),
            Band(name="B113_GW", description="Usable wavelengths flag for Wavelength: 1215.690 nm, FWHM: 8.568 nm"),
            Band(name="B114", description="Reflectance for Wavelength: 1223.147 nm, FWHM: 8.569 nm"),
            Band(name="B114_GW", description="Usable wavelengths flag for Wavelength: 1223.147 nm, FWHM: 8.569 nm"),
            Band(name="B115", description="Reflectance for Wavelength: 1230.604 nm, FWHM: 8.571 nm"),
            Band(name="B115_GW", description="Usable wavelengths flag for Wavelength: 1230.604 nm, FWHM: 8.571 nm"),
            Band(name="B116", description="Reflectance for Wavelength: 1238.060 nm, FWHM: 8.572 nm"),
            Band(name="B116_GW", description="Usable wavelengths flag for Wavelength: 1238.060 nm, FWHM: 8.572 nm"),
            Band(name="B117", description="Reflectance for Wavelength: 1245.515 nm, FWHM: 8.573 nm"),
            Band(name="B117_GW", description="Usable wavelengths flag for Wavelength: 1245.515 nm, FWHM: 8.573 nm"),
            Band(name="B118", description="Reflectance for Wavelength: 1252.972 nm, FWHM: 8.575 nm"),
            Band(name="B118_GW", description="Usable wavelengths flag for Wavelength: 1252.972 nm, FWHM: 8.575 nm"),
            Band(name="B119", description="Reflectance for Wavelength: 1260.428 nm, FWHM: 8.576 nm"),
            Band(name="B119_GW", description="Usable wavelengths flag for Wavelength: 1260.428 nm, FWHM: 8.576 nm"),
            Band(name="B120", description="Reflectance for Wavelength: 1267.883 nm, FWHM: 8.578 nm"),
            Band(name="B120_GW", description="Usable wavelengths flag for Wavelength: 1267.883 nm, FWHM: 8.578 nm"),
            Band(name="B121", description="Reflectance for Wavelength: 1275.339 nm, FWHM: 8.579 nm"),
            Band(name="B121_GW", description="Usable wavelengths flag for Wavelength: 1275.339 nm, FWHM: 8.579 nm"),
            Band(name="B122", description="Reflectance for Wavelength: 1282.794 nm, FWHM: 8.580 nm"),
            Band(name="B122_GW", description="Usable wavelengths flag for Wavelength: 1282.794 nm, FWHM: 8.580 nm"),
            Band(name="B123", description="Reflectance for Wavelength: 1290.250 nm, FWHM: 8.582 nm"),
            Band(name="B123_GW", description="Usable wavelengths flag for Wavelength: 1290.250 nm, FWHM: 8.582 nm"),
            Band(name="B124", description="Reflectance for Wavelength: 1297.705 nm, FWHM: 8.583 nm"),
            Band(name="B124_GW", description="Usable wavelengths flag for Wavelength: 1297.705 nm, FWHM: 8.583 nm"),
            Band(name="B125", description="Reflectance for Wavelength: 1305.160 nm, FWHM: 8.585 nm"),
            Band(name="B125_GW", description="Usable wavelengths flag for Wavelength: 1305.160 nm, FWHM: 8.585 nm"),
            Band(name="B126", description="Reflectance for Wavelength: 1312.614 nm, FWHM: 8.586 nm"),
            Band(name="B126_GW", description="Usable wavelengths flag for Wavelength: 1312.614 nm, FWHM: 8.586 nm"),
            Band(name="B127", description="Reflectance for Wavelength: 1320.068 nm, FWHM: 8.587 nm"),
            Band(name="B127_GW", description="Usable wavelengths flag for Wavelength: 1320.068 nm, FWHM: 8.587 nm"),
            Band(name="B128", description="Reflectance for Wavelength: 1327.522 nm, FWHM: 8.589 nm"),
            Band(name="B128_GW", description="Usable wavelengths flag for Wavelength: 1327.522 nm, FWHM: 8.589 nm"),
            Band(name="B129", description="Reflectance for Wavelength: 1334.976 nm, FWHM: 8.590 nm"),
            Band(name="B129_GW", description="Usable wavelengths flag for Wavelength: 1334.976 nm, FWHM: 8.590 nm"),
            Band(name="B130", description="Reflectance for Wavelength: 1342.429 nm, FWHM: 8.592 nm"),
            Band(name="B130_GW", description="Usable wavelengths flag for Wavelength: 1342.429 nm, FWHM: 8.592 nm"),
            Band(name="B131", description="Reflectance for Wavelength: 1349.882 nm, FWHM: 8.593 nm"),
            Band(name="B131_GW", description="Usable wavelengths flag for Wavelength: 1349.882 nm, FWHM: 8.593 nm"),
            Band(name="B132", description="Reflectance for Wavelength: 1357.335 nm, FWHM: 8.594 nm"),
            Band(name="B132_GW", description="Usable wavelengths flag for Wavelength: 1357.335 nm, FWHM: 8.594 nm"),
            Band(name="B133", description="Reflectance for Wavelength: 1364.787 nm, FWHM: 8.596 nm"),
            Band(name="B133_GW", description="Usable wavelengths flag for Wavelength: 1364.787 nm, FWHM: 8.596 nm"),
            Band(name="B134", description="Reflectance for Wavelength: 1372.238 nm, FWHM: 8.597 nm"),
            Band(name="B134_GW", description="Usable wavelengths flag for Wavelength: 1372.238 nm, FWHM: 8.597 nm"),
            Band(name="B135", description="Reflectance for Wavelength: 1379.691 nm, FWHM: 8.599 nm"),
            Band(name="B135_GW", description="Usable wavelengths flag for Wavelength: 1379.691 nm, FWHM: 8.599 nm"),
            Band(name="B136", description="Reflectance for Wavelength: 1387.142 nm, FWHM: 8.600 nm"),
            Band(name="B136_GW", description="Usable wavelengths flag for Wavelength: 1387.142 nm, FWHM: 8.600 nm"),
            Band(name="B137", description="Reflectance for Wavelength: 1394.593 nm, FWHM: 8.601 nm"),
            Band(name="B137_GW", description="Usable wavelengths flag for Wavelength: 1394.593 nm, FWHM: 8.601 nm"),
            Band(name="B138", description="Reflectance for Wavelength: 1402.043 nm, FWHM: 8.603 nm"),
            Band(name="B138_GW", description="Usable wavelengths flag for Wavelength: 1402.043 nm, FWHM: 8.603 nm"),
            Band(name="B139", description="Reflectance for Wavelength: 1409.494 nm, FWHM: 8.604 nm"),
            Band(name="B139_GW", description="Usable wavelengths flag for Wavelength: 1409.494 nm, FWHM: 8.604 nm"),
            Band(name="B140", description="Reflectance for Wavelength: 1416.944 nm, FWHM: 8.606 nm"),
            Band(name="B140_GW", description="Usable wavelengths flag for Wavelength: 1416.944 nm, FWHM: 8.606 nm"),
            Band(name="B141", description="Reflectance for Wavelength: 1424.393 nm, FWHM: 8.607 nm"),
            Band(name="B141_GW", description="Usable wavelengths flag for Wavelength: 1424.393 nm, FWHM: 8.607 nm"),
            Band(name="B142", description="Reflectance for Wavelength: 1431.843 nm, FWHM: 8.608 nm"),
            Band(name="B142_GW", description="Usable wavelengths flag for Wavelength: 1431.843 nm, FWHM: 8.608 nm"),
            Band(name="B143", description="Reflectance for Wavelength: 1439.292 nm, FWHM: 8.610 nm"),
            Band(name="B143_GW", description="Usable wavelengths flag for Wavelength: 1439.292 nm, FWHM: 8.610 nm"),
            Band(name="B144", description="Reflectance for Wavelength: 1446.740 nm, FWHM: 8.611 nm"),
            Band(name="B144_GW", description="Usable wavelengths flag for Wavelength: 1446.740 nm, FWHM: 8.611 nm"),
            Band(name="B145", description="Reflectance for Wavelength: 1454.189 nm, FWHM: 8.613 nm"),
            Band(name="B145_GW", description="Usable wavelengths flag for Wavelength: 1454.189 nm, FWHM: 8.613 nm"),
            Band(name="B146", description="Reflectance for Wavelength: 1461.637 nm, FWHM: 8.614 nm"),
            Band(name="B146_GW", description="Usable wavelengths flag for Wavelength: 1461.637 nm, FWHM: 8.614 nm"),
            Band(name="B147", description="Reflectance for Wavelength: 1469.085 nm, FWHM: 8.615 nm"),
            Band(name="B147_GW", description="Usable wavelengths flag for Wavelength: 1469.085 nm, FWHM: 8.615 nm"),
            Band(name="B148", description="Reflectance for Wavelength: 1476.532 nm, FWHM: 8.617 nm"),
            Band(name="B148_GW", description="Usable wavelengths flag for Wavelength: 1476.532 nm, FWHM: 8.617 nm"),
            Band(name="B149", description="Reflectance for Wavelength: 1483.980 nm, FWHM: 8.618 nm"),
            Band(name="B149_GW", description="Usable wavelengths flag for Wavelength: 1483.980 nm, FWHM: 8.618 nm"),
            Band(name="B150", description="Reflectance for Wavelength: 1491.426 nm, FWHM: 8.620 nm"),
            Band(name="B150_GW", description="Usable wavelengths flag for Wavelength: 1491.426 nm, FWHM: 8.620 nm"),
            Band(name="B151", description="Reflectance for Wavelength: 1498.873 nm, FWHM: 8.621 nm"),
            Band(name="B151_GW", description="Usable wavelengths flag for Wavelength: 1498.873 nm, FWHM: 8.621 nm"),
            Band(name="B152", description="Reflectance for Wavelength: 1506.319 nm, FWHM: 8.622 nm"),
            Band(name="B152_GW", description="Usable wavelengths flag for Wavelength: 1506.319 nm, FWHM: 8.622 nm"),
            Band(name="B153", description="Reflectance for Wavelength: 1513.765 nm, FWHM: 8.624 nm"),
            Band(name="B153_GW", description="Usable wavelengths flag for Wavelength: 1513.765 nm, FWHM: 8.624 nm"),
            Band(name="B154", description="Reflectance for Wavelength: 1521.210 nm, FWHM: 8.625 nm"),
            Band(name="B154_GW", description="Usable wavelengths flag for Wavelength: 1521.210 nm, FWHM: 8.625 nm"),
            Band(name="B155", description="Reflectance for Wavelength: 1528.655 nm, FWHM: 8.627 nm"),
            Band(name="B155_GW", description="Usable wavelengths flag for Wavelength: 1528.655 nm, FWHM: 8.627 nm"),
            Band(name="B156", description="Reflectance for Wavelength: 1536.101 nm, FWHM: 8.628 nm"),
            Band(name="B156_GW", description="Usable wavelengths flag for Wavelength: 1536.101 nm, FWHM: 8.628 nm"),
            Band(name="B157", description="Reflectance for Wavelength: 1543.545 nm, FWHM: 8.629 nm"),
            Band(name="B157_GW", description="Usable wavelengths flag for Wavelength: 1543.545 nm, FWHM: 8.629 nm"),
            Band(name="B158", description="Reflectance for Wavelength: 1550.989 nm, FWHM: 8.631 nm"),
            Band(name="B158_GW", description="Usable wavelengths flag for Wavelength: 1550.989 nm, FWHM: 8.631 nm"),
            Band(name="B159", description="Reflectance for Wavelength: 1558.433 nm, FWHM: 8.632 nm"),
            Band(name="B159_GW", description="Usable wavelengths flag for Wavelength: 1558.433 nm, FWHM: 8.632 nm"),
            Band(name="B160", description="Reflectance for Wavelength: 1565.877 nm, FWHM: 8.634 nm"),
            Band(name="B160_GW", description="Usable wavelengths flag for Wavelength: 1565.877 nm, FWHM: 8.634 nm"),
            Band(name="B161", description="Reflectance for Wavelength: 1573.319 nm, FWHM: 8.635 nm"),
            Band(name="B161_GW", description="Usable wavelengths flag for Wavelength: 1573.319 nm, FWHM: 8.635 nm"),
            Band(name="B162", description="Reflectance for Wavelength: 1580.762 nm, FWHM: 8.636 nm"),
            Band(name="B162_GW", description="Usable wavelengths flag for Wavelength: 1580.762 nm, FWHM: 8.636 nm"),
            Band(name="B163", description="Reflectance for Wavelength: 1588.205 nm, FWHM: 8.638 nm"),
            Band(name="B163_GW", description="Usable wavelengths flag for Wavelength: 1588.205 nm, FWHM: 8.638 nm"),
            Band(name="B164", description="Reflectance for Wavelength: 1595.647 nm, FWHM: 8.639 nm"),
            Band(name="B164_GW", description="Usable wavelengths flag for Wavelength: 1595.647 nm, FWHM: 8.639 nm"),
            Band(name="B165", description="Reflectance for Wavelength: 1603.089 nm, FWHM: 8.641 nm"),
            Band(name="B165_GW", description="Usable wavelengths flag for Wavelength: 1603.089 nm, FWHM: 8.641 nm"),
            Band(name="B166", description="Reflectance for Wavelength: 1610.530 nm, FWHM: 8.642 nm"),
            Band(name="B166_GW", description="Usable wavelengths flag for Wavelength: 1610.530 nm, FWHM: 8.642 nm"),
            Band(name="B167", description="Reflectance for Wavelength: 1617.970 nm, FWHM: 8.643 nm"),
            Band(name="B167_GW", description="Usable wavelengths flag for Wavelength: 1617.970 nm, FWHM: 8.643 nm"),
            Band(name="B168", description="Reflectance for Wavelength: 1625.410 nm, FWHM: 8.645 nm"),
            Band(name="B168_GW", description="Usable wavelengths flag for Wavelength: 1625.410 nm, FWHM: 8.645 nm"),
            Band(name="B169", description="Reflectance for Wavelength: 1632.851 nm, FWHM: 8.646 nm"),
            Band(name="B169_GW", description="Usable wavelengths flag for Wavelength: 1632.851 nm, FWHM: 8.646 nm"),
            Band(name="B170", description="Reflectance for Wavelength: 1640.290 nm, FWHM: 8.648 nm"),
            Band(name="B170_GW", description="Usable wavelengths flag for Wavelength: 1640.290 nm, FWHM: 8.648 nm"),
            Band(name="B171", description="Reflectance for Wavelength: 1647.730 nm, FWHM: 8.649 nm"),
            Band(name="B171_GW", description="Usable wavelengths flag for Wavelength: 1647.730 nm, FWHM: 8.649 nm"),
            Band(name="B172", description="Reflectance for Wavelength: 1655.169 nm, FWHM: 8.650 nm"),
            Band(name="B172_GW", description="Usable wavelengths flag for Wavelength: 1655.169 nm, FWHM: 8.650 nm"),
            Band(name="B173", description="Reflectance for Wavelength: 1662.607 nm, FWHM: 8.652 nm"),
            Band(name="B173_GW", description="Usable wavelengths flag for Wavelength: 1662.607 nm, FWHM: 8.652 nm"),
            Band(name="B174", description="Reflectance for Wavelength: 1670.046 nm, FWHM: 8.653 nm"),
            Band(name="B174_GW", description="Usable wavelengths flag for Wavelength: 1670.046 nm, FWHM: 8.653 nm"),
            Band(name="B175", description="Reflectance for Wavelength: 1677.484 nm, FWHM: 8.655 nm"),
            Band(name="B175_GW", description="Usable wavelengths flag for Wavelength: 1677.484 nm, FWHM: 8.655 nm"),
            Band(name="B176", description="Reflectance for Wavelength: 1684.921 nm, FWHM: 8.656 nm"),
            Band(name="B176_GW", description="Usable wavelengths flag for Wavelength: 1684.921 nm, FWHM: 8.656 nm"),
            Band(name="B177", description="Reflectance for Wavelength: 1692.358 nm, FWHM: 8.657 nm"),
            Band(name="B177_GW", description="Usable wavelengths flag for Wavelength: 1692.358 nm, FWHM: 8.657 nm"),
            Band(name="B178", description="Reflectance for Wavelength: 1699.795 nm, FWHM: 8.659 nm"),
            Band(name="B178_GW", description="Usable wavelengths flag for Wavelength: 1699.795 nm, FWHM: 8.659 nm"),
            Band(name="B179", description="Reflectance for Wavelength: 1707.231 nm, FWHM: 8.660 nm"),
            Band(name="B179_GW", description="Usable wavelengths flag for Wavelength: 1707.231 nm, FWHM: 8.660 nm"),
            Band(name="B180", description="Reflectance for Wavelength: 1714.667 nm, FWHM: 8.662 nm"),
            Band(name="B180_GW", description="Usable wavelengths flag for Wavelength: 1714.667 nm, FWHM: 8.662 nm"),
            Band(name="B181", description="Reflectance for Wavelength: 1722.103 nm, FWHM: 8.663 nm"),
            Band(name="B181_GW", description="Usable wavelengths flag for Wavelength: 1722.103 nm, FWHM: 8.663 nm"),
            Band(name="B182", description="Reflectance for Wavelength: 1729.538 nm, FWHM: 8.664 nm"),
            Band(name="B182_GW", description="Usable wavelengths flag for Wavelength: 1729.538 nm, FWHM: 8.664 nm"),
            Band(name="B183", description="Reflectance for Wavelength: 1736.973 nm, FWHM: 8.666 nm"),
            Band(name="B183_GW", description="Usable wavelengths flag for Wavelength: 1736.973 nm, FWHM: 8.666 nm"),
            Band(name="B184", description="Reflectance for Wavelength: 1744.407 nm, FWHM: 8.667 nm"),
            Band(name="B184_GW", description="Usable wavelengths flag for Wavelength: 1744.407 nm, FWHM: 8.667 nm"),
            Band(name="B185", description="Reflectance for Wavelength: 1751.841 nm, FWHM: 8.669 nm"),
            Band(name="B185_GW", description="Usable wavelengths flag for Wavelength: 1751.841 nm, FWHM: 8.669 nm"),
            Band(name="B186", description="Reflectance for Wavelength: 1759.275 nm, FWHM: 8.670 nm"),
            Band(name="B186_GW", description="Usable wavelengths flag for Wavelength: 1759.275 nm, FWHM: 8.670 nm"),
            Band(name="B187", description="Reflectance for Wavelength: 1766.708 nm, FWHM: 8.671 nm"),
            Band(name="B187_GW", description="Usable wavelengths flag for Wavelength: 1766.708 nm, FWHM: 8.671 nm"),
            Band(name="B188", description="Reflectance for Wavelength: 1774.142 nm, FWHM: 8.673 nm"),
            Band(name="B188_GW", description="Usable wavelengths flag for Wavelength: 1774.142 nm, FWHM: 8.673 nm"),
            Band(name="B189", description="Reflectance for Wavelength: 1781.574 nm, FWHM: 8.674 nm"),
            Band(name="B189_GW", description="Usable wavelengths flag for Wavelength: 1781.574 nm, FWHM: 8.674 nm"),
            Band(name="B190", description="Reflectance for Wavelength: 1789.007 nm, FWHM: 8.676 nm"),
            Band(name="B190_GW", description="Usable wavelengths flag for Wavelength: 1789.007 nm, FWHM: 8.676 nm"),
            Band(name="B191", description="Reflectance for Wavelength: 1796.438 nm, FWHM: 8.677 nm"),
            Band(name="B191_GW", description="Usable wavelengths flag for Wavelength: 1796.438 nm, FWHM: 8.677 nm"),
            Band(name="B192", description="Reflectance for Wavelength: 1803.870 nm, FWHM: 8.678 nm"),
            Band(name="B192_GW", description="Usable wavelengths flag for Wavelength: 1803.870 nm, FWHM: 8.678 nm"),
            Band(name="B193", description="Reflectance for Wavelength: 1811.301 nm, FWHM: 8.680 nm"),
            Band(name="B193_GW", description="Usable wavelengths flag for Wavelength: 1811.301 nm, FWHM: 8.680 nm"),
            Band(name="B194", description="Reflectance for Wavelength: 1818.731 nm, FWHM: 8.681 nm"),
            Band(name="B194_GW", description="Usable wavelengths flag for Wavelength: 1818.731 nm, FWHM: 8.681 nm"),
            Band(name="B195", description="Reflectance for Wavelength: 1826.161 nm, FWHM: 8.683 nm"),
            Band(name="B195_GW", description="Usable wavelengths flag for Wavelength: 1826.161 nm, FWHM: 8.683 nm"),
            Band(name="B196", description="Reflectance for Wavelength: 1833.591 nm, FWHM: 8.684 nm"),
            Band(name="B196_GW", description="Usable wavelengths flag for Wavelength: 1833.591 nm, FWHM: 8.684 nm"),
            Band(name="B197", description="Reflectance for Wavelength: 1841.021 nm, FWHM: 8.685 nm"),
            Band(name="B197_GW", description="Usable wavelengths flag for Wavelength: 1841.021 nm, FWHM: 8.685 nm"),
            Band(name="B198", description="Reflectance for Wavelength: 1848.449 nm, FWHM: 8.687 nm"),
            Band(name="B198_GW", description="Usable wavelengths flag for Wavelength: 1848.449 nm, FWHM: 8.687 nm"),
            Band(name="B199", description="Reflectance for Wavelength: 1855.877 nm, FWHM: 8.688 nm"),
            Band(name="B199_GW", description="Usable wavelengths flag for Wavelength: 1855.877 nm, FWHM: 8.688 nm"),
            Band(name="B200", description="Reflectance for Wavelength: 1863.305 nm, FWHM: 8.690 nm"),
            Band(name="B200_GW", description="Usable wavelengths flag for Wavelength: 1863.305 nm, FWHM: 8.690 nm"),
            Band(name="B201", description="Reflectance for Wavelength: 1870.733 nm, FWHM: 8.691 nm"),
            Band(name="B201_GW", description="Usable wavelengths flag for Wavelength: 1870.733 nm, FWHM: 8.691 nm"),
            Band(name="B202", description="Reflectance for Wavelength: 1878.160 nm, FWHM: 8.692 nm"),
            Band(name="B202_GW", description="Usable wavelengths flag for Wavelength: 1878.160 nm, FWHM: 8.692 nm"),
            Band(name="B203", description="Reflectance for Wavelength: 1885.587 nm, FWHM: 8.694 nm"),
            Band(name="B203_GW", description="Usable wavelengths flag for Wavelength: 1885.587 nm, FWHM: 8.694 nm"),
            Band(name="B204", description="Reflectance for Wavelength: 1893.013 nm, FWHM: 8.695 nm"),
            Band(name="B204_GW", description="Usable wavelengths flag for Wavelength: 1893.013 nm, FWHM: 8.695 nm"),
            Band(name="B205", description="Reflectance for Wavelength: 1900.439 nm, FWHM: 8.697 nm"),
            Band(name="B205_GW", description="Usable wavelengths flag for Wavelength: 1900.439 nm, FWHM: 8.697 nm"),
            Band(name="B206", description="Reflectance for Wavelength: 1907.864 nm, FWHM: 8.698 nm"),
            Band(name="B206_GW", description="Usable wavelengths flag for Wavelength: 1907.864 nm, FWHM: 8.698 nm"),
            Band(name="B207", description="Reflectance for Wavelength: 1915.289 nm, FWHM: 8.699 nm"),
            Band(name="B207_GW", description="Usable wavelengths flag for Wavelength: 1915.289 nm, FWHM: 8.699 nm"),
            Band(name="B208", description="Reflectance for Wavelength: 1922.713 nm, FWHM: 8.701 nm"),
            Band(name="B208_GW", description="Usable wavelengths flag for Wavelength: 1922.713 nm, FWHM: 8.701 nm"),
            Band(name="B209", description="Reflectance for Wavelength: 1930.137 nm, FWHM: 8.702 nm"),
            Band(name="B209_GW", description="Usable wavelengths flag for Wavelength: 1930.137 nm, FWHM: 8.702 nm"),
            Band(name="B210", description="Reflectance for Wavelength: 1937.561 nm, FWHM: 8.704 nm"),
            Band(name="B210_GW", description="Usable wavelengths flag for Wavelength: 1937.561 nm, FWHM: 8.704 nm"),
            Band(name="B211", description="Reflectance for Wavelength: 1944.984 nm, FWHM: 8.705 nm"),
            Band(name="B211_GW", description="Usable wavelengths flag for Wavelength: 1944.984 nm, FWHM: 8.705 nm"),
            Band(name="B212", description="Reflectance for Wavelength: 1952.407 nm, FWHM: 8.706 nm"),
            Band(name="B212_GW", description="Usable wavelengths flag for Wavelength: 1952.407 nm, FWHM: 8.706 nm"),
            Band(name="B213", description="Reflectance for Wavelength: 1959.829 nm, FWHM: 8.708 nm"),
            Band(name="B213_GW", description="Usable wavelengths flag for Wavelength: 1959.829 nm, FWHM: 8.708 nm"),
            Band(name="B214", description="Reflectance for Wavelength: 1967.252 nm, FWHM: 8.709 nm"),
            Band(name="B214_GW", description="Usable wavelengths flag for Wavelength: 1967.252 nm, FWHM: 8.709 nm"),
            Band(name="B215", description="Reflectance for Wavelength: 1974.673 nm, FWHM: 8.711 nm"),
            Band(name="B215_GW", description="Usable wavelengths flag for Wavelength: 1974.673 nm, FWHM: 8.711 nm"),
            Band(name="B216", description="Reflectance for Wavelength: 1982.095 nm, FWHM: 8.712 nm"),
            Band(name="B216_GW", description="Usable wavelengths flag for Wavelength: 1982.095 nm, FWHM: 8.712 nm"),
            Band(name="B217", description="Reflectance for Wavelength: 1989.515 nm, FWHM: 8.714 nm"),
            Band(name="B217_GW", description="Usable wavelengths flag for Wavelength: 1989.515 nm, FWHM: 8.714 nm"),
            Band(name="B218", description="Reflectance for Wavelength: 1996.936 nm, FWHM: 8.715 nm"),
            Band(name="B218_GW", description="Usable wavelengths flag for Wavelength: 1996.936 nm, FWHM: 8.715 nm"),
            Band(name="B219", description="Reflectance for Wavelength: 2004.355 nm, FWHM: 8.716 nm"),
            Band(name="B219_GW", description="Usable wavelengths flag for Wavelength: 2004.355 nm, FWHM: 8.716 nm"),
            Band(name="B220", description="Reflectance for Wavelength: 2011.775 nm, FWHM: 8.718 nm"),
            Band(name="B220_GW", description="Usable wavelengths flag for Wavelength: 2011.775 nm, FWHM: 8.718 nm"),
            Band(name="B221", description="Reflectance for Wavelength: 2019.193 nm, FWHM: 8.719 nm"),
            Band(name="B221_GW", description="Usable wavelengths flag for Wavelength: 2019.193 nm, FWHM: 8.719 nm"),
            Band(name="B222", description="Reflectance for Wavelength: 2026.612 nm, FWHM: 8.721 nm"),
            Band(name="B222_GW", description="Usable wavelengths flag for Wavelength: 2026.612 nm, FWHM: 8.721 nm"),
            Band(name="B223", description="Reflectance for Wavelength: 2034.030 nm, FWHM: 8.722 nm"),
            Band(name="B223_GW", description="Usable wavelengths flag for Wavelength: 2034.030 nm, FWHM: 8.722 nm"),
            Band(name="B224", description="Reflectance for Wavelength: 2041.447 nm, FWHM: 8.723 nm"),
            Band(name="B224_GW", description="Usable wavelengths flag for Wavelength: 2041.447 nm, FWHM: 8.723 nm"),
            Band(name="B225", description="Reflectance for Wavelength: 2048.865 nm, FWHM: 8.725 nm"),
            Band(name="B225_GW", description="Usable wavelengths flag for Wavelength: 2048.865 nm, FWHM: 8.725 nm"),
            Band(name="B226", description="Reflectance for Wavelength: 2056.281 nm, FWHM: 8.726 nm"),
            Band(name="B226_GW", description="Usable wavelengths flag for Wavelength: 2056.281 nm, FWHM: 8.726 nm"),
            Band(name="B227", description="Reflectance for Wavelength: 2063.697 nm, FWHM: 8.727 nm"),
            Band(name="B227_GW", description="Usable wavelengths flag for Wavelength: 2063.697 nm, FWHM: 8.727 nm"),
            Band(name="B228", description="Reflectance for Wavelength: 2071.112 nm, FWHM: 8.729 nm"),
            Band(name="B228_GW", description="Usable wavelengths flag for Wavelength: 2071.112 nm, FWHM: 8.729 nm"),
            Band(name="B229", description="Reflectance for Wavelength: 2078.527 nm, FWHM: 8.730 nm"),
            Band(name="B229_GW", description="Usable wavelengths flag for Wavelength: 2078.527 nm, FWHM: 8.730 nm"),
            Band(name="B230", description="Reflectance for Wavelength: 2085.942 nm, FWHM: 8.732 nm"),
            Band(name="B230_GW", description="Usable wavelengths flag for Wavelength: 2085.942 nm, FWHM: 8.732 nm"),
            Band(name="B231", description="Reflectance for Wavelength: 2093.356 nm, FWHM: 8.733 nm"),
            Band(name="B231_GW", description="Usable wavelengths flag for Wavelength: 2093.356 nm, FWHM: 8.733 nm"),
            Band(name="B232", description="Reflectance for Wavelength: 2100.769 nm, FWHM: 8.734 nm"),
            Band(name="B232_GW", description="Usable wavelengths flag for Wavelength: 2100.769 nm, FWHM: 8.734 nm"),
            Band(name="B233", description="Reflectance for Wavelength: 2108.182 nm, FWHM: 8.736 nm"),
            Band(name="B233_GW", description="Usable wavelengths flag for Wavelength: 2108.182 nm, FWHM: 8.736 nm"),
            Band(name="B234", description="Reflectance for Wavelength: 2115.594 nm, FWHM: 8.737 nm"),
            Band(name="B234_GW", description="Usable wavelengths flag for Wavelength: 2115.594 nm, FWHM: 8.737 nm"),
            Band(name="B235", description="Reflectance for Wavelength: 2123.006 nm, FWHM: 8.739 nm"),
            Band(name="B235_GW", description="Usable wavelengths flag for Wavelength: 2123.006 nm, FWHM: 8.739 nm"),
            Band(name="B236", description="Reflectance for Wavelength: 2130.417 nm, FWHM: 8.740 nm"),
            Band(name="B236_GW", description="Usable wavelengths flag for Wavelength: 2130.417 nm, FWHM: 8.740 nm"),
            Band(name="B237", description="Reflectance for Wavelength: 2137.829 nm, FWHM: 8.741 nm"),
            Band(name="B237_GW", description="Usable wavelengths flag for Wavelength: 2137.829 nm, FWHM: 8.741 nm"),
            Band(name="B238", description="Reflectance for Wavelength: 2145.239 nm, FWHM: 8.743 nm"),
            Band(name="B238_GW", description="Usable wavelengths flag for Wavelength: 2145.239 nm, FWHM: 8.743 nm"),
            Band(name="B239", description="Reflectance for Wavelength: 2152.648 nm, FWHM: 8.744 nm"),
            Band(name="B239_GW", description="Usable wavelengths flag for Wavelength: 2152.648 nm, FWHM: 8.744 nm"),
            Band(name="B240", description="Reflectance for Wavelength: 2160.058 nm, FWHM: 8.746 nm"),
            Band(name="B240_GW", description="Usable wavelengths flag for Wavelength: 2160.058 nm, FWHM: 8.746 nm"),
            Band(name="B241", description="Reflectance for Wavelength: 2167.467 nm, FWHM: 8.747 nm"),
            Band(name="B241_GW", description="Usable wavelengths flag for Wavelength: 2167.467 nm, FWHM: 8.747 nm"),
            Band(name="B242", description="Reflectance for Wavelength: 2174.875 nm, FWHM: 8.748 nm"),
            Band(name="B242_GW", description="Usable wavelengths flag for Wavelength: 2174.875 nm, FWHM: 8.748 nm"),
            Band(name="B243", description="Reflectance for Wavelength: 2182.283 nm, FWHM: 8.750 nm"),
            Band(name="B243_GW", description="Usable wavelengths flag for Wavelength: 2182.283 nm, FWHM: 8.750 nm"),
            Band(name="B244", description="Reflectance for Wavelength: 2189.690 nm, FWHM: 8.751 nm"),
            Band(name="B244_GW", description="Usable wavelengths flag for Wavelength: 2189.690 nm, FWHM: 8.751 nm"),
            Band(name="B245", description="Reflectance for Wavelength: 2197.097 nm, FWHM: 8.753 nm"),
            Band(name="B245_GW", description="Usable wavelengths flag for Wavelength: 2197.097 nm, FWHM: 8.753 nm"),
            Band(name="B246", description="Reflectance for Wavelength: 2204.503 nm, FWHM: 8.754 nm"),
            Band(name="B246_GW", description="Usable wavelengths flag for Wavelength: 2204.503 nm, FWHM: 8.754 nm"),
            Band(name="B247", description="Reflectance for Wavelength: 2211.909 nm, FWHM: 8.755 nm"),
            Band(name="B247_GW", description="Usable wavelengths flag for Wavelength: 2211.909 nm, FWHM: 8.755 nm"),
            Band(name="B248", description="Reflectance for Wavelength: 2219.315 nm, FWHM: 8.757 nm"),
            Band(name="B248_GW", description="Usable wavelengths flag for Wavelength: 2219.315 nm, FWHM: 8.757 nm"),
            Band(name="B249", description="Reflectance for Wavelength: 2226.719 nm, FWHM: 8.758 nm"),
            Band(name="B249_GW", description="Usable wavelengths flag for Wavelength: 2226.719 nm, FWHM: 8.758 nm"),
            Band(name="B250", description="Reflectance for Wavelength: 2234.123 nm, FWHM: 8.760 nm"),
            Band(name="B250_GW", description="Usable wavelengths flag for Wavelength: 2234.123 nm, FWHM: 8.760 nm"),
            Band(name="B251", description="Reflectance for Wavelength: 2241.527 nm, FWHM: 8.761 nm"),
            Band(name="B251_GW", description="Usable wavelengths flag for Wavelength: 2241.527 nm, FWHM: 8.761 nm"),
            Band(name="B252", description="Reflectance for Wavelength: 2248.930 nm, FWHM: 8.763 nm"),
            Band(name="B252_GW", description="Usable wavelengths flag for Wavelength: 2248.930 nm, FWHM: 8.763 nm"),
            Band(name="B253", description="Reflectance for Wavelength: 2256.333 nm, FWHM: 8.764 nm"),
            Band(name="B253_GW", description="Usable wavelengths flag for Wavelength: 2256.333 nm, FWHM: 8.764 nm"),
            Band(name="B254", description="Reflectance for Wavelength: 2263.735 nm, FWHM: 8.765 nm"),
            Band(name="B254_GW", description="Usable wavelengths flag for Wavelength: 2263.735 nm, FWHM: 8.765 nm"),
            Band(name="B255", description="Reflectance for Wavelength: 2271.136 nm, FWHM: 8.767 nm"),
            Band(name="B255_GW", description="Usable wavelengths flag for Wavelength: 2271.136 nm, FWHM: 8.767 nm"),
            Band(name="B256", description="Reflectance for Wavelength: 2278.538 nm, FWHM: 8.768 nm"),
            Band(name="B256_GW", description="Usable wavelengths flag for Wavelength: 2278.538 nm, FWHM: 8.768 nm"),
            Band(name="B257", description="Reflectance for Wavelength: 2285.939 nm, FWHM: 8.770 nm"),
            Band(name="B257_GW", description="Usable wavelengths flag for Wavelength: 2285.939 nm, FWHM: 8.770 nm"),
            Band(name="B258", description="Reflectance for Wavelength: 2293.339 nm, FWHM: 8.771 nm"),
            Band(name="B258_GW", description="Usable wavelengths flag for Wavelength: 2293.339 nm, FWHM: 8.771 nm"),
            Band(name="B259", description="Reflectance for Wavelength: 2300.738 nm, FWHM: 8.772 nm"),
            Band(name="B259_GW", description="Usable wavelengths flag for Wavelength: 2300.738 nm, FWHM: 8.772 nm"),
            Band(name="B260", description="Reflectance for Wavelength: 2308.136 nm, FWHM: 8.774 nm"),
            Band(name="B260_GW", description="Usable wavelengths flag for Wavelength: 2308.136 nm, FWHM: 8.774 nm"),
            Band(name="B261", description="Reflectance for Wavelength: 2315.534 nm, FWHM: 8.775 nm"),
            Band(name="B261_GW", description="Usable wavelengths flag for Wavelength: 2315.534 nm, FWHM: 8.775 nm"),
            Band(name="B262", description="Reflectance for Wavelength: 2322.933 nm, FWHM: 8.777 nm"),
            Band(name="B262_GW", description="Usable wavelengths flag for Wavelength: 2322.933 nm, FWHM: 8.777 nm"),
            Band(name="B263", description="Reflectance for Wavelength: 2330.330 nm, FWHM: 8.778 nm"),
            Band(name="B263_GW", description="Usable wavelengths flag for Wavelength: 2330.330 nm, FWHM: 8.778 nm"),
            Band(name="B264", description="Reflectance for Wavelength: 2337.726 nm, FWHM: 8.779 nm"),
            Band(name="B264_GW", description="Usable wavelengths flag for Wavelength: 2337.726 nm, FWHM: 8.779 nm"),
            Band(name="B265", description="Reflectance for Wavelength: 2345.122 nm, FWHM: 8.781 nm"),
            Band(name="B265_GW", description="Usable wavelengths flag for Wavelength: 2345.122 nm, FWHM: 8.781 nm"),
            Band(name="B266", description="Reflectance for Wavelength: 2352.517 nm, FWHM: 8.782 nm"),
            Band(name="B266_GW", description="Usable wavelengths flag for Wavelength: 2352.517 nm, FWHM: 8.782 nm"),
            Band(name="B267", description="Reflectance for Wavelength: 2359.913 nm, FWHM: 8.783 nm"),
            Band(name="B267_GW", description="Usable wavelengths flag for Wavelength: 2359.913 nm, FWHM: 8.783 nm"),
            Band(name="B268", description="Reflectance for Wavelength: 2367.307 nm, FWHM: 8.785 nm"),
            Band(name="B268_GW", description="Usable wavelengths flag for Wavelength: 2367.307 nm, FWHM: 8.785 nm"),
            Band(name="B269", description="Reflectance for Wavelength: 2374.701 nm, FWHM: 8.786 nm"),
            Band(name="B269_GW", description="Usable wavelengths flag for Wavelength: 2374.701 nm, FWHM: 8.786 nm"),
            Band(name="B270", description="Reflectance for Wavelength: 2382.094 nm, FWHM: 8.788 nm"),
            Band(name="B270_GW", description="Usable wavelengths flag for Wavelength: 2382.094 nm, FWHM: 8.788 nm"),
            Band(name="B271", description="Reflectance for Wavelength: 2389.486 nm, FWHM: 8.789 nm"),
            Band(name="B271_GW", description="Usable wavelengths flag for Wavelength: 2389.486 nm, FWHM: 8.789 nm"),
            Band(name="B272", description="Reflectance for Wavelength: 2396.878 nm, FWHM: 8.790 nm"),
            Band(name="B272_GW", description="Usable wavelengths flag for Wavelength: 2396.878 nm, FWHM: 8.790 nm"),
            Band(name="B273", description="Reflectance for Wavelength: 2404.270 nm, FWHM: 8.792 nm"),
            Band(name="B273_GW", description="Usable wavelengths flag for Wavelength: 2404.270 nm, FWHM: 8.792 nm"),
            Band(name="B274", description="Reflectance for Wavelength: 2411.660 nm, FWHM: 8.793 nm"),
            Band(name="B274_GW", description="Usable wavelengths flag for Wavelength: 2411.660 nm, FWHM: 8.793 nm"),
            Band(name="B275", description="Reflectance for Wavelength: 2419.051 nm, FWHM: 8.795 nm"),
            Band(name="B275_GW", description="Usable wavelengths flag for Wavelength: 2419.051 nm, FWHM: 8.795 nm"),
            Band(name="B276", description="Reflectance for Wavelength: 2426.440 nm, FWHM: 8.796 nm"),
            Band(name="B276_GW", description="Usable wavelengths flag for Wavelength: 2426.440 nm, FWHM: 8.796 nm"),
            Band(name="B277", description="Reflectance for Wavelength: 2433.830 nm, FWHM: 8.797 nm"),
            Band(name="B277_GW", description="Usable wavelengths flag for Wavelength: 2433.830 nm, FWHM: 8.797 nm"),
            Band(name="B278", description="Reflectance for Wavelength: 2441.218 nm, FWHM: 8.799 nm"),
            Band(name="B278_GW", description="Usable wavelengths flag for Wavelength: 2441.218 nm, FWHM: 8.799 nm"),
            Band(name="B279", description="Reflectance for Wavelength: 2448.606 nm, FWHM: 8.800 nm"),
            Band(name="B279_GW", description="Usable wavelengths flag for Wavelength: 2448.606 nm, FWHM: 8.800 nm"),
            Band(name="B280", description="Reflectance for Wavelength: 2455.994 nm, FWHM: 8.802 nm"),
            Band(name="B280_GW", description="Usable wavelengths flag for Wavelength: 2455.994 nm, FWHM: 8.802 nm"),
            Band(name="B281", description="Reflectance for Wavelength: 2463.382 nm, FWHM: 8.803 nm"),
            Band(name="B281_GW", description="Usable wavelengths flag for Wavelength: 2463.382 nm, FWHM: 8.803 nm"),
            Band(name="B282", description="Reflectance for Wavelength: 2470.768 nm, FWHM: 8.804 nm"),
            Band(name="B282_GW", description="Usable wavelengths flag for Wavelength: 2470.768 nm, FWHM: 8.804 nm"),
            Band(name="B283", description="Reflectance for Wavelength: 2478.153 nm, FWHM: 8.806 nm"),
            Band(name="B283_GW", description="Usable wavelengths flag for Wavelength: 2478.153 nm, FWHM: 8.806 nm"),
            Band(name="B284", description="Reflectance for Wavelength: 2485.539 nm, FWHM: 8.807 nm"),
            Band(name="B284_GW", description="Usable wavelengths flag for Wavelength: 2485.539 nm, FWHM: 8.807 nm"),
            Band(name="B285", description="Reflectance for Wavelength: 2492.924 nm, FWHM: 8.809 nm"),
            Band(name="B285_GW", description="Usable wavelengths flag for Wavelength: 2492.924 nm, FWHM: 8.809 nm"),
            Band(name="elev", description="Elevation"),
        ]
    ),
    Product(
        product_id="EMIT_L2A_RFLUNCERT.001",
        description="L2A Reflectance Uncertainty",
        bands=[
            Band(name="B001", description="Reflectance Uncertainty for Wavelength: 381.006 nm, FWHM: 8.415 nm"),
            Band(name="B002", description="Reflectance Uncertainty for Wavelength: 388.409 nm, FWHM: 8.415 nm"),
            Band(name="B003", description="Reflectance Uncertainty for Wavelength: 395.816 nm, FWHM: 8.415 nm"),
            Band(name="B004", description="Reflectance Uncertainty for Wavelength: 403.225 nm, FWHM: 8.415 nm"),
            Band(name="B005", description="Reflectance Uncertainty for Wavelength: 410.638 nm, FWHM: 8.417 nm"),
            Band(name="B006", description="Reflectance Uncertainty for Wavelength: 418.054 nm, FWHM: 8.418 nm"),
            Band(name="B007", description="Reflectance Uncertainty for Wavelength: 425.472 nm, FWHM: 8.419 nm"),
            Band(name="B008", description="Reflectance Uncertainty for Wavelength: 432.893 nm, FWHM: 8.421 nm"),
            Band(name="B009", description="Reflectance Uncertainty for Wavelength: 440.317 nm, FWHM: 8.422 nm"),
            Band(name="B010", description="Reflectance Uncertainty for Wavelength: 447.743 nm, FWHM: 8.424 nm"),
            Band(name="B011", description="Reflectance Uncertainty for Wavelength: 455.170 nm, FWHM: 8.425 nm"),
            Band(name="B012", description="Reflectance Uncertainty for Wavelength: 462.599 nm, FWHM: 8.426 nm"),
            Band(name="B013", description="Reflectance Uncertainty for Wavelength: 470.030 nm, FWHM: 8.428 nm"),
            Band(name="B014", description="Reflectance Uncertainty for Wavelength: 477.463 nm, FWHM: 8.429 nm"),
            Band(name="B015", description="Reflectance Uncertainty for Wavelength: 484.897 nm, FWHM: 8.431 nm"),
            Band(name="B016", description="Reflectance Uncertainty for Wavelength: 492.333 nm, FWHM: 8.432 nm"),
            Band(name="B017", description="Reflectance Uncertainty for Wavelength: 499.771 nm, FWHM: 8.433 nm"),
            Band(name="B018", description="Reflectance Uncertainty for Wavelength: 507.210 nm, FWHM: 8.435 nm"),
            Band(name="B019", description="Reflectance Uncertainty for Wavelength: 514.650 nm, FWHM: 8.436 nm"),
            Band(name="B020", description="Reflectance Uncertainty for Wavelength: 522.091 nm, FWHM: 8.438 nm"),
            Band(name="B021", description="Reflectance Uncertainty for Wavelength: 529.533 nm, FWHM: 8.439 nm"),
            Band(name="B022", description="Reflectance Uncertainty for Wavelength: 536.977 nm, FWHM: 8.440 nm"),
            Band(name="B023", description="Reflectance Uncertainty for Wavelength: 544.421 nm, FWHM: 8.442 nm"),
            Band(name="B024", description="Reflectance Uncertainty for Wavelength: 551.867 nm, FWHM: 8.443 nm"),
            Band(name="B025", description="Reflectance Uncertainty for Wavelength: 559.314 nm, FWHM: 8.445 nm"),
            Band(name="B026", description="Reflectance Uncertainty for Wavelength: 566.762 nm, FWHM: 8.446 nm"),
            Band(name="B027", description="Reflectance Uncertainty for Wavelength: 574.209 nm, FWHM: 8.447 nm"),
            Band(name="B028", description="Reflectance Uncertainty for Wavelength: 581.659 nm, FWHM: 8.449 nm"),
            Band(name="B029", description="Reflectance Uncertainty for Wavelength: 589.108 nm, FWHM: 8.450 nm"),
            Band(name="B030", description="Reflectance Uncertainty for Wavelength: 596.558 nm, FWHM: 8.452 nm"),
            Band(name="B031", description="Reflectance Uncertainty for Wavelength: 604.010 nm, FWHM: 8.453 nm"),
            Band(name="B032", description="Reflectance Uncertainty for Wavelength: 611.462 nm, FWHM: 8.454 nm"),
            Band(name="B033", description="Reflectance Uncertainty for Wavelength: 618.915 nm, FWHM: 8.456 nm"),
            Band(name="B034", description="Reflectance Uncertainty for Wavelength: 626.368 nm, FWHM: 8.457 nm"),
            Band(name="B035", description="Reflectance Uncertainty for Wavelength: 633.821 nm, FWHM: 8.459 nm"),
            Band(name="B036", description="Reflectance Uncertainty for Wavelength: 641.276 nm, FWHM: 8.460 nm"),
            Band(name="B037", description="Reflectance Uncertainty for Wavelength: 648.730 nm, FWHM: 8.461 nm"),
            Band(name="B038", description="Reflectance Uncertainty for Wavelength: 656.186 nm, FWHM: 8.463 nm"),
            Band(name="B039", description="Reflectance Uncertainty for Wavelength: 663.641 nm, FWHM: 8.464 nm"),
            Band(name="B040", description="Reflectance Uncertainty for Wavelength: 671.098 nm, FWHM: 8.466 nm"),
            Band(name="B041", description="Reflectance Uncertainty for Wavelength: 678.554 nm, FWHM: 8.467 nm"),
            Band(name="B042", description="Reflectance Uncertainty for Wavelength: 686.010 nm, FWHM: 8.468 nm"),
            Band(name="B043", description="Reflectance Uncertainty for Wavelength: 693.468 nm, FWHM: 8.470 nm"),
            Band(name="B044", description="Reflectance Uncertainty for Wavelength: 700.925 nm, FWHM: 8.471 nm"),
            Band(name="B045", description="Reflectance Uncertainty for Wavelength: 708.384 nm, FWHM: 8.473 nm"),
            Band(name="B046", description="Reflectance Uncertainty for Wavelength: 715.841 nm, FWHM: 8.474 nm"),
            Band(name="B047", description="Reflectance Uncertainty for Wavelength: 723.299 nm, FWHM: 8.475 nm"),
            Band(name="B048", description="Reflectance Uncertainty for Wavelength: 730.759 nm, FWHM: 8.477 nm"),
            Band(name="B049", description="Reflectance Uncertainty for Wavelength: 738.217 nm, FWHM: 8.478 nm"),
            Band(name="B050", description="Reflectance Uncertainty for Wavelength: 745.677 nm, FWHM: 8.480 nm"),
            Band(name="B051", description="Reflectance Uncertainty for Wavelength: 753.136 nm, FWHM: 8.481 nm"),
            Band(name="B052", description="Reflectance Uncertainty for Wavelength: 760.596 nm, FWHM: 8.482 nm"),
            Band(name="B053", description="Reflectance Uncertainty for Wavelength: 768.056 nm, FWHM: 8.484 nm"),
            Band(name="B054", description="Reflectance Uncertainty for Wavelength: 775.516 nm, FWHM: 8.485 nm"),
            Band(name="B055", description="Reflectance Uncertainty for Wavelength: 782.978 nm, FWHM: 8.487 nm"),
            Band(name="B056", description="Reflectance Uncertainty for Wavelength: 790.438 nm, FWHM: 8.488 nm"),
            Band(name="B057", description="Reflectance Uncertainty for Wavelength: 797.899 nm, FWHM: 8.489 nm"),
            Band(name="B058", description="Reflectance Uncertainty for Wavelength: 805.362 nm, FWHM: 8.491 nm"),
            Band(name="B059", description="Reflectance Uncertainty for Wavelength: 812.823 nm, FWHM: 8.492 nm"),
            Band(name="B060", description="Reflectance Uncertainty for Wavelength: 820.285 nm, FWHM: 8.494 nm"),
            Band(name="B061", description="Reflectance Uncertainty for Wavelength: 827.746 nm, FWHM: 8.495 nm"),
            Band(name="B062", description="Reflectance Uncertainty for Wavelength: 835.207 nm, FWHM: 8.496 nm"),
            Band(name="B063", description="Reflectance Uncertainty for Wavelength: 842.670 nm, FWHM: 8.498 nm"),
            Band(name="B064", description="Reflectance Uncertainty for Wavelength: 850.131 nm, FWHM: 8.499 nm"),
            Band(name="B065", description="Reflectance Uncertainty for Wavelength: 857.594 nm, FWHM: 8.501 nm"),
            Band(name="B066", description="Reflectance Uncertainty for Wavelength: 865.055 nm, FWHM: 8.502 nm"),
            Band(name="B067", description="Reflectance Uncertainty for Wavelength: 872.518 nm, FWHM: 8.503 nm"),
            Band(name="B068", description="Reflectance Uncertainty for Wavelength: 879.980 nm, FWHM: 8.505 nm"),
            Band(name="B069", description="Reflectance Uncertainty for Wavelength: 887.441 nm, FWHM: 8.506 nm"),
            Band(name="B070", description="Reflectance Uncertainty for Wavelength: 894.904 nm, FWHM: 8.508 nm"),
            Band(name="B071", description="Reflectance Uncertainty for Wavelength: 902.366 nm, FWHM: 8.509 nm"),
            Band(name="B072", description="Reflectance Uncertainty for Wavelength: 909.829 nm, FWHM: 8.510 nm"),
            Band(name="B073", description="Reflectance Uncertainty for Wavelength: 917.291 nm, FWHM: 8.512 nm"),
            Band(name="B074", description="Reflectance Uncertainty for Wavelength: 924.754 nm, FWHM: 8.513 nm"),
            Band(name="B075", description="Reflectance Uncertainty for Wavelength: 932.216 nm, FWHM: 8.515 nm"),
            Band(name="B076", description="Reflectance Uncertainty for Wavelength: 939.679 nm, FWHM: 8.516 nm"),
            Band(name="B077", description="Reflectance Uncertainty for Wavelength: 947.140 nm, FWHM: 8.517 nm"),
            Band(name="B078", description="Reflectance Uncertainty for Wavelength: 954.603 nm, FWHM: 8.519 nm"),
            Band(name="B079", description="Reflectance Uncertainty for Wavelength: 962.064 nm, FWHM: 8.520 nm"),
            Band(name="B080", description="Reflectance Uncertainty for Wavelength: 969.527 nm, FWHM: 8.522 nm"),
            Band(name="B081", description="Reflectance Uncertainty for Wavelength: 976.988 nm, FWHM: 8.523 nm"),
            Band(name="B082", description="Reflectance Uncertainty for Wavelength: 984.450 nm, FWHM: 8.524 nm"),
            Band(name="B083", description="Reflectance Uncertainty for Wavelength: 991.911 nm, FWHM: 8.526 nm"),
            Band(name="B084", description="Reflectance Uncertainty for Wavelength: 999.373 nm, FWHM: 8.527 nm"),
            Band(name="B085", description="Reflectance Uncertainty for Wavelength: 1006.834 nm, FWHM: 8.529 nm"),
            Band(name="B086", description="Reflectance Uncertainty for Wavelength: 1014.295 nm, FWHM: 8.530 nm"),
            Band(name="B087", description="Reflectance Uncertainty for Wavelength: 1021.757 nm, FWHM: 8.531 nm"),
            Band(name="B088", description="Reflectance Uncertainty for Wavelength: 1029.217 nm, FWHM: 8.533 nm"),
            Band(name="B089", description="Reflectance Uncertainty for Wavelength: 1036.678 nm, FWHM: 8.534 nm"),
            Band(name="B090", description="Reflectance Uncertainty for Wavelength: 1044.138 nm, FWHM: 8.536 nm"),
            Band(name="B091", description="Reflectance Uncertainty for Wavelength: 1051.599 nm, FWHM: 8.537 nm"),
            Band(name="B092", description="Reflectance Uncertainty for Wavelength: 1059.060 nm, FWHM: 8.538 nm"),
            Band(name="B093", description="Reflectance Uncertainty for Wavelength: 1066.520 nm, FWHM: 8.540 nm"),
            Band(name="B094", description="Reflectance Uncertainty for Wavelength: 1073.980 nm, FWHM: 8.541 nm"),
            Band(name="B095", description="Reflectance Uncertainty for Wavelength: 1081.440 nm, FWHM: 8.543 nm"),
            Band(name="B096", description="Reflectance Uncertainty for Wavelength: 1088.900 nm, FWHM: 8.544 nm"),
            Band(name="B097", description="Reflectance Uncertainty for Wavelength: 1096.360 nm, FWHM: 8.545 nm"),
            Band(name="B098", description="Reflectance Uncertainty for Wavelength: 1103.818 nm, FWHM: 8.547 nm"),
            Band(name="B099", description="Reflectance Uncertainty for Wavelength: 1111.278 nm, FWHM: 8.548 nm"),
            Band(name="B100", description="Reflectance Uncertainty for Wavelength: 1118.737 nm, FWHM: 8.550 nm"),
            Band(name="B101", description="Reflectance Uncertainty for Wavelength: 1126.196 nm, FWHM: 8.551 nm"),
            Band(name="B102", description="Reflectance Uncertainty for Wavelength: 1133.655 nm, FWHM: 8.552 nm"),
            Band(name="B103", description="Reflectance Uncertainty for Wavelength: 1141.113 nm, FWHM: 8.554 nm"),
            Band(name="B104", description="Reflectance Uncertainty for Wavelength: 1148.572 nm, FWHM: 8.555 nm"),
            Band(name="B105", description="Reflectance Uncertainty for Wavelength: 1156.030 nm, FWHM: 8.557 nm"),
            Band(name="B106", description="Reflectance Uncertainty for Wavelength: 1163.488 nm, FWHM: 8.558 nm"),
            Band(name="B107", description="Reflectance Uncertainty for Wavelength: 1170.946 nm, FWHM: 8.559 nm"),
            Band(name="B108", description="Reflectance Uncertainty for Wavelength: 1178.404 nm, FWHM: 8.561 nm"),
            Band(name="B109", description="Reflectance Uncertainty for Wavelength: 1185.862 nm, FWHM: 8.562 nm"),
            Band(name="B110", description="Reflectance Uncertainty for Wavelength: 1193.318 nm, FWHM: 8.564 nm"),
            Band(name="B111", description="Reflectance Uncertainty for Wavelength: 1200.776 nm, FWHM: 8.565 nm"),
            Band(name="B112", description="Reflectance Uncertainty for Wavelength: 1208.233 nm, FWHM: 8.566 nm"),
            Band(name="B113", description="Reflectance Uncertainty for Wavelength: 1215.690 nm, FWHM: 8.568 nm"),
            Band(name="B114", description="Reflectance Uncertainty for Wavelength: 1223.147 nm, FWHM: 8.569 nm"),
            Band(name="B115", description="Reflectance Uncertainty for Wavelength: 1230.604 nm, FWHM: 8.571 nm"),
            Band(name="B116", description="Reflectance Uncertainty for Wavelength: 1238.060 nm, FWHM: 8.572 nm"),
            Band(name="B117", description="Reflectance Uncertainty for Wavelength: 1245.515 nm, FWHM: 8.573 nm"),
            Band(name="B118", description="Reflectance Uncertainty for Wavelength: 1252.972 nm, FWHM: 8.575 nm"),
            Band(name="B119", description="Reflectance Uncertainty for Wavelength: 1260.428 nm, FWHM: 8.576 nm"),
            Band(name="B120", description="Reflectance Uncertainty for Wavelength: 1267.883 nm, FWHM: 8.578 nm"),
            Band(name="B121", description="Reflectance Uncertainty for Wavelength: 1275.339 nm, FWHM: 8.579 nm"),
            Band(name="B122", description="Reflectance Uncertainty for Wavelength: 1282.794 nm, FWHM: 8.580 nm"),
            Band(name="B123", description="Reflectance Uncertainty for Wavelength: 1290.250 nm, FWHM: 8.582 nm"),
            Band(name="B124", description="Reflectance Uncertainty for Wavelength: 1297.705 nm, FWHM: 8.583 nm"),
            Band(name="B125", description="Reflectance Uncertainty for Wavelength: 1305.160 nm, FWHM: 8.585 nm"),
            Band(name="B126", description="Reflectance Uncertainty for Wavelength: 1312.614 nm, FWHM: 8.586 nm"),
            Band(name="B127", description="Reflectance Uncertainty for Wavelength: 1320.068 nm, FWHM: 8.587 nm"),
            Band(name="B128", description="Reflectance Uncertainty for Wavelength: 1327.522 nm, FWHM: 8.589 nm"),
            Band(name="B129", description="Reflectance Uncertainty for Wavelength: 1334.976 nm, FWHM: 8.590 nm"),
            Band(name="B130", description="Reflectance Uncertainty for Wavelength: 1342.429 nm, FWHM: 8.592 nm"),
            Band(name="B131", description="Reflectance Uncertainty for Wavelength: 1349.882 nm, FWHM: 8.593 nm"),
            Band(name="B132", description="Reflectance Uncertainty for Wavelength: 1357.335 nm, FWHM: 8.594 nm"),
            Band(name="B133", description="Reflectance Uncertainty for Wavelength: 1364.787 nm, FWHM: 8.596 nm"),
            Band(name="B134", description="Reflectance Uncertainty for Wavelength: 1372.238 nm, FWHM: 8.597 nm"),
            Band(name="B135", description="Reflectance Uncertainty for Wavelength: 1379.691 nm, FWHM: 8.599 nm"),
            Band(name="B136", description="Reflectance Uncertainty for Wavelength: 1387.142 nm, FWHM: 8.600 nm"),
            Band(name="B137", description="Reflectance Uncertainty for Wavelength: 1394.593 nm, FWHM: 8.601 nm"),
            Band(name="B138", description="Reflectance Uncertainty for Wavelength: 1402.043 nm, FWHM: 8.603 nm"),
            Band(name="B139", description="Reflectance Uncertainty for Wavelength: 1409.494 nm, FWHM: 8.604 nm"),
            Band(name="B140", description="Reflectance Uncertainty for Wavelength: 1416.944 nm, FWHM: 8.606 nm"),
            Band(name="B141", description="Reflectance Uncertainty for Wavelength: 1424.393 nm, FWHM: 8.607 nm"),
            Band(name="B142", description="Reflectance Uncertainty for Wavelength: 1431.843 nm, FWHM: 8.608 nm"),
            Band(name="B143", description="Reflectance Uncertainty for Wavelength: 1439.292 nm, FWHM: 8.610 nm"),
            Band(name="B144", description="Reflectance Uncertainty for Wavelength: 1446.740 nm, FWHM: 8.611 nm"),
            Band(name="B145", description="Reflectance Uncertainty for Wavelength: 1454.189 nm, FWHM: 8.613 nm"),
            Band(name="B146", description="Reflectance Uncertainty for Wavelength: 1461.637 nm, FWHM: 8.614 nm"),
            Band(name="B147", description="Reflectance Uncertainty for Wavelength: 1469.085 nm, FWHM: 8.615 nm"),
            Band(name="B148", description="Reflectance Uncertainty for Wavelength: 1476.532 nm, FWHM: 8.617 nm"),
            Band(name="B149", description="Reflectance Uncertainty for Wavelength: 1483.980 nm, FWHM: 8.618 nm"),
            Band(name="B150", description="Reflectance Uncertainty for Wavelength: 1491.426 nm, FWHM: 8.620 nm"),
            Band(name="B151", description="Reflectance Uncertainty for Wavelength: 1498.873 nm, FWHM: 8.621 nm"),
            Band(name="B152", description="Reflectance Uncertainty for Wavelength: 1506.319 nm, FWHM: 8.622 nm"),
            Band(name="B153", description="Reflectance Uncertainty for Wavelength: 1513.765 nm, FWHM: 8.624 nm"),
            Band(name="B154", description="Reflectance Uncertainty for Wavelength: 1521.210 nm, FWHM: 8.625 nm"),
            Band(name="B155", description="Reflectance Uncertainty for Wavelength: 1528.655 nm, FWHM: 8.627 nm"),
            Band(name="B156", description="Reflectance Uncertainty for Wavelength: 1536.101 nm, FWHM: 8.628 nm"),
            Band(name="B157", description="Reflectance Uncertainty for Wavelength: 1543.545 nm, FWHM: 8.629 nm"),
            Band(name="B158", description="Reflectance Uncertainty for Wavelength: 1550.989 nm, FWHM: 8.631 nm"),
            Band(name="B159", description="Reflectance Uncertainty for Wavelength: 1558.433 nm, FWHM: 8.632 nm"),
            Band(name="B160", description="Reflectance Uncertainty for Wavelength: 1565.877 nm, FWHM: 8.634 nm"),
            Band(name="B161", description="Reflectance Uncertainty for Wavelength: 1573.319 nm, FWHM: 8.635 nm"),
            Band(name="B162", description="Reflectance Uncertainty for Wavelength: 1580.762 nm, FWHM: 8.636 nm"),
            Band(name="B163", description="Reflectance Uncertainty for Wavelength: 1588.205 nm, FWHM: 8.638 nm"),
            Band(name="B164", description="Reflectance Uncertainty for Wavelength: 1595.647 nm, FWHM: 8.639 nm"),
            Band(name="B165", description="Reflectance Uncertainty for Wavelength: 1603.089 nm, FWHM: 8.641 nm"),
            Band(name="B166", description="Reflectance Uncertainty for Wavelength: 1610.530 nm, FWHM: 8.642 nm"),
            Band(name="B167", description="Reflectance Uncertainty for Wavelength: 1617.970 nm, FWHM: 8.643 nm"),
            Band(name="B168", description="Reflectance Uncertainty for Wavelength: 1625.410 nm, FWHM: 8.645 nm"),
            Band(name="B169", description="Reflectance Uncertainty for Wavelength: 1632.851 nm, FWHM: 8.646 nm"),
            Band(name="B170", description="Reflectance Uncertainty for Wavelength: 1640.290 nm, FWHM: 8.648 nm"),
            Band(name="B171", description="Reflectance Uncertainty for Wavelength: 1647.730 nm, FWHM: 8.649 nm"),
            Band(name="B172", description="Reflectance Uncertainty for Wavelength: 1655.169 nm, FWHM: 8.650 nm"),
            Band(name="B173", description="Reflectance Uncertainty for Wavelength: 1662.607 nm, FWHM: 8.652 nm"),
            Band(name="B174", description="Reflectance Uncertainty for Wavelength: 1670.046 nm, FWHM: 8.653 nm"),
            Band(name="B175", description="Reflectance Uncertainty for Wavelength: 1677.484 nm, FWHM: 8.655 nm"),
            Band(name="B176", description="Reflectance Uncertainty for Wavelength: 1684.921 nm, FWHM: 8.656 nm"),
            Band(name="B177", description="Reflectance Uncertainty for Wavelength: 1692.358 nm, FWHM: 8.657 nm"),
            Band(name="B178", description="Reflectance Uncertainty for Wavelength: 1699.795 nm, FWHM: 8.659 nm"),
            Band(name="B179", description="Reflectance Uncertainty for Wavelength: 1707.231 nm, FWHM: 8.660 nm"),
            Band(name="B180", description="Reflectance Uncertainty for Wavelength: 1714.667 nm, FWHM: 8.662 nm"),
            Band(name="B181", description="Reflectance Uncertainty for Wavelength: 1722.103 nm, FWHM: 8.663 nm"),
            Band(name="B182", description="Reflectance Uncertainty for Wavelength: 1729.538 nm, FWHM: 8.664 nm"),
            Band(name="B183", description="Reflectance Uncertainty for Wavelength: 1736.973 nm, FWHM: 8.666 nm"),
            Band(name="B184", description="Reflectance Uncertainty for Wavelength: 1744.407 nm, FWHM: 8.667 nm"),
            Band(name="B185", description="Reflectance Uncertainty for Wavelength: 1751.841 nm, FWHM: 8.669 nm"),
            Band(name="B186", description="Reflectance Uncertainty for Wavelength: 1759.275 nm, FWHM: 8.670 nm"),
            Band(name="B187", description="Reflectance Uncertainty for Wavelength: 1766.708 nm, FWHM: 8.671 nm"),
            Band(name="B188", description="Reflectance Uncertainty for Wavelength: 1774.142 nm, FWHM: 8.673 nm"),
            Band(name="B189", description="Reflectance Uncertainty for Wavelength: 1781.574 nm, FWHM: 8.674 nm"),
            Band(name="B190", description="Reflectance Uncertainty for Wavelength: 1789.007 nm, FWHM: 8.676 nm"),
            Band(name="B191", description="Reflectance Uncertainty for Wavelength: 1796.438 nm, FWHM: 8.677 nm"),
            Band(name="B192", description="Reflectance Uncertainty for Wavelength: 1803.870 nm, FWHM: 8.678 nm"),
            Band(name="B193", description="Reflectance Uncertainty for Wavelength: 1811.301 nm, FWHM: 8.680 nm"),
            Band(name="B194", description="Reflectance Uncertainty for Wavelength: 1818.731 nm, FWHM: 8.681 nm"),
            Band(name="B195", description="Reflectance Uncertainty for Wavelength: 1826.161 nm, FWHM: 8.683 nm"),
            Band(name="B196", description="Reflectance Uncertainty for Wavelength: 1833.591 nm, FWHM: 8.684 nm"),
            Band(name="B197", description="Reflectance Uncertainty for Wavelength: 1841.021 nm, FWHM: 8.685 nm"),
            Band(name="B198", description="Reflectance Uncertainty for Wavelength: 1848.449 nm, FWHM: 8.687 nm"),
            Band(name="B199", description="Reflectance Uncertainty for Wavelength: 1855.877 nm, FWHM: 8.688 nm"),
            Band(name="B200", description="Reflectance Uncertainty for Wavelength: 1863.305 nm, FWHM: 8.690 nm"),
            Band(name="B201", description="Reflectance Uncertainty for Wavelength: 1870.733 nm, FWHM: 8.691 nm"),
            Band(name="B202", description="Reflectance Uncertainty for Wavelength: 1878.160 nm, FWHM: 8.692 nm"),
            Band(name="B203", description="Reflectance Uncertainty for Wavelength: 1885.587 nm, FWHM: 8.694 nm"),
            Band(name="B204", description="Reflectance Uncertainty for Wavelength: 1893.013 nm, FWHM: 8.695 nm"),
            Band(name="B205", description="Reflectance Uncertainty for Wavelength: 1900.439 nm, FWHM: 8.697 nm"),
            Band(name="B206", description="Reflectance Uncertainty for Wavelength: 1907.864 nm, FWHM: 8.698 nm"),
            Band(name="B207", description="Reflectance Uncertainty for Wavelength: 1915.289 nm, FWHM: 8.699 nm"),
            Band(name="B208", description="Reflectance Uncertainty for Wavelength: 1922.713 nm, FWHM: 8.701 nm"),
            Band(name="B209", description="Reflectance Uncertainty for Wavelength: 1930.137 nm, FWHM: 8.702 nm"),
            Band(name="B210", description="Reflectance Uncertainty for Wavelength: 1937.561 nm, FWHM: 8.704 nm"),
            Band(name="B211", description="Reflectance Uncertainty for Wavelength: 1944.984 nm, FWHM: 8.705 nm"),
            Band(name="B212", description="Reflectance Uncertainty for Wavelength: 1952.407 nm, FWHM: 8.706 nm"),
            Band(name="B213", description="Reflectance Uncertainty for Wavelength: 1959.829 nm, FWHM: 8.708 nm"),
            Band(name="B214", description="Reflectance Uncertainty for Wavelength: 1967.252 nm, FWHM: 8.709 nm"),
            Band(name="B215", description="Reflectance Uncertainty for Wavelength: 1974.673 nm, FWHM: 8.711 nm"),
            Band(name="B216", description="Reflectance Uncertainty for Wavelength: 1982.095 nm, FWHM: 8.712 nm"),
            Band(name="B217", description="Reflectance Uncertainty for Wavelength: 1989.515 nm, FWHM: 8.714 nm"),
            Band(name="B218", description="Reflectance Uncertainty for Wavelength: 1996.936 nm, FWHM: 8.715 nm"),
            Band(name="B219", description="Reflectance Uncertainty for Wavelength: 2004.355 nm, FWHM: 8.716 nm"),
            Band(name="B220", description="Reflectance Uncertainty for Wavelength: 2011.775 nm, FWHM: 8.718 nm"),
            Band(name="B221", description="Reflectance Uncertainty for Wavelength: 2019.193 nm, FWHM: 8.719 nm"),
            Band(name="B222", description="Reflectance Uncertainty for Wavelength: 2026.612 nm, FWHM: 8.721 nm"),
            Band(name="B223", description="Reflectance Uncertainty for Wavelength: 2034.030 nm, FWHM: 8.722 nm"),
            Band(name="B224", description="Reflectance Uncertainty for Wavelength: 2041.447 nm, FWHM: 8.723 nm"),
            Band(name="B225", description="Reflectance Uncertainty for Wavelength: 2048.865 nm, FWHM: 8.725 nm"),
            Band(name="B226", description="Reflectance Uncertainty for Wavelength: 2056.281 nm, FWHM: 8.726 nm"),
            Band(name="B227", description="Reflectance Uncertainty for Wavelength: 2063.697 nm, FWHM: 8.727 nm"),
            Band(name="B228", description="Reflectance Uncertainty for Wavelength: 2071.112 nm, FWHM: 8.729 nm"),
            Band(name="B229", description="Reflectance Uncertainty for Wavelength: 2078.527 nm, FWHM: 8.730 nm"),
            Band(name="B230", description="Reflectance Uncertainty for Wavelength: 2085.942 nm, FWHM: 8.732 nm"),
            Band(name="B231", description="Reflectance Uncertainty for Wavelength: 2093.356 nm, FWHM: 8.733 nm"),
            Band(name="B232", description="Reflectance Uncertainty for Wavelength: 2100.769 nm, FWHM: 8.734 nm"),
            Band(name="B233", description="Reflectance Uncertainty for Wavelength: 2108.182 nm, FWHM: 8.736 nm"),
            Band(name="B234", description="Reflectance Uncertainty for Wavelength: 2115.594 nm, FWHM: 8.737 nm"),
            Band(name="B235", description="Reflectance Uncertainty for Wavelength: 2123.006 nm, FWHM: 8.739 nm"),
            Band(name="B236", description="Reflectance Uncertainty for Wavelength: 2130.417 nm, FWHM: 8.740 nm"),
            Band(name="B237", description="Reflectance Uncertainty for Wavelength: 2137.829 nm, FWHM: 8.741 nm"),
            Band(name="B238", description="Reflectance Uncertainty for Wavelength: 2145.239 nm, FWHM: 8.743 nm"),
            Band(name="B239", description="Reflectance Uncertainty for Wavelength: 2152.648 nm, FWHM: 8.744 nm"),
            Band(name="B240", description="Reflectance Uncertainty for Wavelength: 2160.058 nm, FWHM: 8.746 nm"),
            Band(name="B241", description="Reflectance Uncertainty for Wavelength: 2167.467 nm, FWHM: 8.747 nm"),
            Band(name="B242", description="Reflectance Uncertainty for Wavelength: 2174.875 nm, FWHM: 8.748 nm"),
            Band(name="B243", description="Reflectance Uncertainty for Wavelength: 2182.283 nm, FWHM: 8.750 nm"),
            Band(name="B244", description="Reflectance Uncertainty for Wavelength: 2189.690 nm, FWHM: 8.751 nm"),
            Band(name="B245", description="Reflectance Uncertainty for Wavelength: 2197.097 nm, FWHM: 8.753 nm"),
            Band(name="B246", description="Reflectance Uncertainty for Wavelength: 2204.503 nm, FWHM: 8.754 nm"),
            Band(name="B247", description="Reflectance Uncertainty for Wavelength: 2211.909 nm, FWHM: 8.755 nm"),
            Band(name="B248", description="Reflectance Uncertainty for Wavelength: 2219.315 nm, FWHM: 8.757 nm"),
            Band(name="B249", description="Reflectance Uncertainty for Wavelength: 2226.719 nm, FWHM: 8.758 nm"),
            Band(name="B250", description="Reflectance Uncertainty for Wavelength: 2234.123 nm, FWHM: 8.760 nm"),
            Band(name="B251", description="Reflectance Uncertainty for Wavelength: 2241.527 nm, FWHM: 8.761 nm"),
            Band(name="B252", description="Reflectance Uncertainty for Wavelength: 2248.930 nm, FWHM: 8.763 nm"),
            Band(name="B253", description="Reflectance Uncertainty for Wavelength: 2256.333 nm, FWHM: 8.764 nm"),
            Band(name="B254", description="Reflectance Uncertainty for Wavelength: 2263.735 nm, FWHM: 8.765 nm"),
            Band(name="B255", description="Reflectance Uncertainty for Wavelength: 2271.136 nm, FWHM: 8.767 nm"),
            Band(name="B256", description="Reflectance Uncertainty for Wavelength: 2278.538 nm, FWHM: 8.768 nm"),
            Band(name="B257", description="Reflectance Uncertainty for Wavelength: 2285.939 nm, FWHM: 8.770 nm"),
            Band(name="B258", description="Reflectance Uncertainty for Wavelength: 2293.339 nm, FWHM: 8.771 nm"),
            Band(name="B259", description="Reflectance Uncertainty for Wavelength: 2300.738 nm, FWHM: 8.772 nm"),
            Band(name="B260", description="Reflectance Uncertainty for Wavelength: 2308.136 nm, FWHM: 8.774 nm"),
            Band(name="B261", description="Reflectance Uncertainty for Wavelength: 2315.534 nm, FWHM: 8.775 nm"),
            Band(name="B262", description="Reflectance Uncertainty for Wavelength: 2322.933 nm, FWHM: 8.777 nm"),
            Band(name="B263", description="Reflectance Uncertainty for Wavelength: 2330.330 nm, FWHM: 8.778 nm"),
            Band(name="B264", description="Reflectance Uncertainty for Wavelength: 2337.726 nm, FWHM: 8.779 nm"),
            Band(name="B265", description="Reflectance Uncertainty for Wavelength: 2345.122 nm, FWHM: 8.781 nm"),
            Band(name="B266", description="Reflectance Uncertainty for Wavelength: 2352.517 nm, FWHM: 8.782 nm"),
            Band(name="B267", description="Reflectance Uncertainty for Wavelength: 2359.913 nm, FWHM: 8.783 nm"),
            Band(name="B268", description="Reflectance Uncertainty for Wavelength: 2367.307 nm, FWHM: 8.785 nm"),
            Band(name="B269", description="Reflectance Uncertainty for Wavelength: 2374.701 nm, FWHM: 8.786 nm"),
            Band(name="B270", description="Reflectance Uncertainty for Wavelength: 2382.094 nm, FWHM: 8.788 nm"),
            Band(name="B271", description="Reflectance Uncertainty for Wavelength: 2389.486 nm, FWHM: 8.789 nm"),
            Band(name="B272", description="Reflectance Uncertainty for Wavelength: 2396.878 nm, FWHM: 8.790 nm"),
            Band(name="B273", description="Reflectance Uncertainty for Wavelength: 2404.270 nm, FWHM: 8.792 nm"),
            Band(name="B274", description="Reflectance Uncertainty for Wavelength: 2411.660 nm, FWHM: 8.793 nm"),
            Band(name="B275", description="Reflectance Uncertainty for Wavelength: 2419.051 nm, FWHM: 8.795 nm"),
            Band(name="B276", description="Reflectance Uncertainty for Wavelength: 2426.440 nm, FWHM: 8.796 nm"),
            Band(name="B277", description="Reflectance Uncertainty for Wavelength: 2433.830 nm, FWHM: 8.797 nm"),
            Band(name="B278", description="Reflectance Uncertainty for Wavelength: 2441.218 nm, FWHM: 8.799 nm"),
            Band(name="B279", description="Reflectance Uncertainty for Wavelength: 2448.606 nm, FWHM: 8.800 nm"),
            Band(name="B280", description="Reflectance Uncertainty for Wavelength: 2455.994 nm, FWHM: 8.802 nm"),
            Band(name="B281", description="Reflectance Uncertainty for Wavelength: 2463.382 nm, FWHM: 8.803 nm"),
            Band(name="B282", description="Reflectance Uncertainty for Wavelength: 2470.768 nm, FWHM: 8.804 nm"),
            Band(name="B283", description="Reflectance Uncertainty for Wavelength: 2478.153 nm, FWHM: 8.806 nm"),
            Band(name="B284", description="Reflectance Uncertainty for Wavelength: 2485.539 nm, FWHM: 8.807 nm"),
            Band(name="B285", description="Reflectance Uncertainty for Wavelength: 2492.924 nm, FWHM: 8.809 nm"),
            Band(name="elev", description="Elevation"),
        ]
    ),
    Product(
        product_id="EMIT_L2A_MASK.001",
        description="L2A Reflectance Masks",
        bands=[
            Band(name="B001", description="Interpolation flag for Wavelength: 381.006 nm, FWHM: 8.415 nm"),
            Band(name="B002", description="Interpolation flag for Wavelength: 388.409 nm, FWHM: 8.415 nm"),
            Band(name="B003", description="Interpolation flag for Wavelength: 395.816 nm, FWHM: 8.415 nm"),
            Band(name="B004", description="Interpolation flag for Wavelength: 403.225 nm, FWHM: 8.415 nm"),
            Band(name="B005", description="Interpolation flag for Wavelength: 410.638 nm, FWHM: 8.417 nm"),
            Band(name="B006", description="Interpolation flag for Wavelength: 418.054 nm, FWHM: 8.418 nm"),
            Band(name="B007", description="Interpolation flag for Wavelength: 425.472 nm, FWHM: 8.419 nm"),
            Band(name="B008", description="Interpolation flag for Wavelength: 432.893 nm, FWHM: 8.421 nm"),
            Band(name="B009", description="Interpolation flag for Wavelength: 440.317 nm, FWHM: 8.422 nm"),
            Band(name="B010", description="Interpolation flag for Wavelength: 447.743 nm, FWHM: 8.424 nm"),
            Band(name="B011", description="Interpolation flag for Wavelength: 455.170 nm, FWHM: 8.425 nm"),
            Band(name="B012", description="Interpolation flag for Wavelength: 462.599 nm, FWHM: 8.426 nm"),
            Band(name="B013", description="Interpolation flag for Wavelength: 470.030 nm, FWHM: 8.428 nm"),
            Band(name="B014", description="Interpolation flag for Wavelength: 477.463 nm, FWHM: 8.429 nm"),
            Band(name="B015", description="Interpolation flag for Wavelength: 484.897 nm, FWHM: 8.431 nm"),
            Band(name="B016", description="Interpolation flag for Wavelength: 492.333 nm, FWHM: 8.432 nm"),
            Band(name="B017", description="Interpolation flag for Wavelength: 499.771 nm, FWHM: 8.433 nm"),
            Band(name="B018", description="Interpolation flag for Wavelength: 507.210 nm, FWHM: 8.435 nm"),
            Band(name="B019", description="Interpolation flag for Wavelength: 514.650 nm, FWHM: 8.436 nm"),
            Band(name="B020", description="Interpolation flag for Wavelength: 522.091 nm, FWHM: 8.438 nm"),
            Band(name="B021", description="Interpolation flag for Wavelength: 529.533 nm, FWHM: 8.439 nm"),
            Band(name="B022", description="Interpolation flag for Wavelength: 536.977 nm, FWHM: 8.440 nm"),
            Band(name="B023", description="Interpolation flag for Wavelength: 544.421 nm, FWHM: 8.442 nm"),
            Band(name="B024", description="Interpolation flag for Wavelength: 551.867 nm, FWHM: 8.443 nm"),
            Band(name="B025", description="Interpolation flag for Wavelength: 559.314 nm, FWHM: 8.445 nm"),
            Band(name="B026", description="Interpolation flag for Wavelength: 566.762 nm, FWHM: 8.446 nm"),
            Band(name="B027", description="Interpolation flag for Wavelength: 574.209 nm, FWHM: 8.447 nm"),
            Band(name="B028", description="Interpolation flag for Wavelength: 581.659 nm, FWHM: 8.449 nm"),
            Band(name="B029", description="Interpolation flag for Wavelength: 589.108 nm, FWHM: 8.450 nm"),
            Band(name="B030", description="Interpolation flag for Wavelength: 596.558 nm, FWHM: 8.452 nm"),
            Band(name="B031", description="Interpolation flag for Wavelength: 604.010 nm, FWHM: 8.453 nm"),
            Band(name="B032", description="Interpolation flag for Wavelength: 611.462 nm, FWHM: 8.454 nm"),
            Band(name="B033", description="Interpolation flag for Wavelength: 618.915 nm, FWHM: 8.456 nm"),
            Band(name="B034", description="Interpolation flag for Wavelength: 626.368 nm, FWHM: 8.457 nm"),
            Band(name="B035", description="Interpolation flag for Wavelength: 633.821 nm, FWHM: 8.459 nm"),
            Band(name="B036", description="Interpolation flag for Wavelength: 641.276 nm, FWHM: 8.460 nm"),
            Band(name="B037", description="Interpolation flag for Wavelength: 648.730 nm, FWHM: 8.461 nm"),
            Band(name="B038", description="Interpolation flag for Wavelength: 656.186 nm, FWHM: 8.463 nm"),
            Band(name="B039", description="Interpolation flag for Wavelength: 663.641 nm, FWHM: 8.464 nm"),
            Band(name="B040", description="Interpolation flag for Wavelength: 671.098 nm, FWHM: 8.466 nm"),
            Band(name="B041", description="Interpolation flag for Wavelength: 678.554 nm, FWHM: 8.467 nm"),
            Band(name="B042", description="Interpolation flag for Wavelength: 686.010 nm, FWHM: 8.468 nm"),
            Band(name="B043", description="Interpolation flag for Wavelength: 693.468 nm, FWHM: 8.470 nm"),
            Band(name="B044", description="Interpolation flag for Wavelength: 700.925 nm, FWHM: 8.471 nm"),
            Band(name="B045", description="Interpolation flag for Wavelength: 708.384 nm, FWHM: 8.473 nm"),
            Band(name="B046", description="Interpolation flag for Wavelength: 715.841 nm, FWHM: 8.474 nm"),
            Band(name="B047", description="Interpolation flag for Wavelength: 723.299 nm, FWHM: 8.475 nm"),
            Band(name="B048", description="Interpolation flag for Wavelength: 730.759 nm, FWHM: 8.477 nm"),
            Band(name="B049", description="Interpolation flag for Wavelength: 738.217 nm, FWHM: 8.478 nm"),
            Band(name="B050", description="Interpolation flag for Wavelength: 745.677 nm, FWHM: 8.480 nm"),
            Band(name="B051", description="Interpolation flag for Wavelength: 753.136 nm, FWHM: 8.481 nm"),
            Band(name="B052", description="Interpolation flag for Wavelength: 760.596 nm, FWHM: 8.482 nm"),
            Band(name="B053", description="Interpolation flag for Wavelength: 768.056 nm, FWHM: 8.484 nm"),
            Band(name="B054", description="Interpolation flag for Wavelength: 775.516 nm, FWHM: 8.485 nm"),
            Band(name="B055", description="Interpolation flag for Wavelength: 782.978 nm, FWHM: 8.487 nm"),
            Band(name="B056", description="Interpolation flag for Wavelength: 790.438 nm, FWHM: 8.488 nm"),
            Band(name="B057", description="Interpolation flag for Wavelength: 797.899 nm, FWHM: 8.489 nm"),
            Band(name="B058", description="Interpolation flag for Wavelength: 805.362 nm, FWHM: 8.491 nm"),
            Band(name="B059", description="Interpolation flag for Wavelength: 812.823 nm, FWHM: 8.492 nm"),
            Band(name="B060", description="Interpolation flag for Wavelength: 820.285 nm, FWHM: 8.494 nm"),
            Band(name="B061", description="Interpolation flag for Wavelength: 827.746 nm, FWHM: 8.495 nm"),
            Band(name="B062", description="Interpolation flag for Wavelength: 835.207 nm, FWHM: 8.496 nm"),
            Band(name="B063", description="Interpolation flag for Wavelength: 842.670 nm, FWHM: 8.498 nm"),
            Band(name="B064", description="Interpolation flag for Wavelength: 850.131 nm, FWHM: 8.499 nm"),
            Band(name="B065", description="Interpolation flag for Wavelength: 857.594 nm, FWHM: 8.501 nm"),
            Band(name="B066", description="Interpolation flag for Wavelength: 865.055 nm, FWHM: 8.502 nm"),
            Band(name="B067", description="Interpolation flag for Wavelength: 872.518 nm, FWHM: 8.503 nm"),
            Band(name="B068", description="Interpolation flag for Wavelength: 879.980 nm, FWHM: 8.505 nm"),
            Band(name="B069", description="Interpolation flag for Wavelength: 887.441 nm, FWHM: 8.506 nm"),
            Band(name="B070", description="Interpolation flag for Wavelength: 894.904 nm, FWHM: 8.508 nm"),
            Band(name="B071", description="Interpolation flag for Wavelength: 902.366 nm, FWHM: 8.509 nm"),
            Band(name="B072", description="Interpolation flag for Wavelength: 909.829 nm, FWHM: 8.510 nm"),
            Band(name="B073", description="Interpolation flag for Wavelength: 917.291 nm, FWHM: 8.512 nm"),
            Band(name="B074", description="Interpolation flag for Wavelength: 924.754 nm, FWHM: 8.513 nm"),
            Band(name="B075", description="Interpolation flag for Wavelength: 932.216 nm, FWHM: 8.515 nm"),
            Band(name="B076", description="Interpolation flag for Wavelength: 939.679 nm, FWHM: 8.516 nm"),
            Band(name="B077", description="Interpolation flag for Wavelength: 947.140 nm, FWHM: 8.517 nm"),
            Band(name="B078", description="Interpolation flag for Wavelength: 954.603 nm, FWHM: 8.519 nm"),
            Band(name="B079", description="Interpolation flag for Wavelength: 962.064 nm, FWHM: 8.520 nm"),
            Band(name="B080", description="Interpolation flag for Wavelength: 969.527 nm, FWHM: 8.522 nm"),
            Band(name="B081", description="Interpolation flag for Wavelength: 976.988 nm, FWHM: 8.523 nm"),
            Band(name="B082", description="Interpolation flag for Wavelength: 984.450 nm, FWHM: 8.524 nm"),
            Band(name="B083", description="Interpolation flag for Wavelength: 991.911 nm, FWHM: 8.526 nm"),
            Band(name="B084", description="Interpolation flag for Wavelength: 999.373 nm, FWHM: 8.527 nm"),
            Band(name="B085", description="Interpolation flag for Wavelength: 1006.834 nm, FWHM: 8.529 nm"),
            Band(name="B086", description="Interpolation flag for Wavelength: 1014.295 nm, FWHM: 8.530 nm"),
            Band(name="B087", description="Interpolation flag for Wavelength: 1021.757 nm, FWHM: 8.531 nm"),
            Band(name="B088", description="Interpolation flag for Wavelength: 1029.217 nm, FWHM: 8.533 nm"),
            Band(name="B089", description="Interpolation flag for Wavelength: 1036.678 nm, FWHM: 8.534 nm"),
            Band(name="B090", description="Interpolation flag for Wavelength: 1044.138 nm, FWHM: 8.536 nm"),
            Band(name="B091", description="Interpolation flag for Wavelength: 1051.599 nm, FWHM: 8.537 nm"),
            Band(name="B092", description="Interpolation flag for Wavelength: 1059.060 nm, FWHM: 8.538 nm"),
            Band(name="B093", description="Interpolation flag for Wavelength: 1066.520 nm, FWHM: 8.540 nm"),
            Band(name="B094", description="Interpolation flag for Wavelength: 1073.980 nm, FWHM: 8.541 nm"),
            Band(name="B095", description="Interpolation flag for Wavelength: 1081.440 nm, FWHM: 8.543 nm"),
            Band(name="B096", description="Interpolation flag for Wavelength: 1088.900 nm, FWHM: 8.544 nm"),
            Band(name="B097", description="Interpolation flag for Wavelength: 1096.360 nm, FWHM: 8.545 nm"),
            Band(name="B098", description="Interpolation flag for Wavelength: 1103.818 nm, FWHM: 8.547 nm"),
            Band(name="B099", description="Interpolation flag for Wavelength: 1111.278 nm, FWHM: 8.548 nm"),
            Band(name="B100", description="Interpolation flag for Wavelength: 1118.737 nm, FWHM: 8.550 nm"),
            Band(name="B101", description="Interpolation flag for Wavelength: 1126.196 nm, FWHM: 8.551 nm"),
            Band(name="B102", description="Interpolation flag for Wavelength: 1133.655 nm, FWHM: 8.552 nm"),
            Band(name="B103", description="Interpolation flag for Wavelength: 1141.113 nm, FWHM: 8.554 nm"),
            Band(name="B104", description="Interpolation flag for Wavelength: 1148.572 nm, FWHM: 8.555 nm"),
            Band(name="B105", description="Interpolation flag for Wavelength: 1156.030 nm, FWHM: 8.557 nm"),
            Band(name="B106", description="Interpolation flag for Wavelength: 1163.488 nm, FWHM: 8.558 nm"),
            Band(name="B107", description="Interpolation flag for Wavelength: 1170.946 nm, FWHM: 8.559 nm"),
            Band(name="B108", description="Interpolation flag for Wavelength: 1178.404 nm, FWHM: 8.561 nm"),
            Band(name="B109", description="Interpolation flag for Wavelength: 1185.862 nm, FWHM: 8.562 nm"),
            Band(name="B110", description="Interpolation flag for Wavelength: 1193.318 nm, FWHM: 8.564 nm"),
            Band(name="B111", description="Interpolation flag for Wavelength: 1200.776 nm, FWHM: 8.565 nm"),
            Band(name="B112", description="Interpolation flag for Wavelength: 1208.233 nm, FWHM: 8.566 nm"),
            Band(name="B113", description="Interpolation flag for Wavelength: 1215.690 nm, FWHM: 8.568 nm"),
            Band(name="B114", description="Interpolation flag for Wavelength: 1223.147 nm, FWHM: 8.569 nm"),
            Band(name="B115", description="Interpolation flag for Wavelength: 1230.604 nm, FWHM: 8.571 nm"),
            Band(name="B116", description="Interpolation flag for Wavelength: 1238.060 nm, FWHM: 8.572 nm"),
            Band(name="B117", description="Interpolation flag for Wavelength: 1245.515 nm, FWHM: 8.573 nm"),
            Band(name="B118", description="Interpolation flag for Wavelength: 1252.972 nm, FWHM: 8.575 nm"),
            Band(name="B119", description="Interpolation flag for Wavelength: 1260.428 nm, FWHM: 8.576 nm"),
            Band(name="B120", description="Interpolation flag for Wavelength: 1267.883 nm, FWHM: 8.578 nm"),
            Band(name="B121", description="Interpolation flag for Wavelength: 1275.339 nm, FWHM: 8.579 nm"),
            Band(name="B122", description="Interpolation flag for Wavelength: 1282.794 nm, FWHM: 8.580 nm"),
            Band(name="B123", description="Interpolation flag for Wavelength: 1290.250 nm, FWHM: 8.582 nm"),
            Band(name="B124", description="Interpolation flag for Wavelength: 1297.705 nm, FWHM: 8.583 nm"),
            Band(name="B125", description="Interpolation flag for Wavelength: 1305.160 nm, FWHM: 8.585 nm"),
            Band(name="B126", description="Interpolation flag for Wavelength: 1312.614 nm, FWHM: 8.586 nm"),
            Band(name="B127", description="Interpolation flag for Wavelength: 1320.068 nm, FWHM: 8.587 nm"),
            Band(name="B128", description="Interpolation flag for Wavelength: 1327.522 nm, FWHM: 8.589 nm"),
            Band(name="B129", description="Interpolation flag for Wavelength: 1334.976 nm, FWHM: 8.590 nm"),
            Band(name="B130", description="Interpolation flag for Wavelength: 1342.429 nm, FWHM: 8.592 nm"),
            Band(name="B131", description="Interpolation flag for Wavelength: 1349.882 nm, FWHM: 8.593 nm"),
            Band(name="B132", description="Interpolation flag for Wavelength: 1357.335 nm, FWHM: 8.594 nm"),
            Band(name="B133", description="Interpolation flag for Wavelength: 1364.787 nm, FWHM: 8.596 nm"),
            Band(name="B134", description="Interpolation flag for Wavelength: 1372.238 nm, FWHM: 8.597 nm"),
            Band(name="B135", description="Interpolation flag for Wavelength: 1379.691 nm, FWHM: 8.599 nm"),
            Band(name="B136", description="Interpolation flag for Wavelength: 1387.142 nm, FWHM: 8.600 nm"),
            Band(name="B137", description="Interpolation flag for Wavelength: 1394.593 nm, FWHM: 8.601 nm"),
            Band(name="B138", description="Interpolation flag for Wavelength: 1402.043 nm, FWHM: 8.603 nm"),
            Band(name="B139", description="Interpolation flag for Wavelength: 1409.494 nm, FWHM: 8.604 nm"),
            Band(name="B140", description="Interpolation flag for Wavelength: 1416.944 nm, FWHM: 8.606 nm"),
            Band(name="B141", description="Interpolation flag for Wavelength: 1424.393 nm, FWHM: 8.607 nm"),
            Band(name="B142", description="Interpolation flag for Wavelength: 1431.843 nm, FWHM: 8.608 nm"),
            Band(name="B143", description="Interpolation flag for Wavelength: 1439.292 nm, FWHM: 8.610 nm"),
            Band(name="B144", description="Interpolation flag for Wavelength: 1446.740 nm, FWHM: 8.611 nm"),
            Band(name="B145", description="Interpolation flag for Wavelength: 1454.189 nm, FWHM: 8.613 nm"),
            Band(name="B146", description="Interpolation flag for Wavelength: 1461.637 nm, FWHM: 8.614 nm"),
            Band(name="B147", description="Interpolation flag for Wavelength: 1469.085 nm, FWHM: 8.615 nm"),
            Band(name="B148", description="Interpolation flag for Wavelength: 1476.532 nm, FWHM: 8.617 nm"),
            Band(name="B149", description="Interpolation flag for Wavelength: 1483.980 nm, FWHM: 8.618 nm"),
            Band(name="B150", description="Interpolation flag for Wavelength: 1491.426 nm, FWHM: 8.620 nm"),
            Band(name="B151", description="Interpolation flag for Wavelength: 1498.873 nm, FWHM: 8.621 nm"),
            Band(name="B152", description="Interpolation flag for Wavelength: 1506.319 nm, FWHM: 8.622 nm"),
            Band(name="B153", description="Interpolation flag for Wavelength: 1513.765 nm, FWHM: 8.624 nm"),
            Band(name="B154", description="Interpolation flag for Wavelength: 1521.210 nm, FWHM: 8.625 nm"),
            Band(name="B155", description="Interpolation flag for Wavelength: 1528.655 nm, FWHM: 8.627 nm"),
            Band(name="B156", description="Interpolation flag for Wavelength: 1536.101 nm, FWHM: 8.628 nm"),
            Band(name="B157", description="Interpolation flag for Wavelength: 1543.545 nm, FWHM: 8.629 nm"),
            Band(name="B158", description="Interpolation flag for Wavelength: 1550.989 nm, FWHM: 8.631 nm"),
            Band(name="B159", description="Interpolation flag for Wavelength: 1558.433 nm, FWHM: 8.632 nm"),
            Band(name="B160", description="Interpolation flag for Wavelength: 1565.877 nm, FWHM: 8.634 nm"),
            Band(name="B161", description="Interpolation flag for Wavelength: 1573.319 nm, FWHM: 8.635 nm"),
            Band(name="B162", description="Interpolation flag for Wavelength: 1580.762 nm, FWHM: 8.636 nm"),
            Band(name="B163", description="Interpolation flag for Wavelength: 1588.205 nm, FWHM: 8.638 nm"),
            Band(name="B164", description="Interpolation flag for Wavelength: 1595.647 nm, FWHM: 8.639 nm"),
            Band(name="B165", description="Interpolation flag for Wavelength: 1603.089 nm, FWHM: 8.641 nm"),
            Band(name="B166", description="Interpolation flag for Wavelength: 1610.530 nm, FWHM: 8.642 nm"),
            Band(name="B167", description="Interpolation flag for Wavelength: 1617.970 nm, FWHM: 8.643 nm"),
            Band(name="B168", description="Interpolation flag for Wavelength: 1625.410 nm, FWHM: 8.645 nm"),
            Band(name="B169", description="Interpolation flag for Wavelength: 1632.851 nm, FWHM: 8.646 nm"),
            Band(name="B170", description="Interpolation flag for Wavelength: 1640.290 nm, FWHM: 8.648 nm"),
            Band(name="B171", description="Interpolation flag for Wavelength: 1647.730 nm, FWHM: 8.649 nm"),
            Band(name="B172", description="Interpolation flag for Wavelength: 1655.169 nm, FWHM: 8.650 nm"),
            Band(name="B173", description="Interpolation flag for Wavelength: 1662.607 nm, FWHM: 8.652 nm"),
            Band(name="B174", description="Interpolation flag for Wavelength: 1670.046 nm, FWHM: 8.653 nm"),
            Band(name="B175", description="Interpolation flag for Wavelength: 1677.484 nm, FWHM: 8.655 nm"),
            Band(name="B176", description="Interpolation flag for Wavelength: 1684.921 nm, FWHM: 8.656 nm"),
            Band(name="B177", description="Interpolation flag for Wavelength: 1692.358 nm, FWHM: 8.657 nm"),
            Band(name="B178", description="Interpolation flag for Wavelength: 1699.795 nm, FWHM: 8.659 nm"),
            Band(name="B179", description="Interpolation flag for Wavelength: 1707.231 nm, FWHM: 8.660 nm"),
            Band(name="B180", description="Interpolation flag for Wavelength: 1714.667 nm, FWHM: 8.662 nm"),
            Band(name="B181", description="Interpolation flag for Wavelength: 1722.103 nm, FWHM: 8.663 nm"),
            Band(name="B182", description="Interpolation flag for Wavelength: 1729.538 nm, FWHM: 8.664 nm"),
            Band(name="B183", description="Interpolation flag for Wavelength: 1736.973 nm, FWHM: 8.666 nm"),
            Band(name="B184", description="Interpolation flag for Wavelength: 1744.407 nm, FWHM: 8.667 nm"),
            Band(name="B185", description="Interpolation flag for Wavelength: 1751.841 nm, FWHM: 8.669 nm"),
            Band(name="B186", description="Interpolation flag for Wavelength: 1759.275 nm, FWHM: 8.670 nm"),
            Band(name="B187", description="Interpolation flag for Wavelength: 1766.708 nm, FWHM: 8.671 nm"),
            Band(name="B188", description="Interpolation flag for Wavelength: 1774.142 nm, FWHM: 8.673 nm"),
            Band(name="B189", description="Interpolation flag for Wavelength: 1781.574 nm, FWHM: 8.674 nm"),
            Band(name="B190", description="Interpolation flag for Wavelength: 1789.007 nm, FWHM: 8.676 nm"),
            Band(name="B191", description="Interpolation flag for Wavelength: 1796.438 nm, FWHM: 8.677 nm"),
            Band(name="B192", description="Interpolation flag for Wavelength: 1803.870 nm, FWHM: 8.678 nm"),
            Band(name="B193", description="Interpolation flag for Wavelength: 1811.301 nm, FWHM: 8.680 nm"),
            Band(name="B194", description="Interpolation flag for Wavelength: 1818.731 nm, FWHM: 8.681 nm"),
            Band(name="B195", description="Interpolation flag for Wavelength: 1826.161 nm, FWHM: 8.683 nm"),
            Band(name="B196", description="Interpolation flag for Wavelength: 1833.591 nm, FWHM: 8.684 nm"),
            Band(name="B197", description="Interpolation flag for Wavelength: 1841.021 nm, FWHM: 8.685 nm"),
            Band(name="B198", description="Interpolation flag for Wavelength: 1848.449 nm, FWHM: 8.687 nm"),
            Band(name="B199", description="Interpolation flag for Wavelength: 1855.877 nm, FWHM: 8.688 nm"),
            Band(name="B200", description="Interpolation flag for Wavelength: 1863.305 nm, FWHM: 8.690 nm"),
            Band(name="B201", description="Interpolation flag for Wavelength: 1870.733 nm, FWHM: 8.691 nm"),
            Band(name="B202", description="Interpolation flag for Wavelength: 1878.160 nm, FWHM: 8.692 nm"),
            Band(name="B203", description="Interpolation flag for Wavelength: 1885.587 nm, FWHM: 8.694 nm"),
            Band(name="B204", description="Interpolation flag for Wavelength: 1893.013 nm, FWHM: 8.695 nm"),
            Band(name="B205", description="Interpolation flag for Wavelength: 1900.439 nm, FWHM: 8.697 nm"),
            Band(name="B206", description="Interpolation flag for Wavelength: 1907.864 nm, FWHM: 8.698 nm"),
            Band(name="B207", description="Interpolation flag for Wavelength: 1915.289 nm, FWHM: 8.699 nm"),
            Band(name="B208", description="Interpolation flag for Wavelength: 1922.713 nm, FWHM: 8.701 nm"),
            Band(name="B209", description="Interpolation flag for Wavelength: 1930.137 nm, FWHM: 8.702 nm"),
            Band(name="B210", description="Interpolation flag for Wavelength: 1937.561 nm, FWHM: 8.704 nm"),
            Band(name="B211", description="Interpolation flag for Wavelength: 1944.984 nm, FWHM: 8.705 nm"),
            Band(name="B212", description="Interpolation flag for Wavelength: 1952.407 nm, FWHM: 8.706 nm"),
            Band(name="B213", description="Interpolation flag for Wavelength: 1959.829 nm, FWHM: 8.708 nm"),
            Band(name="B214", description="Interpolation flag for Wavelength: 1967.252 nm, FWHM: 8.709 nm"),
            Band(name="B215", description="Interpolation flag for Wavelength: 1974.673 nm, FWHM: 8.711 nm"),
            Band(name="B216", description="Interpolation flag for Wavelength: 1982.095 nm, FWHM: 8.712 nm"),
            Band(name="B217", description="Interpolation flag for Wavelength: 1989.515 nm, FWHM: 8.714 nm"),
            Band(name="B218", description="Interpolation flag for Wavelength: 1996.936 nm, FWHM: 8.715 nm"),
            Band(name="B219", description="Interpolation flag for Wavelength: 2004.355 nm, FWHM: 8.716 nm"),
            Band(name="B220", description="Interpolation flag for Wavelength: 2011.775 nm, FWHM: 8.718 nm"),
            Band(name="B221", description="Interpolation flag for Wavelength: 2019.193 nm, FWHM: 8.719 nm"),
            Band(name="B222", description="Interpolation flag for Wavelength: 2026.612 nm, FWHM: 8.721 nm"),
            Band(name="B223", description="Interpolation flag for Wavelength: 2034.030 nm, FWHM: 8.722 nm"),
            Band(name="B224", description="Interpolation flag for Wavelength: 2041.447 nm, FWHM: 8.723 nm"),
            Band(name="B225", description="Interpolation flag for Wavelength: 2048.865 nm, FWHM: 8.725 nm"),
            Band(name="B226", description="Interpolation flag for Wavelength: 2056.281 nm, FWHM: 8.726 nm"),
            Band(name="B227", description="Interpolation flag for Wavelength: 2063.697 nm, FWHM: 8.727 nm"),
            Band(name="B228", description="Interpolation flag for Wavelength: 2071.112 nm, FWHM: 8.729 nm"),
            Band(name="B229", description="Interpolation flag for Wavelength: 2078.527 nm, FWHM: 8.730 nm"),
            Band(name="B230", description="Interpolation flag for Wavelength: 2085.942 nm, FWHM: 8.732 nm"),
            Band(name="B231", description="Interpolation flag for Wavelength: 2093.356 nm, FWHM: 8.733 nm"),
            Band(name="B232", description="Interpolation flag for Wavelength: 2100.769 nm, FWHM: 8.734 nm"),
            Band(name="B233", description="Interpolation flag for Wavelength: 2108.182 nm, FWHM: 8.736 nm"),
            Band(name="B234", description="Interpolation flag for Wavelength: 2115.594 nm, FWHM: 8.737 nm"),
            Band(name="B235", description="Interpolation flag for Wavelength: 2123.006 nm, FWHM: 8.739 nm"),
            Band(name="B236", description="Interpolation flag for Wavelength: 2130.417 nm, FWHM: 8.740 nm"),
            Band(name="B237", description="Interpolation flag for Wavelength: 2137.829 nm, FWHM: 8.741 nm"),
            Band(name="B238", description="Interpolation flag for Wavelength: 2145.239 nm, FWHM: 8.743 nm"),
            Band(name="B239", description="Interpolation flag for Wavelength: 2152.648 nm, FWHM: 8.744 nm"),
            Band(name="B240", description="Interpolation flag for Wavelength: 2160.058 nm, FWHM: 8.746 nm"),
            Band(name="B241", description="Interpolation flag for Wavelength: 2167.467 nm, FWHM: 8.747 nm"),
            Band(name="B242", description="Interpolation flag for Wavelength: 2174.875 nm, FWHM: 8.748 nm"),
            Band(name="B243", description="Interpolation flag for Wavelength: 2182.283 nm, FWHM: 8.750 nm"),
            Band(name="B244", description="Interpolation flag for Wavelength: 2189.690 nm, FWHM: 8.751 nm"),
            Band(name="B245", description="Interpolation flag for Wavelength: 2197.097 nm, FWHM: 8.753 nm"),
            Band(name="B246", description="Interpolation flag for Wavelength: 2204.503 nm, FWHM: 8.754 nm"),
            Band(name="B247", description="Interpolation flag for Wavelength: 2211.909 nm, FWHM: 8.755 nm"),
            Band(name="B248", description="Interpolation flag for Wavelength: 2219.315 nm, FWHM: 8.757 nm"),
            Band(name="B249", description="Interpolation flag for Wavelength: 2226.719 nm, FWHM: 8.758 nm"),
            Band(name="B250", description="Interpolation flag for Wavelength: 2234.123 nm, FWHM: 8.760 nm"),
            Band(name="B251", description="Interpolation flag for Wavelength: 2241.527 nm, FWHM: 8.761 nm"),
            Band(name="B252", description="Interpolation flag for Wavelength: 2248.930 nm, FWHM: 8.763 nm"),
            Band(name="B253", description="Interpolation flag for Wavelength: 2256.333 nm, FWHM: 8.764 nm"),
            Band(name="B254", description="Interpolation flag for Wavelength: 2263.735 nm, FWHM: 8.765 nm"),
            Band(name="B255", description="Interpolation flag for Wavelength: 2271.136 nm, FWHM: 8.767 nm"),
            Band(name="B256", description="Interpolation flag for Wavelength: 2278.538 nm, FWHM: 8.768 nm"),
            Band(name="B257", description="Interpolation flag for Wavelength: 2285.939 nm, FWHM: 8.770 nm"),
            Band(name="B258", description="Interpolation flag for Wavelength: 2293.339 nm, FWHM: 8.771 nm"),
            Band(name="B259", description="Interpolation flag for Wavelength: 2300.738 nm, FWHM: 8.772 nm"),
            Band(name="B260", description="Interpolation flag for Wavelength: 2308.136 nm, FWHM: 8.774 nm"),
            Band(name="B261", description="Interpolation flag for Wavelength: 2315.534 nm, FWHM: 8.775 nm"),
            Band(name="B262", description="Interpolation flag for Wavelength: 2322.933 nm, FWHM: 8.777 nm"),
            Band(name="B263", description="Interpolation flag for Wavelength: 2330.330 nm, FWHM: 8.778 nm"),
            Band(name="B264", description="Interpolation flag for Wavelength: 2337.726 nm, FWHM: 8.779 nm"),
            Band(name="B265", description="Interpolation flag for Wavelength: 2345.122 nm, FWHM: 8.781 nm"),
            Band(name="B266", description="Interpolation flag for Wavelength: 2352.517 nm, FWHM: 8.782 nm"),
            Band(name="B267", description="Interpolation flag for Wavelength: 2359.913 nm, FWHM: 8.783 nm"),
            Band(name="B268", description="Interpolation flag for Wavelength: 2367.307 nm, FWHM: 8.785 nm"),
            Band(name="B269", description="Interpolation flag for Wavelength: 2374.701 nm, FWHM: 8.786 nm"),
            Band(name="B270", description="Interpolation flag for Wavelength: 2382.094 nm, FWHM: 8.788 nm"),
            Band(name="B271", description="Interpolation flag for Wavelength: 2389.486 nm, FWHM: 8.789 nm"),
            Band(name="B272", description="Interpolation flag for Wavelength: 2396.878 nm, FWHM: 8.790 nm"),
            Band(name="B273", description="Interpolation flag for Wavelength: 2404.270 nm, FWHM: 8.792 nm"),
            Band(name="B274", description="Interpolation flag for Wavelength: 2411.660 nm, FWHM: 8.793 nm"),
            Band(name="B275", description="Interpolation flag for Wavelength: 2419.051 nm, FWHM: 8.795 nm"),
            Band(name="B276", description="Interpolation flag for Wavelength: 2426.440 nm, FWHM: 8.796 nm"),
            Band(name="B277", description="Interpolation flag for Wavelength: 2433.830 nm, FWHM: 8.797 nm"),
            Band(name="B278", description="Interpolation flag for Wavelength: 2441.218 nm, FWHM: 8.799 nm"),
            Band(name="B279", description="Interpolation flag for Wavelength: 2448.606 nm, FWHM: 8.800 nm"),
            Band(name="B280", description="Interpolation flag for Wavelength: 2455.994 nm, FWHM: 8.802 nm"),
            Band(name="B281", description="Interpolation flag for Wavelength: 2463.382 nm, FWHM: 8.803 nm"),
            Band(name="B282", description="Interpolation flag for Wavelength: 2470.768 nm, FWHM: 8.804 nm"),
            Band(name="B283", description="Interpolation flag for Wavelength: 2478.153 nm, FWHM: 8.806 nm"),
            Band(name="B284", description="Interpolation flag for Wavelength: 2485.539 nm, FWHM: 8.807 nm"),
            Band(name="B285", description="Interpolation flag for Wavelength: 2492.924 nm, FWHM: 8.809 nm"),
            Band(name="aggregate_flag", description="Aggregated binary flag of bands 1-5"),
            Band(name="aod550", description="AOD at 550 nm estimates"),
            Band(name="cirrus_flag", description="Dense cirrus clouds"),
            Band(name="cloud_flag", description="Cloud coverage"),
            Band(name="dilated_cloud_flag", description="Cloud coverage + buffer"),
            Band(name="elev", description="Elevation"),
            Band(name="h2o", description="Water vapor estimates"),
            Band(name="spacecraft_flag", description="Spacecraft or space station components that intersect the EMIT field of view"),
            Band(name="water_flag", description="Water bodies"),
        ]
    ),
]
